@@ -3,7 +3,7 @@ from textwrap import dedent
 from lxml import etree
 
 from pcs import settings
-from pcs.cli.common.console_report import error
+from pcs.cli.reports.output import error
 from pcs.common.tools import xml_fromstring
 
 
@@ -19,9 +19,10 @@ def get_capabilities_definition():
             capabilities_xml = xml_fromstring(file_.read())
     except (EnvironmentError, etree.XMLSyntaxError, etree.DocumentInvalid) as e:
         raise error(
-            "Cannot read capabilities definition file '{0}': '{1}'"
-            .format(filename, str(e))
-        )
+            "Cannot read capabilities definition file '{0}': '{1}'".format(
+                filename, str(e)
+            )
+        ) from e
     capabilities = []
     for feat_xml in capabilities_xml.findall(".//capability"):
         feat = dict(feat_xml.attrib)
@@ -31,6 +32,7 @@ def get_capabilities_definition():
         capabilities.append(feat)
     return capabilities
 
+
 def get_pcs_capabilities():
     """
     Get pcs capabilities form the capabilities file
