@@ -19,6 +19,8 @@ from pcs.lib.commands import (
     resource,
     resource_agent,
     sbd,
+    services,
+    scsi,
     status,
     stonith,
     stonith_agent,
@@ -229,8 +231,8 @@ def load_module(env, middleware_factory, name):
             env,
             middleware.build(middleware_factory.cib),
             {
-                "set": constraint_colocation.create_with_set,
-                "show": constraint_colocation.show,
+                "create_with_set": constraint_colocation.create_with_set,
+                "config": constraint_colocation.config,
             },
         )
 
@@ -239,8 +241,8 @@ def load_module(env, middleware_factory, name):
             env,
             middleware.build(middleware_factory.cib),
             {
-                "set": constraint_order.create_with_set,
-                "show": constraint_order.show,
+                "create_with_set": constraint_order.create_with_set,
+                "config": constraint_order.config,
             },
         )
 
@@ -249,9 +251,9 @@ def load_module(env, middleware_factory, name):
             env,
             middleware.build(middleware_factory.cib),
             {
-                "set": constraint_ticket.create_with_set,
-                "show": constraint_ticket.show,
-                "add": constraint_ticket.create,
+                "create_with_set": constraint_ticket.create_with_set,
+                "config": constraint_ticket.config,
+                "create": constraint_ticket.create,
                 "remove": constraint_ticket.remove,
             },
         )
@@ -303,21 +305,21 @@ def load_module(env, middleware_factory, name):
             env,
             middleware.build(),
             {
-                "status": qdevice.qdevice_status_text,
-                "setup": qdevice.qdevice_setup,
-                "destroy": qdevice.qdevice_destroy,
-                "start": qdevice.qdevice_start,
-                "stop": qdevice.qdevice_stop,
-                "kill": qdevice.qdevice_kill,
-                "enable": qdevice.qdevice_enable,
-                "disable": qdevice.qdevice_disable,
+                "qdevice_status_text": qdevice.qdevice_status_text,
+                "qdevice_setup": qdevice.qdevice_setup,
+                "qdevice_destroy": qdevice.qdevice_destroy,
+                "qdevice_start": qdevice.qdevice_start,
+                "qdevice_stop": qdevice.qdevice_stop,
+                "qdevice_kill": qdevice.qdevice_kill,
+                "qdevice_enable": qdevice.qdevice_enable,
+                "qdevice_disable": qdevice.qdevice_disable,
                 # following commands are internal use only, called from pcsd
                 "client_net_setup": qdevice.client_net_setup,
                 "client_net_import_certificate": (
                     qdevice.client_net_import_certificate
                 ),
                 "client_net_destroy": qdevice.client_net_destroy,
-                "sign_net_cert_request": (
+                "qdevice_net_sign_certificate_request": (
                     qdevice.qdevice_net_sign_certificate_request
                 ),
             },
@@ -334,8 +336,8 @@ def load_module(env, middleware_factory, name):
                 "remove_device_heuristics": quorum.remove_device_heuristics,
                 "set_expected_votes_live": quorum.set_expected_votes_live,
                 "set_options": quorum.set_options,
-                "status": quorum.status_text,
-                "status_device": quorum.status_device_text,
+                "status_text": quorum.status_text,
+                "status_device_text": quorum.status_device_text,
                 "update_device": quorum.update_device,
             },
         )
@@ -379,6 +381,7 @@ def load_module(env, middleware_factory, name):
                 "group_add": resource.group_add,
                 "manage": resource.manage,
                 "move": resource.move,
+                "move_autoclean": resource.move_autoclean,
                 "get_resource_relations_tree": (
                     resource.get_resource_relations_tree
                 ),
@@ -432,6 +435,8 @@ def load_module(env, middleware_factory, name):
                 "history_get_text": stonith.history_get_text,
                 "history_cleanup": stonith.history_cleanup,
                 "history_update": stonith.history_update,
+                "update_scsi_devices": stonith.update_scsi_devices,
+                "update_scsi_devices_add_remove": stonith.update_scsi_devices_add_remove,
             },
         )
 
@@ -455,6 +460,27 @@ def load_module(env, middleware_factory, name):
             },
         )
 
+    if name == "services":
+        return bind_all(
+            env,
+            middleware.build(),
+            {
+                "start_service": services.start_service,
+                "stop_service": services.stop_service,
+                "enable_service": services.enable_service,
+                "disable_service": services.disable_service,
+                "get_services_info": services.get_services_info,
+            },
+        )
+    if name == "scsi":
+        return bind_all(
+            env,
+            middleware.build(),
+            {
+                "unfence_node": scsi.unfence_node,
+            },
+        )
+
     if name == "stonith_agent":
         return bind_all(
             env,
@@ -472,8 +498,6 @@ def load_module(env, middleware_factory, name):
             {
                 "config": tag.config,
                 "create": tag.create,
-                "delete": tag.remove,
-                "list": tag.config,
                 "remove": tag.remove,
                 "update": tag.update,
             },
