@@ -6,45 +6,35 @@ from .types import (
 
 # force categories
 FORCE = F("FORCE")
-FORCE_ALERT_RECIPIENT_VALUE_NOT_UNIQUE = F(
-    "FORCE_ALERT_RECIPIENT_VALUE_NOT_UNIQUE"
-)
-FORCE_ALREADY_IN_CLUSTER = F("FORCE_ALREADY_IN_CLUSTER")
-FORCE_BOOTH_DESTROY = F("FORCE_BOOTH_DESTROY")
-FORCE_BOOTH_REMOVE_FROM_CIB = F("FORCE_BOOTH_REMOVE_FROM_CIB")
-FORCE_REMOVE_MULTIPLE_NODES = F("FORCE_REMOVE_MULTIPLE_NODES")
-FORCE_CONSTRAINT_DUPLICATE = F("FORCE_CONSTRAINT_DUPLICATE")
-FORCE_CONSTRAINT_MULTIINSTANCE_RESOURCE = F(
-    "FORCE_CONSTRAINT_MULTIINSTANCE_RESOURCE"
-)
-FORCE_FILE_OVERWRITE = F("FORCE_FILE_OVERWRITE")
-FORCE_LOAD_NODES_FROM_CIB = F("FORCE_LOAD_NODES_FROM_CIB")
-FORCE_LOAD_THRESHOLD = F("FORCE_LOAD_THRESHOLD")
-FORCE_METADATA_ISSUE = F("FORCE_METADATA_ISSUE")
-FORCE_NODE_ADDRESSES_UNRESOLVABLE = F("FORCE_NODE_ADDRESSES_UNRESOLVABLE")
-FORCE_NODE_DOES_NOT_EXIST = F("FORCE_NODE_DOES_NOT_EXIST")
-FORCE_OPTIONS = F("FORCE_OPTIONS")
-FORCE_OVERWRITE = F("FORCE_OVERWRITE")
-FORCE_QDEVICE_MODEL = F("FORCE_QDEVICE_MODEL")
-FORCE_QDEVICE_USED = F("FORCE_QDEVICE_USED")
-FORCE_QUORUM_LOSS = F("FORCE_QUORUM_LOSS")
-FORCE_STONITH_RESOURCE_DOES_NOT_EXIST = F(
-    "FORCE_STONITH_RESOURCE_DOES_NOT_EXIST"
-)
-FORCE_NOT_SUITABLE_COMMAND = F("FORCE_NOT_SUITABLE_COMMAND")
-FORCE_CLEAR_CLUSTER_NODE = F("FORCE_CLEAR_CLUSTER_NODE")
-FORCE_RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE = F(
-    "FORCE_RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE"
-)
 SKIP_OFFLINE_NODES = F("SKIP_OFFLINE_NODES")
-SKIP_FILE_DISTRIBUTION_ERRORS = F("SKIP_FILE_DISTRIBUTION_ERRORS")
-SKIP_ACTION_ON_NODES_ERRORS = F("SKIP_ACTION_ON_NODES_ERRORS")
-SKIP_UNREADABLE_CONFIG = F("SKIP_UNREADABLE_CONFIG")
 
 
 # messages
 
 
+ADD_REMOVE_ITEMS_NOT_SPECIFIED = M("ADD_REMOVE_ITEMS_NOT_SPECIFIED")
+ADD_REMOVE_ITEMS_DUPLICATION = M("ADD_REMOVE_ITEMS_DUPLICATION")
+ADD_REMOVE_CANNOT_ADD_ITEMS_ALREADY_IN_THE_CONTAINER = M(
+    "ADD_REMOVE_CANNOT_ADD_ITEMS_ALREADY_IN_THE_CONTAINER"
+)
+ADD_REMOVE_CANNOT_REMOVE_ITEMS_NOT_IN_THE_CONTAINER = M(
+    "ADD_REMOVE_CANNOT_REMOVE_ITEMS_NOT_IN_THE_CONTAINER"
+)
+ADD_REMOVE_CANNOT_ADD_AND_REMOVE_ITEMS_AT_THE_SAME_TIME = M(
+    "ADD_REMOVE_CANNOT_ADD_AND_REMOVE_ITEMS_AT_THE_SAME_TIME"
+)
+ADD_REMOVE_CANNOT_REMOVE_ALL_ITEMS_FROM_THE_CONTAINER = M(
+    "ADD_REMOVE_CANNOT_REMOVE_ALL_ITEMS_FROM_THE_CONTAINER"
+)
+ADD_REMOVE_ADJACENT_ITEM_NOT_IN_THE_CONTAINER = M(
+    "ADD_REMOVE_ADJACENT_ITEM_NOT_IN_THE_CONTAINER"
+)
+ADD_REMOVE_CANNOT_PUT_ITEM_NEXT_TO_ITSELF = M(
+    "ADD_REMOVE_CANNOT_PUT_ITEM_NEXT_TO_ITSELF"
+)
+ADD_REMOVE_CANNOT_SPECIFY_ADJACENT_ITEM_WITHOUT_ITEMS_TO_ADD = M(
+    "ADD_REMOVE_CANNOT_SPECIFY_ADJACENT_ITEM_WITHOUT_ITEMS_TO_ADD"
+)
 AGENT_NAME_GUESS_FOUND_MORE_THAN_ONE = M("AGENT_NAME_GUESS_FOUND_MORE_THAN_ONE")
 AGENT_NAME_GUESS_FOUND_NONE = M("AGENT_NAME_GUESS_FOUND_NONE")
 AGENT_NAME_GUESSED = M("AGENT_NAME_GUESSED")
@@ -77,19 +67,26 @@ CANNOT_BAN_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE = M(
 CANNOT_BAN_RESOURCE_STOPPED_NO_NODE_SPECIFIED = M(
     "CANNOT_BAN_RESOURCE_STOPPED_NO_NODE_SPECIFIED"
 )
+# TODO: remove, use ADD_REMOVE reports
 CANNOT_GROUP_RESOURCE_ADJACENT_RESOURCE_FOR_NEW_GROUP = M(
     "CANNOT_GROUP_RESOURCE_ADJACENT_RESOURCE_FOR_NEW_GROUP"
 )
+# TODO: remove, use ADD_REMOVE reports
 CANNOT_GROUP_RESOURCE_ADJACENT_RESOURCE_NOT_IN_GROUP = M(
     "CANNOT_GROUP_RESOURCE_ADJACENT_RESOURCE_NOT_IN_GROUP"
 )
+# TODO: remove, use ADD_REMOVE reports
 CANNOT_GROUP_RESOURCE_ALREADY_IN_THE_GROUP = M(
     "CANNOT_GROUP_RESOURCE_ALREADY_IN_THE_GROUP"
 )
+# TODO: remove, use ADD_REMOVE reports
 CANNOT_GROUP_RESOURCE_MORE_THAN_ONCE = M("CANNOT_GROUP_RESOURCE_MORE_THAN_ONCE")
+# TODO: remove, use ADD_REMOVE reports
 CANNOT_GROUP_RESOURCE_NEXT_TO_ITSELF = M("CANNOT_GROUP_RESOURCE_NEXT_TO_ITSELF")
+# TODO: remove, use ADD_REMOVE reports
 CANNOT_GROUP_RESOURCE_NO_RESOURCES = M("CANNOT_GROUP_RESOURCE_NO_RESOURCES")
 CANNOT_GROUP_RESOURCE_WRONG_TYPE = M("CANNOT_GROUP_RESOURCE_WRONG_TYPE")
+CANNOT_LEAVE_GROUP_EMPTY_AFTER_MOVE = M("CANNOT_LEAVE_GROUP_EMPTY_AFTER_MOVE")
 CANNOT_MOVE_RESOURCE_BUNDLE = M("CANNOT_MOVE_RESOURCE_BUNDLE")
 CANNOT_MOVE_RESOURCE_CLONE = M("CANNOT_MOVE_RESOURCE_CLONE")
 CANNOT_MOVE_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE = M(
@@ -125,9 +122,6 @@ CIB_LOAD_ERROR_GET_NODES_FOR_VALIDATION = M(
 )
 CIB_NVSET_AMBIGUOUS_PROVIDE_NVSET_ID = M("CIB_NVSET_AMBIGUOUS_PROVIDE_NVSET_ID")
 CIB_LOAD_ERROR_SCOPE_MISSING = M("CIB_LOAD_ERROR_SCOPE_MISSING")
-CIB_PUSH_FORCED_FULL_DUE_TO_CRM_FEATURE_SET = M(
-    "CIB_PUSH_FORCED_FULL_DUE_TO_CRM_FEATURE_SET"
-)
 CIB_PUSH_ERROR = M("CIB_PUSH_ERROR")
 CIB_SAVE_TMP_ERROR = M("CIB_SAVE_TMP_ERROR")
 CIB_SIMULATE_ERROR = M("CIB_SIMULATE_ERROR")
@@ -312,6 +306,7 @@ NODE_TO_CLEAR_IS_STILL_IN_CLUSTER = M("NODE_TO_CLEAR_IS_STILL_IN_CLUSTER")
 NODE_IN_LOCAL_CLUSTER = M("NODE_IN_LOCAL_CLUSTER")
 OMITTING_NODE = M("OMITTING_NODE")
 OBJECT_WITH_ID_IN_UNEXPECTED_CONTEXT = M("OBJECT_WITH_ID_IN_UNEXPECTED_CONTEXT")
+PACEMAKER_SIMULATION_RESULT = M("PACEMAKER_SIMULATION_RESULT")
 PACEMAKER_LOCAL_NODE_NAME_NOT_FOUND = M("PACEMAKER_LOCAL_NODE_NAME_NOT_FOUND")
 PARSE_ERROR_COROSYNC_CONF = M("PARSE_ERROR_COROSYNC_CONF")
 PARSE_ERROR_COROSYNC_CONF_EXTRA_CHARACTERS_AFTER_OPENING_BRACE = M(
@@ -410,6 +405,14 @@ RESOURCE_UNMOVE_UNBAN_PCMK_SUCCESS = M("RESOURCE_UNMOVE_UNBAN_PCMK_SUCCESS")
 RESOURCE_UNMOVE_UNBAN_PCMK_EXPIRED_NOT_SUPPORTED = M(
     "RESOURCE_UNMOVE_UNBAN_PCMK_EXPIRED_NOT_SUPPORTED"
 )
+RESOURCE_MOVE_CONSTRAINT_CREATED = M("RESOURCE_MOVE_CONSTRAINT_CREATED")
+RESOURCE_MOVE_CONSTRAINT_REMOVED = M("RESOURCE_MOVE_CONSTRAINT_REMOVED")
+RESOURCE_MOVE_AFFECTS_OTRHER_RESOURCES = M(
+    "RESOURCE_MOVE_AFFECTS_OTRHER_RESOURCES"
+)
+RESOURCE_MOVE_AUTOCLEAN_SIMULATION_FAILURE = M(
+    "RESOURCE_MOVE_AUTOCLEAN_SIMULATION_FAILURE"
+)
 RULE_IN_EFFECT_STATUS_DETECTION_NOT_SUPPORTED = M(
     "RULE_IN_EFFECT_STATUS_DETECTION_NOT_SUPPORTED"
 )
@@ -454,19 +457,43 @@ SERVICE_ACTION_SUCCEEDED = M("SERVICE_ACTION_SUCCEEDED")
 SERVICE_ACTION_SKIPPED = M("SERVICE_ACTION_SKIPPED")
 SERVICE_NOT_INSTALLED = M("SERVICE_NOT_INSTALLED")
 SERVICE_VERSION_MISMATCH = M("SERVICE_VERSION_MISMATCH")
+UNABLE_TO_GET_RESOURCE_OPERATION_DIGESTS = M(
+    "UNABLE_TO_GET_RESOURCE_OPERATION_DIGESTS"
+)
 STONITH_RESOURCES_DO_NOT_EXIST = M("STONITH_RESOURCES_DO_NOT_EXIST")
+STONITH_RESTARTLESS_UPDATE_OF_SCSI_DEVICES_NOT_SUPPORTED = M(
+    "STONITH_RESTARTLESS_UPDATE_OF_SCSI_DEVICES_NOT_SUPPORTED"
+)
+STONITH_RESTARTLESS_UPDATE_UNSUPPORTED_AGENT = M(
+    "STONITH_RESTARTLESS_UPDATE_UNSUPPORTED_AGENT"
+)
+STONITH_UNFENCING_FAILED = M("STONITH_UNFENCING_FAILED")
+STONITH_UNFENCING_DEVICE_STATUS_FAILED = M(
+    "STONITH_UNFENCING_DEVICE_STATUS_FAILED"
+)
+STONITH_UNFENCING_SKIPPED_DEVICES_FENCED = M(
+    "STONITH_UNFENCING_SKIPPED_DEVICES_FENCED"
+)
+STONITH_RESTARTLESS_UPDATE_UNABLE_TO_PERFORM = M(
+    "STONITH_RESTARTLESS_UPDATE_UNABLE_TO_PERFORM"
+)
 SERVICE_COMMANDS_ON_NODES_STARTED = M("SERVICE_COMMANDS_ON_NODES_STARTED")
 SERVICE_COMMANDS_ON_NODES_SKIPPED = M("SERVICE_COMMANDS_ON_NODES_SKIPPED")
 SERVICE_COMMAND_ON_NODE_ERROR = M("SERVICE_COMMAND_ON_NODE_ERROR")
 SERVICE_COMMAND_ON_NODE_SUCCESS = M("SERVICE_COMMAND_ON_NODE_SUCCESS")
+SERVICE_UNABLE_TO_DETECT_INIT_SYSTEM = M("SERVICE_UNABLE_TO_DETECT_INIT_SYSTEM")
 SYSTEM_WILL_RESET = M("SYSTEM_WILL_RESET")
+# TODO: remove, use ADD_REMOVE reports
 TAG_ADD_REMOVE_IDS_DUPLICATION = M("TAG_ADD_REMOVE_IDS_DUPLICATION")
+# TODO: remove, use ADD_REMOVE reports
 TAG_ADJACENT_REFERENCE_ID_NOT_IN_THE_TAG = M(
     "TAG_ADJACENT_REFERENCE_ID_NOT_IN_THE_TAG"
 )
+# TODO: remove, use ADD_REMOVE reports
 TAG_CANNOT_ADD_AND_REMOVE_IDS_AT_THE_SAME_TIME = M(
     "TAG_CANNOT_ADD_AND_REMOVE_IDS_AT_THE_SAME_TIME"
 )
+# TODO: remove, use ADD_REMOVE reports
 TAG_CANNOT_ADD_REFERENCE_IDS_ALREADY_IN_THE_TAG = M(
     "TAG_CANNOT_ADD_REFERENCE_IDS_ALREADY_IN_THE_TAG"
 )
@@ -474,8 +501,11 @@ TAG_CANNOT_CONTAIN_ITSELF = M("TAG_CANNOT_CONTAIN_ITSELF")
 TAG_CANNOT_CREATE_EMPTY_TAG_NO_IDS_SPECIFIED = M(
     "TAG_CANNOT_CREATE_EMPTY_TAG_NO_IDS_SPECIFIED"
 )
+# TODO: remove, use ADD_REMOVE reports
 TAG_CANNOT_PUT_ID_NEXT_TO_ITSELF = M("TAG_CANNOT_PUT_ID_NEXT_TO_ITSELF")
+# TODO: remove, use ADD_REMOVE reports
 TAG_CANNOT_REMOVE_ADJACENT_ID = M("TAG_CANNOT_REMOVE_ADJACENT_ID")
+# TODO: remove, use ADD_REMOVE reports
 TAG_CANNOT_REMOVE_REFERENCES_WITHOUT_REMOVING_TAG = M(
     "TAG_CANNOT_REMOVE_REFERENCES_WITHOUT_REMOVING_TAG"
 )
@@ -485,12 +515,15 @@ TAG_CANNOT_REMOVE_TAG_REFERENCED_IN_CONSTRAINTS = M(
 TAG_CANNOT_REMOVE_TAGS_NO_TAGS_SPECIFIED = M(
     "TAG_CANNOT_REMOVE_TAGS_NO_TAGS_SPECIFIED"
 )
+# TODO: remove, use ADD_REMOVE reports
 TAG_CANNOT_SPECIFY_ADJACENT_ID_WITHOUT_IDS_TO_ADD = M(
     "TAG_CANNOT_SPECIFY_ADJACENT_ID_WITHOUT_IDS_TO_ADD"
 )
+# TODO: remove, use ADD_REMOVE reports
 TAG_CANNOT_UPDATE_TAG_NO_IDS_SPECIFIED = M(
     "TAG_CANNOT_UPDATE_TAG_NO_IDS_SPECIFIED"
 )
+# TODO: remove, use ADD_REMOVE reports
 TAG_IDS_NOT_IN_THE_TAG = M("TAG_IDS_NOT_IN_THE_TAG")
 TMP_FILE_WRITE = M("TMP_FILE_WRITE")
 UNABLE_TO_CONNECT_TO_ANY_REMAINING_NODE = M(
@@ -516,6 +549,7 @@ USE_COMMAND_NODE_ADD_GUEST = M("USE_COMMAND_NODE_ADD_GUEST")
 USE_COMMAND_NODE_REMOVE_GUEST = M("USE_COMMAND_NODE_REMOVE_GUEST")
 USING_DEFAULT_ADDRESS_FOR_HOST = M("USING_DEFAULT_ADDRESS_FOR_HOST")
 USING_DEFAULT_WATCHDOG = M("USING_DEFAULT_WATCHDOG")
+WAIT_FOR_IDLE_STARTED = M("WAIT_FOR_IDLE_STARTED")
 WAIT_FOR_IDLE_ERROR = M("WAIT_FOR_IDLE_ERROR")
 WAIT_FOR_IDLE_NOT_LIVE_CLUSTER = M("WAIT_FOR_IDLE_NOT_LIVE_CLUSTER")
 WAIT_FOR_IDLE_TIMED_OUT = M("WAIT_FOR_IDLE_TIMED_OUT")
