@@ -18,18 +18,21 @@ import pcs.cli.constraint_order.command as order_command
 from pcs.cli.constraint_ticket import command as ticket_command
 from pcs.cli.reports import process_library_reports
 from pcs.cli.reports.output import warn
-from pcs.common import reports
+from pcs.common import (
+    const,
+    pacemaker,
+    reports,
+)
 from pcs.common.reports import ReportItem
 from pcs.common.reports.constraints import (
     colocation as colocation_format,
     order as order_format,
 )
-from pcs.common.tools import Version
+from pcs.common.str_tools import format_list
 from pcs.lib.cib.constraint import resource_set
 from pcs.lib.cib.constraint.order import ATTRIB as order_attrib
 from pcs.lib.node import get_existing_nodes_names
 from pcs.lib.pacemaker.values import (
-    RESOURCE_ROLES,
     sanitize_id,
     SCORE_INFINITY,
 )
@@ -41,7 +44,7 @@ from pcs.lib.pacemaker.values import (
 OPTIONS_ACTION = resource_set.ATTRIB["action"]
 
 DEFAULT_ACTION = "start"
-DEFAULT_ROLE = "Started"
+DEFAULT_ROLE = const.PCMK_ROLE_STARTED
 
 OPTIONS_SYMMETRICAL = order_attrib["symmetrical"]
 OPTIONS_KIND = order_attrib["kind"]
@@ -71,7 +74,7 @@ class CrmRuleReturnCode(Enum):
 
 def constraint_location_cmd(lib, argv, modifiers):
     if not argv:
-        sub_cmd = "show"
+        sub_cmd = "config"
     else:
         sub_cmd = argv.pop(0)
 
@@ -82,6 +85,8 @@ def constraint_location_cmd(lib, argv, modifiers):
             location_remove(lib, argv, modifiers)
         elif sub_cmd == "show":
             location_show(lib, argv, modifiers)
+        elif sub_cmd == "config":
+            location_config_cmd(lib, argv, modifiers)
         elif len(argv) >= 2:
             if argv[0] == "rule":
                 location_rule(lib, [sub_cmd] + argv, modifiers)
@@ -97,7 +102,7 @@ def constraint_location_cmd(lib, argv, modifiers):
 
 def constraint_order_cmd(lib, argv, modifiers):
     if not argv:
-        sub_cmd = "show"
+        sub_cmd = "config"
     else:
         sub_cmd = argv.pop(0)
 
@@ -108,6 +113,8 @@ def constraint_order_cmd(lib, argv, modifiers):
             order_rm(lib, argv, modifiers)
         elif sub_cmd == "show":
             order_command.show(lib, argv, modifiers)
+        elif sub_cmd == "config":
+            order_command.config_cmd(lib, argv, modifiers)
         else:
             order_start(lib, [sub_cmd] + argv, modifiers)
     except CmdLineInputError as e:
@@ -115,16 +122,27 @@ def constraint_order_cmd(lib, argv, modifiers):
 
 
 def constraint_show(lib, argv, modifiers):
+    warn(
+        "This command is deprecated and will be removed. "
+        "Please use 'pcs constraint config' instead.",
+        stderr=True,
+    )
+    return constraint_config_cmd(lib, argv, modifiers)
+
+
+def constraint_config_cmd(lib, argv, modifiers):
     """
     Options:
       * --all - print expired constraints
       * -f - CIB file
       * --full
     """
-    location_show(lib, argv, modifiers)
-    order_command.show(lib, argv, modifiers.get_subset("--full", "-f"))
-    colocation_command.show(lib, argv, modifiers.get_subset("--full", "-f"))
-    ticket_command.show(lib, argv, modifiers.get_subset("--full", "-f"))
+    location_config_cmd(lib, argv, modifiers)
+    order_command.config_cmd(lib, argv, modifiers.get_subset("--full", "-f"))
+    colocation_command.config_cmd(
+        lib, argv, modifiers.get_subset("--full", "-f")
+    )
+    ticket_command.config_cmd(lib, argv, modifiers.get_subset("--full", "-f"))
 
 
 def colocation_rm(lib, argv, modifiers):
@@ -203,16 +221,6 @@ def colocation_add(lib, argv, modifiers):
         ]
         return score, arg_array
 
-    def _validate_and_prepare_role(role):
-        role_cleaned = role.lower().capitalize()
-        if role_cleaned not in RESOURCE_ROLES:
-            utils.err(
-                "invalid role value '{0}', allowed values are: '{1}'".format(
-                    role, "', '".join(RESOURCE_ROLES)
-                )
-            )
-        return role_cleaned
-
     del lib
     modifiers.ensure_only_supported("-f", "--force")
     if len(argv) < 3:
@@ -221,6 +229,23 @@ def colocation_add(lib, argv, modifiers):
     role1 = ""
     role2 = ""
 
+    cib_dom = utils.get_cib_dom()
+    new_roles_supported = utils.isCibVersionSatisfied(
+        cib_dom, const.PCMK_NEW_ROLES_CIB_VERSION
+    )
+
+    def _validate_and_prepare_role(role):
+        role_cleaned = role.lower().capitalize()
+        if role_cleaned not in const.PCMK_ROLES:
+            utils.err(
+                "invalid role value '{0}', allowed values are: {1}".format(
+                    role, format_list(const.PCMK_ROLES)
+                )
+            )
+        return pacemaker.role.get_value_for_cib(
+            role_cleaned, new_roles_supported
+        )
+
     if argv[2] == "with":
         role1 = _validate_and_prepare_role(argv.pop(0))
         resource1 = argv.pop(0)
@@ -254,7 +279,6 @@ def colocation_add(lib, argv, modifiers):
 
     score, nv_pairs = _parse_score_options(argv)
 
-    cib_dom = utils.get_cib_dom()
     _validate_constraint_resource(cib_dom, resource1)
     _validate_constraint_resource(cib_dom, resource2)
 
@@ -321,13 +345,23 @@ def colocation_find_duplicates(dom, constraint_el):
     """
     Commandline options: no options
     """
+    new_roles_supported = utils.isCibVersionSatisfied(
+        dom, const.PCMK_NEW_ROLES_CIB_VERSION
+    )
 
     def normalize(const_el):
         return (
             const_el.getAttribute("rsc"),
             const_el.getAttribute("with-rsc"),
-            const_el.getAttribute("rsc-role").capitalize() or DEFAULT_ROLE,
-            const_el.getAttribute("with-rsc-role").capitalize() or DEFAULT_ROLE,
+            pacemaker.role.get_value_for_cib(
+                const_el.getAttribute("rsc-role").capitalize() or DEFAULT_ROLE,
+                new_roles_supported,
+            ),
+            pacemaker.role.get_value_for_cib(
+                const_el.getAttribute("with-rsc-role").capitalize()
+                or DEFAULT_ROLE,
+                new_roles_supported,
+            ),
         )
 
     normalized_el = normalize(constraint_el)
@@ -551,7 +585,6 @@ def order_find_duplicates(dom, constraint_el):
     """
 
     def normalize(constraint_el):
-        # pylint: disable=line-too-long
         return (
             constraint_el.getAttribute("first"),
             constraint_el.getAttribute("then"),
@@ -570,8 +603,17 @@ def order_find_duplicates(dom, constraint_el):
     ]
 
 
-# Show the currently configured location constraints by node or resource
 def location_show(lib, argv, modifiers):
+    warn(
+        "This command is deprecated and will be removed. "
+        "Please use 'pcs constraint location config' instead.",
+        stderr=True,
+    )
+    return location_config_cmd(lib, argv, modifiers)
+
+
+# Show the currently configured location constraints by node or resource
+def location_config_cmd(lib, argv, modifiers):
     """
     Options:
       * --all - print expired constraints
@@ -886,7 +928,7 @@ def _verify_node_name(node, existing_nodes):
         report_list.append(
             ReportItem.error(
                 reports.messages.NodeNotFound(node),
-                force_code=reports.codes.FORCE_NODE_DOES_NOT_EXIST,
+                force_code=reports.codes.FORCE,
             )
         )
     return report_list
@@ -1031,7 +1073,7 @@ def location_add(lib, argv, modifiers, skip_score_and_node_check=False):
                 corosync_conf=lib_env.get_corosync_conf(),
                 cib=lib_env.get_cib(),
             )
-            report_list = _verify_node_name(node, existing_nodes)
+            report_list += _verify_node_name(node, existing_nodes)
             if report_list:
                 process_library_reports(report_list)
         _verify_score(score)
@@ -1040,16 +1082,7 @@ def location_add(lib, argv, modifiers, skip_score_and_node_check=False):
     if not id_valid:
         utils.err(id_error)
 
-    required_version = None
-    if [x for x in options if x[0] == "resource-discovery"]:
-        required_version = 2, 2, 0
-    if rsc_type == RESOURCE_TYPE_REGEXP:
-        required_version = 2, 6, 0
-
-    if required_version:
-        dom = utils.cluster_upgrade_to_version(required_version)
-    else:
-        dom = utils.get_cib_dom()
+    dom = utils.get_cib_dom()
 
     if rsc_type == RESOURCE_TYPE_RESOURCE:
         (
@@ -1171,20 +1204,13 @@ def location_rule(lib, argv, modifiers):
             rule_utils.TokenPreprocessor().run(rule_argv)
         )
         if rule_utils.has_node_attr_expr_with_type_integer(parsed_rule):
-            utils.checkAndUpgradeCIB(3, 5, 0)
+            utils.checkAndUpgradeCIB(
+                const.PCMK_RULES_NODE_ATTR_EXPR_WITH_INT_TYPE_CIB_VERSION
+            )
     except (rule_utils.ParserException, rule_utils.CibBuilderException):
         pass
 
-    required_version = None
-    if resource_discovery:
-        required_version = 2, 2, 0
-    if rsc_type == RESOURCE_TYPE_REGEXP:
-        required_version = 2, 6, 0
-
-    if required_version:
-        dom = utils.cluster_upgrade_to_version(required_version)
-    else:
-        dom = utils.get_cib_dom()
+    dom = utils.get_cib_dom()
 
     if rsc_type == RESOURCE_TYPE_RESOURCE:
         (
@@ -1228,7 +1254,7 @@ def location_rule(lib, argv, modifiers):
         lc.setAttribute("rsc-pattern", rsc_value)
 
     rule_utils.dom_rule_add(
-        lc, options, rule_argv, Version(*utils.getValidateWithVersion(cib))
+        lc, options, rule_argv, utils.getValidateWithVersion(cib)
     )
     location_rule_check_duplicates(constraints, lc, modifiers.get("--force"))
     utils.replace_cib_configuration(cib)
@@ -1581,7 +1607,9 @@ def constraint_rule(lib, argv, modifiers):
                 rule_utils.TokenPreprocessor().run(rule_argv)
             )
             if rule_utils.has_node_attr_expr_with_type_integer(parsed_rule):
-                utils.checkAndUpgradeCIB(3, 5, 0)
+                utils.checkAndUpgradeCIB(
+                    const.PCMK_RULES_NODE_ATTR_EXPR_WITH_INT_TYPE_CIB_VERSION
+                )
         except (rule_utils.ParserException, rule_utils.CibBuilderException):
             pass
         cib = utils.get_cib_dom()
@@ -1596,7 +1624,7 @@ def constraint_rule(lib, argv, modifiers):
             constraint,
             options,
             rule_argv,
-            Version(*utils.getValidateWithVersion(cib)),
+            utils.getValidateWithVersion(cib),
         )
         location_rule_check_duplicates(
             cib, constraint, modifiers.get("--force")
