@@ -1,10 +1,13 @@
 from typing import (
+    Iterable,
     Optional,
+    Sequence,
     Set,
     Tuple,
 )
 
 from lxml import etree
+from lxml.etree import _Element
 
 from pcs.common import reports
 from pcs.common.fencing_topology import (
@@ -23,18 +26,19 @@ from pcs.common.reports.item import ReportItem
 from pcs.lib.cib.stonith import is_stonith_resource
 from pcs.lib.cib.tools import find_unique_id
 from pcs.lib.errors import LibraryError
+from pcs.lib.pacemaker.state import _Element as StateElement
 from pcs.lib.pacemaker.values import sanitize_id, validate_id
 
 
 def add_level(
     reporter: ReportProcessor,
-    topology_el,
-    resources_el,
+    topology_el: _Element,
+    resources_el: _Element,
     level,
     target_type,
     target_value,
     devices,
-    cluster_status_nodes,
+    cluster_status_nodes: Sequence[StateElement],
     force_device=False,
     force_node=False,
 ):
@@ -92,22 +96,26 @@ def remove_all_levels(topology_el):
 
 
 def remove_levels_by_params(
-    topology_el,
+    topology_el: _Element,
     level=None,
-    target_type=None,
+    # TODO create a special type, so that it cannot accept any string
+    target_type: Optional[str] = None,
     target_value=None,
-    devices=None,
-    ignore_if_missing=False,
+    devices: Optional[Iterable[str]] = None,
+    # TODO remove, deprecated backward compatibility layer
+    ignore_if_missing: bool = False,
+    # TODO remove, deprecated backward compatibility layer
+    validate_device_ids: bool = True,
 ) -> ReportItemList:
     """
     Remove specified fencing level(s)
 
-    etree topology_el -- etree element to remove the levels from
+    topology_el -- etree element to remove the levels from
     int|string level -- level (index) of the fencing level to remove
-    constant target_type -- the removed fencing level target value type
+    target_type -- the removed fencing level target value type
     mixed target_value -- the removed fencing level target value
-    Iterable devices -- list of stonith devices of the removed fencing level
-    bool ignore_if_missing -- when True, do not report if level not found
+    devices -- list of stonith devices of the removed fencing level
+    ignore_if_missing -- when True, do not report if level not found
     """
     # Do not ever remove a fencing-topology element, even if it is empty. There
     # may be ACLs set in pacemaker which allow "write" for fencing-level
@@ -122,6 +130,12 @@ def remove_levels_by_params(
         if has_errors(report_list):
             return report_list
 
+    if validate_device_ids and devices is not None:
+        for device_id in devices:
+            validate_id(
+                device_id, description="stonith id", reporter=report_list
+            )
+
     level_el_list = _find_level_elements(
         topology_el, level, target_type, target_value, devices
     )
@@ -132,7 +146,10 @@ def remove_levels_by_params(
         report_list.append(
             ReportItem.error(
                 reports.messages.CibFencingLevelDoesNotExist(
-                    level, target_type, target_value, devices or []
+                    level,
+                    target_type,
+                    target_value,
+                    sorted(devices) if devices else [],
                 )
             )
         )
@@ -205,22 +222,26 @@ def export(topology_el):
     return export_levels
 
 
-def verify(topology_el, resources_el, cluster_status_nodes) -> ReportItemList:
+def verify(
+    topology_el: _Element,
+    resources_el: _Element,
+    cluster_status_nodes: Sequence[StateElement],
+) -> ReportItemList:
     """
     Check if all cluster nodes and stonith devices used in fencing levels exist.
 
-    etree topology_el -- etree element with fencing levels to check
-    etree resources_el -- etree element with resources definitions
-    Iterable cluster_status_nodes -- list of status of existing cluster nodes
+    topology_el -- fencing levels to check
+    resources_el -- resources definitions
+    cluster_status_nodes -- list of status of existing cluster nodes
     """
     report_list: ReportItemList = []
-    used_nodes = set()
+    used_nodes: Set[str] = set()
     used_devices: Set[str] = set()
 
     for level_el in topology_el.iterfind("fencing-level"):
-        used_devices.update(level_el.get("devices").split(","))
+        used_devices.update(str(level_el.get("devices", "")).split(","))
         if "target" in level_el.attrib:
-            used_nodes.add(level_el.get("target"))
+            used_nodes.add(str(level_el.get("target", "")))
 
     if used_devices:
         report_list.extend(
@@ -257,7 +278,10 @@ def _validate_level(level) -> Tuple[ReportItemList, Optional[int]]:
 
 
 def _validate_target(
-    cluster_status_nodes, target_type, target_value, force_node=False
+    cluster_status_nodes: Sequence[StateElement],
+    target_type,
+    target_value,
+    force_node=False,
 ) -> ReportItemList:
     return _validate_target_typewise(target_type) + _validate_target_valuewise(
         cluster_status_nodes, target_type, target_value, force_node
@@ -283,7 +307,7 @@ def _validate_target_typewise(target_type) -> ReportItemList:
 
 
 def _validate_target_valuewise(
-    cluster_status_nodes,
+    cluster_status_nodes: Sequence[StateElement],
     target_type,
     target_value,
     force_node=False,
@@ -308,7 +332,7 @@ def _validate_target_valuewise(
                         force_code=(
                             None
                             if force_node or not allow_force
-                            else report_codes.FORCE_NODE_DOES_NOT_EXIST
+                            else report_codes.FORCE
                         ),
                     ),
                     message=reports.messages.NodeNotFound(target_value),
@@ -318,7 +342,7 @@ def _validate_target_valuewise(
 
 
 def _validate_devices(
-    resources_el, devices, force_device=False, allow_force=True
+    resources_el: _Element, devices, force_device=False, allow_force=True
 ) -> ReportItemList:
     report_list: ReportItemList = []
     if not devices:
@@ -351,7 +375,7 @@ def _validate_devices(
                     force_code=(
                         None
                         if force_device or not allow_force
-                        else report_codes.FORCE_STONITH_RESOURCE_DOES_NOT_EXIST
+                        else report_codes.FORCE
                     ),
                 ),
                 message=reports.messages.StonithResourcesDoNotExist(
