@@ -1,24 +1,35 @@
+from typing import Iterable, Mapping, Optional
+
 from lxml import etree
 
-from pcs.common import report_codes
-from pcs.lib import reports
+from pcs.common import reports
+from pcs.common.reports import (
+    codes as report_codes,
+    ReportProcessor,
+)
+from pcs.common.reports.item import ReportItem
 from pcs.lib.cib.nvpair import (
     append_new_instance_attributes,
     append_new_meta_attributes,
     get_value,
     get_nvset_as_dict,
 )
-from pcs.lib.cib.resource.operations import(
+from pcs.lib.cib.resource.operations import (
     prepare as prepare_operations,
     create_operations,
 )
-from pcs.lib.cib.tools import does_id_exist, find_element_by_tag_and_id
+from pcs.lib.cib.tools import (
+    does_id_exist,
+    find_element_by_tag_and_id,
+    are_new_role_names_supported,
+)
 from pcs.lib.errors import LibraryError
 from pcs.lib.pacemaker.values import validate_id
 
 
 TAG = "primitive"
 
+
 def is_primitive(resource_el):
     return resource_el.tag == TAG
 
@@ -43,13 +54,20 @@ def find_primitives_by_agent(resources_section, resource_agent_obj):
 
 
 def create(
-    report_processor, resources_section, id_provider, resource_id,
+    report_processor: ReportProcessor,
+    resources_section,
+    id_provider,
+    resource_id,
     resource_agent,
-    raw_operation_list=None, meta_attributes=None, instance_attributes=None,
+    raw_operation_list: Optional[Iterable[Mapping[str, str]]] = None,
+    meta_attributes=None,
+    instance_attributes=None,
     allow_invalid_operation=False,
     allow_invalid_instance_attributes=False,
     use_default_operations=True,
-    resource_type="resource"
+    resource_type="resource",
+    # TODO remove this arg
+    do_not_report_instance_attribute_server_exists=False,
 ):
     # pylint: disable=too-many-arguments
     """
@@ -69,6 +87,8 @@ def create(
     bool use_default_operations is flag for completion operations with default
         actions specified in resource agent
     string resource_type -- describes the resource for reports
+    bool do_not_report_instance_attribute_server_exists -- dirty fix due to
+        suboptimal architecture, TODO: fix the architecture and remove the param
     """
     if raw_operation_list is None:
         raw_operation_list = []
@@ -78,7 +98,9 @@ def create(
         instance_attributes = {}
 
     if does_id_exist(resources_section, resource_id):
-        raise LibraryError(reports.id_already_exists(resource_id))
+        raise LibraryError(
+            ReportItem.error(reports.messages.IdAlreadyExists(resource_id))
+        )
     validate_id(resource_id, "{0} name".format(resource_type))
 
     operation_list = prepare_operations(
@@ -87,18 +109,23 @@ def create(
         resource_agent.get_cib_default_actions(
             necessary_only=not use_default_operations
         ),
-        [operation["name"] for operation in resource_agent.get_actions()],
+        [operation.name for operation in resource_agent.get_actions()],
+        are_new_role_names_supported(resources_section),
         allow_invalid=allow_invalid_operation,
     )
 
-    report_processor.process_list(
+    if report_processor.report_list(
         validate_resource_instance_attributes_create(
             resource_agent,
             instance_attributes,
             resources_section,
             force=allow_invalid_instance_attributes,
+            do_not_report_instance_attribute_server_exists=(
+                do_not_report_instance_attribute_server_exists
+            ),
         )
-    )
+    ).has_errors:
+        raise LibraryError()
 
     return append_new(
         resources_section,
@@ -109,14 +136,20 @@ def create(
         resource_agent.get_type(),
         instance_attributes=instance_attributes,
         meta_attributes=meta_attributes,
-        operation_list=operation_list
+        operation_list=operation_list,
     )
 
+
 def append_new(
-    resources_section, id_provider, resource_id, standard, provider, agent_type,
+    resources_section,
+    id_provider,
+    resource_id,
+    standard,
+    provider,
+    agent_type,
     instance_attributes=None,
     meta_attributes=None,
-    operation_list=None
+    operation_list=None,
 ):
     # pylint:disable=too-many-arguments
     """
@@ -144,39 +177,33 @@ def append_new(
 
     if instance_attributes:
         append_new_instance_attributes(
-            primitive_element,
-            instance_attributes,
-            id_provider
+            primitive_element, instance_attributes, id_provider
         )
 
     if meta_attributes:
         append_new_meta_attributes(
-            primitive_element,
-            meta_attributes,
-            id_provider
+            primitive_element, meta_attributes, id_provider
         )
 
     create_operations(
-        primitive_element,
-        id_provider,
-        operation_list if operation_list else []
+        primitive_element, id_provider, operation_list if operation_list else []
     )
 
     return primitive_element
 
 
 def validate_unique_instance_attributes(
-    resource_agent, instance_attributes, resources_section,
-    resource_id=None, force=False
+    resource_agent,
+    instance_attributes,
+    resources_section,
+    resource_id=None,
+    force=False,
 ):
     report_list = []
-    report_creator = reports.get_problem_creator(
-        report_codes.FORCE_OPTIONS, force
-    )
     ra_unique_attributes = [
-        param["name"]
-        for param in resource_agent.get_parameters()
-        if param["unique"]
+        param.name
+        for param in resource_agent.get_full_info().parameters
+        if param.unique
     ]
     same_agent_resources = find_primitives_by_agent(
         resources_section, resource_agent
@@ -189,57 +216,66 @@ def validate_unique_instance_attributes(
             for primitive in same_agent_resources
             if (
                 primitive.get("id") != resource_id
-                and
-                instance_attributes[attr] == get_value(
-                    "instance_attributes", primitive, attr
-                )
+                and instance_attributes[attr]
+                == get_value("instance_attributes", primitive, attr)
             )
         }
         if conflicting_resources:
             report_list.append(
-                report_creator(
-                    reports.resource_instance_attr_value_not_unique,
-                    attr,
-                    instance_attributes[attr],
-                    resource_agent.get_name(),
-                    conflicting_resources,
+                ReportItem(
+                    severity=reports.item.get_severity(
+                        report_codes.FORCE,
+                        force,
+                    ),
+                    message=reports.messages.ResourceInstanceAttrValueNotUnique(
+                        attr,
+                        instance_attributes[attr],
+                        resource_agent.get_name_info().name,
+                        sorted(conflicting_resources),
+                    ),
                 )
             )
     return report_list
 
 
 def validate_resource_instance_attributes_create(
-    resource_agent, instance_attributes, resources_section, force=False
+    resource_agent,
+    instance_attributes,
+    resources_section,
+    force=False,
+    do_not_report_instance_attribute_server_exists=False,
 ):
-    return (
-        resource_agent.validate_parameters_create(
-            instance_attributes, force=force,
-        )
-        +
-        validate_unique_instance_attributes(
-            resource_agent, instance_attributes, resources_section, force=force
-        )
+    return resource_agent.validate_parameters_create(
+        instance_attributes,
+        force=force,
+        do_not_report_instance_attribute_server_exists=(
+            do_not_report_instance_attribute_server_exists
+        ),
+    ) + validate_unique_instance_attributes(
+        resource_agent, instance_attributes, resources_section, force=force
     )
 
 
 def validate_resource_instance_attributes_update(
-    resource_agent, instance_attributes, resource_id, resources_section,
-    force=False
+    resource_agent,
+    instance_attributes,
+    resource_id,
+    resources_section,
+    force=False,
 ):
-    return (
-        resource_agent.validate_parameters_update(
-            get_nvset_as_dict(
-                "instance_attributes",
-                find_element_by_tag_and_id(
-                    "primitive", resources_section, resource_id
-                )
+    return resource_agent.validate_parameters_update(
+        get_nvset_as_dict(
+            "instance_attributes",
+            find_element_by_tag_and_id(
+                "primitive", resources_section, resource_id
             ),
-            instance_attributes,
-            force=force,
-        )
-        +
-        validate_unique_instance_attributes(
-            resource_agent, instance_attributes, resources_section,
-            resource_id=resource_id, force=force,
-        )
+        ),
+        instance_attributes,
+        force=force,
+    ) + validate_unique_instance_attributes(
+        resource_agent,
+        instance_attributes,
+        resources_section,
+        resource_id=resource_id,
+        force=force,
     )
