@@ -83,13 +83,11 @@ from pcs.lib.env import LibraryEnvironment
 from pcs.lib.file.instance import FileInstance
 from pcs.lib.node import get_existing_nodes_names
 from pcs.lib.errors import LibraryError
-from pcs.lib.external import is_service_running
 from pcs.lib.interface.config import ParserErrorException
 from pcs.lib.pacemaker.live import (
     get_cib,
     get_cib_xml,
     get_cib_xml_cmd_results,
-    get_cluster_status_xml,
     remove_node,
     verify as verify_cmd,
 )
@@ -126,7 +124,7 @@ def node_clear(
         if env.report_processor.report(
             ReportItem(
                 severity=reports.item.get_severity(
-                    report_codes.FORCE_CLEAR_CLUSTER_NODE,
+                    report_codes.FORCE,
                     allow_clear_cluster_node,
                 ),
                 message=reports.messages.NodeToClearIsStillInCluster(node_name),
@@ -175,7 +173,7 @@ def verify(env: LibraryEnvironment, verbose=False):
         fencing_topology.verify(
             get_fencing_topology(cib),
             get_resources(cib),
-            ClusterState(get_cluster_status_xml(runner)).node_section.nodes,
+            ClusterState(env.get_cluster_state()).node_section.nodes,
         )
     )
     if env.report_processor.has_errors:
@@ -819,7 +817,7 @@ def get_corosync_conf_struct(env: LibraryEnvironment) -> CorosyncConfDto:
 
 
 def add_nodes(
-    env,
+    env: LibraryEnvironment,
     nodes,
     wait=False,
     start=False,
@@ -865,7 +863,7 @@ def add_nodes(
 
     report_processor = env.report_processor
     target_factory = env.get_node_target_factory()
-    is_sbd_enabled = sbd.is_sbd_enabled(env.cmd_runner())
+    is_sbd_enabled = sbd.is_sbd_enabled(env.service_manager)
     corosync_conf = env.get_corosync_conf()
     corosync_node_options = {"name", "addrs"}
     sbd_node_options = {"devices", "watchdog"}
@@ -977,9 +975,7 @@ def add_nodes(
         cib_nodes = []
         report_processor.report(
             ReportItem(
-                reports.item.get_severity(
-                    report_codes.FORCE_LOAD_NODES_FROM_CIB, force
-                ),
+                reports.item.get_severity(report_codes.FORCE, force),
                 reports.messages.CibLoadErrorGetNodesForValidation(),
             )
         )
@@ -1060,7 +1056,7 @@ def add_nodes(
 
     # Validate existing cluster nodes status
     atb_has_to_be_enabled = sbd.atb_has_to_be_enabled(
-        env.cmd_runner(), corosync_conf, len(new_nodes)
+        env.service_manager, corosync_conf, len(new_nodes)
     )
     if atb_has_to_be_enabled:
         report_processor.report(
@@ -1191,16 +1187,17 @@ def add_nodes(
 
     # distribute corosync and pacemaker authkeys and other config files
     files_action = {}
-    severity = reports.item.get_severity(
-        reports.codes.SKIP_FILE_DISTRIBUTION_ERRORS, force
-    )
+    severity = reports.item.get_severity(reports.codes.FORCE, force)
     if os.path.isfile(settings.corosync_authkey_file):
         try:
-            files_action.update(
-                node_communication_format.corosync_authkey_file(
-                    open(settings.corosync_authkey_file, "rb").read()
+            with open(
+                settings.corosync_authkey_file, "rb"
+            ) as corosync_authkey_file:
+                files_action.update(
+                    node_communication_format.corosync_authkey_file(
+                        corosync_authkey_file.read()
+                    )
                 )
-            )
         except EnvironmentError as e:
             report_processor.report(
                 ReportItem(
@@ -1216,11 +1213,14 @@ def add_nodes(
 
     if os.path.isfile(settings.pacemaker_authkey_file):
         try:
-            files_action.update(
-                node_communication_format.pcmk_authkey_file(
-                    open(settings.pacemaker_authkey_file, "rb").read()
+            with open(
+                settings.pacemaker_authkey_file, "rb"
+            ) as pcmk_authkey_file:
+                files_action.update(
+                    node_communication_format.pcmk_authkey_file(
+                        pcmk_authkey_file.read()
+                    )
                 )
-            )
         except EnvironmentError as e:
             report_processor.report(
                 ReportItem(
@@ -1236,11 +1236,14 @@ def add_nodes(
 
     if os.path.isfile(settings.pcsd_dr_config_location):
         try:
-            files_action.update(
-                node_communication_format.pcs_dr_config_file(
-                    open(settings.pcsd_dr_config_location, "rb").read()
+            with open(
+                settings.pcsd_dr_config_location, "rb"
+            ) as pcs_dr_config_file:
+                files_action.update(
+                    node_communication_format.pcs_dr_config_file(
+                        pcs_dr_config_file.read()
+                    )
                 )
-            )
         except EnvironmentError as e:
             report_processor.report(
                 ReportItem(
@@ -1259,11 +1262,14 @@ def add_nodes(
     # syncronization of configs will be introduced.
     if os.path.isfile(settings.pcsd_settings_conf_location):
         try:
-            files_action.update(
-                node_communication_format.pcs_settings_conf_file(
-                    open(settings.pcsd_settings_conf_location, "r").read()
+            with open(
+                settings.pcsd_settings_conf_location, "r"
+            ) as pcs_settings_conf_file:
+                files_action.update(
+                    node_communication_format.pcs_settings_conf_file(
+                        pcs_settings_conf_file.read()
+                    )
                 )
-            )
         except EnvironmentError as e:
             report_processor.report(
                 ReportItem(
@@ -1472,9 +1478,7 @@ def _host_check_cluster_setup(
     required_as_stopped_service_list = required_service_list + [
         "pacemaker_remote"
     ]
-    severity = reports.item.get_severity(
-        report_codes.FORCE_ALREADY_IN_CLUSTER, force
-    )
+    severity = reports.item.get_severity(report_codes.FORCE, force)
     cluster_exists_on_nodes = False
     for host_name, host_info in host_info_dict.items():
         try:
@@ -1539,7 +1543,7 @@ def _host_check_cluster_setup(
         report_list.append(
             ReportItem(
                 severity=reports.item.ReportItemSeverity.error(
-                    report_codes.FORCE_ALREADY_IN_CLUSTER
+                    report_codes.FORCE
                 ),
                 message=reports.messages.ClusterWillBeDestroyed(),
             )
@@ -1683,7 +1687,9 @@ def _verify_corosync_conf(corosync_conf_facade):
 
 
 def remove_nodes(
-    env, node_list, force_flags: Container[reports.types.ForceCode] = ()
+    env: LibraryEnvironment,
+    node_list,
+    force_flags: Container[reports.types.ForceCode] = (),
 ):
     # pylint: disable=too-many-locals, too-many-branches, too-many-statements
     """
@@ -1787,7 +1793,7 @@ def remove_nodes(
             )
 
     atb_has_to_be_enabled = sbd.atb_has_to_be_enabled(
-        env.cmd_runner(), corosync_conf, -len(node_list)
+        env.service_manager, corosync_conf, -len(node_list)
     )
     if atb_has_to_be_enabled:
         report_processor.report(
@@ -1818,7 +1824,7 @@ def remove_nodes(
                 report_processor.report(
                     ReportItem(
                         severity=reports.item.get_severity(
-                            report_codes.FORCE_QUORUM_LOSS,
+                            report_codes.FORCE,
                             force_quorum_loss,
                         ),
                         message=reports.messages.CorosyncQuorumWillBeLost(),
@@ -1828,7 +1834,7 @@ def remove_nodes(
             report_processor.report(
                 ReportItem(
                     severity=reports.item.get_severity(
-                        report_codes.FORCE_QUORUM_LOSS,
+                        report_codes.FORCE,
                         force_quorum_loss,
                     ),
                     message=reports.messages.CorosyncQuorumLossUnableToCheck(),
@@ -1894,7 +1900,7 @@ def remove_nodes_from_cib(env: LibraryEnvironment, node_list):
             )
         )
 
-    if is_service_running(env.cmd_runner(), "pacemaker"):
+    if env.service_manager.is_running("pacemaker"):
         for node in node_list:
             # this may raise a LibraryError
             # NOTE: crm_node cannot remove multiple nodes at once
@@ -1966,9 +1972,7 @@ def add_link(
         cib_nodes = []
         report_processor.report(
             ReportItem(
-                reports.item.get_severity(
-                    report_codes.FORCE_LOAD_NODES_FROM_CIB, force
-                ),
+                reports.item.get_severity(report_codes.FORCE, force),
                 reports.messages.CibLoadErrorGetNodesForValidation(),
             )
         )
