@@ -23,7 +23,7 @@ class GetOnlineTargets(
     AllSameDataMixin, AllAtOnceStrategyMixin, RunRemotelyBase
 ):
     def __init__(self, report_processor, ignore_offline_targets=False):
-        super(GetOnlineTargets, self).__init__(report_processor)
+        super().__init__(report_processor)
         self._ignore_offline_targets = ignore_offline_targets
         self._online_target_list = []
 
@@ -81,7 +81,7 @@ class CheckReachability(
 
 class CheckAuth(AllSameDataMixin, AllAtOnceStrategyMixin, RunRemotelyBase):
     def __init__(self, report_processor):
-        super(CheckAuth, self).__init__(report_processor)
+        super().__init__(report_processor)
         self._not_authorized_host_name_list = []
 
     def _get_request_data(self):
@@ -156,7 +156,7 @@ class RunActionBase(
         skip_offline_targets=False,
         allow_fails=False,
     ):
-        super(RunActionBase, self).__init__(report_processor)
+        super().__init__(report_processor)
         self._set_skip_offline(skip_offline_targets)
         self._init_properties()
         self._action_error_force = _force(self._force_code, allow_fails)
@@ -217,7 +217,8 @@ class RunActionBase(
             if self._is_success(item_response):
                 # only success process individually
                 report = self._success_report(
-                    target.label, self._action_key_to_report(key),
+                    target.label,
+                    self._action_key_to_report(key),
                 )
             else:
                 report = self._failure_report(
@@ -250,7 +251,7 @@ class ServiceAction(RunActionBase):
     def _init_properties(self):
         self._request_url = "remote/manage_services"
         self._response_key = "actions"
-        self._force_code = report_codes.SKIP_ACTION_ON_NODES_ERRORS
+        self._force_code = report_codes.FORCE
         self._code_message_map = {"fail": "Operation failed."}
 
     def _failure_report(
@@ -283,13 +284,13 @@ class FileActionBase(RunActionBase):
     # pylint: disable=abstract-method, too-many-ancestors
     def _init_properties(self):
         self._response_key = "files"
-        self._force_code = report_codes.SKIP_FILE_DISTRIBUTION_ERRORS
+        self._force_code = report_codes.FORCE
 
 
 class DistributeFiles(FileActionBase):
     # pylint: disable=too-many-ancestors
     def _init_properties(self):
-        super(DistributeFiles, self)._init_properties()
+        super()._init_properties()
         self._request_url = "remote/put_file"
         self._code_message_map = {"conflict": "File already exists"}
 
@@ -333,7 +334,7 @@ class DistributeFilesWithoutForces(DistributeFiles):
 class RemoveFiles(FileActionBase):
     # pylint: disable=too-many-ancestors
     def _init_properties(self):
-        super(RemoveFiles, self)._init_properties()
+        super()._init_properties()
         self._request_url = "remote/remove_file"
         self._code_message_map = {}
 
@@ -490,7 +491,9 @@ class UpdateKnownHosts(
 
 
 class RemoveNodesFromCib(
-    AllSameDataMixin, AllAtOnceStrategyMixin, RunRemotelyBase,
+    AllSameDataMixin,
+    AllAtOnceStrategyMixin,
+    RunRemotelyBase,
 ):
     def __init__(self, report_processor, nodes_to_remove):
         super().__init__(report_processor)
@@ -553,5 +556,11 @@ class SendPcsdSslCertAndKey(
 
 def _force(force_code, is_forced):
     if is_forced:
-        return dict(severity=ReportItemSeverity.WARNING, forceable=None,)
-    return dict(severity=ReportItemSeverity.ERROR, forceable=force_code,)
+        return dict(
+            severity=ReportItemSeverity.WARNING,
+            forceable=None,
+        )
+    return dict(
+        severity=ReportItemSeverity.ERROR,
+        forceable=force_code,
+    )
