@@ -1,9 +1,12 @@
 from typing import (
-    Optional,
     cast,
+    Mapping,
+    Optional,
+    Union,
 )
 
 from lxml.etree import _Element
+from pcs.common.services.interfaces import ServiceManagerInterface
 
 from pcs.common import file_type_codes
 from pcs.common import reports
@@ -12,7 +15,6 @@ from pcs.common.reports import ReportProcessor
 from pcs.common.reports.item import ReportItem
 from pcs.common.tools import Version
 from pcs.lib.booth.env import BoothEnv
-from pcs.lib.cib.tools import get_cib_crm_feature_set
 from pcs.lib.dr.env import DrEnv
 from pcs.lib.node import get_existing_nodes_names
 from pcs.lib.communication import qdevice
@@ -43,17 +45,35 @@ from pcs.lib.pacemaker.live import (
     ensure_cib_version,
     get_cib,
     get_cib_xml,
-    get_cluster_status_xml,
+    get_cluster_status_dom,
     push_cib_diff_xml,
     replace_cib_configuration,
     wait_for_idle,
 )
-from pcs.lib.pacemaker.state import get_cluster_state_dom
 from pcs.lib.pacemaker.values import get_valid_timeout_seconds
-from pcs.lib.tools import write_tmpfile
+from pcs.lib.services import get_service_manager
+from pcs.lib.tools import create_tmp_cib
 from pcs.lib.xml_tools import etree_to_str
 
-MIN_FEATURE_SET_VERSION_FOR_DIFF = Version(3, 0, 9)
+WaitType = Union[None, bool, int, str]
+
+
+def _wait_type_to_int(wait: WaitType) -> int:
+    """
+    Convert WaitType to int.
+
+    wait -- wait value. If False, it means wait is disabled, therefore -1
+        is returned. If None, wait is enabled without timeout, therefore 0
+        is returned. If string representing timeout or positive integer,
+        wait is enabled with timeout, therefore number of seconds is
+        retuned. Otherwise a LibraryError is raised.
+    """
+    if wait is False:
+        return -1
+    wait_timeout = get_valid_timeout_seconds(wait)
+    if wait_timeout is None:
+        return 0
+    return wait_timeout
 
 
 class LibraryEnvironment:
@@ -88,7 +108,6 @@ class LibraryEnvironment:
         self._cib_upgrade_reported = False
         self._cib_data_tmp_file = None
         self.__loaded_cib_diff_source = None
-        self.__loaded_cib_diff_source_feature_set = None
         self.__loaded_cib_to_modify = None
         self._communicator_factory = NodeCommunicatorFactory(
             LibCommunicatorLogger(self.logger, self.report_processor),
@@ -98,8 +117,7 @@ class LibraryEnvironment:
         )
         self.__loaded_booth_env = None
         self.__loaded_dr_env = None
-
-        self.__timeout_cache = {}
+        self.__service_manager: Optional[ServiceManagerInterface] = None
 
     @property
     def logger(self):
@@ -166,9 +184,6 @@ class LibraryEnvironment:
                         )
                     self._cib_upgrade_reported = True
 
-        self.__loaded_cib_diff_source_feature_set = get_cib_crm_feature_set(
-            self.__loaded_cib_to_modify, none_if_missing=True
-        ) or Version(0, 0, 0)
         return self.__loaded_cib_to_modify
 
     @property
@@ -178,83 +193,74 @@ class LibraryEnvironment:
         return self.__loaded_cib_to_modify
 
     def get_cluster_state(self):
-        return get_cluster_state_dom(get_cluster_status_xml(self.cmd_runner()))
+        return get_cluster_status_dom(self.cmd_runner())
 
-    def get_wait_timeout(self, wait):
-        if wait is False:
-            return False
-
-        if wait not in self.__timeout_cache:
-            if not self.is_cib_live:
-                raise LibraryError(
-                    ReportItem.error(
-                        reports.messages.WaitForIdleNotLiveCluster()
-                    )
-                )
-            self.__timeout_cache[wait] = get_valid_timeout_seconds(wait)
-        return self.__timeout_cache[wait]
-
-    def ensure_wait_satisfiable(self, wait):
+    def wait_for_idle(self, timeout: int = 0) -> None:
         """
+        Wait for the cluster to settle down.
+
+        timeout -- timeout in seconds, if less than 0 wait will be skipped, if 0
+            wait indefinitely
+        """
+        if timeout < 0:
+            # timeout is turned off
+            return
+        self.report_processor.report(
+            ReportItem.info(reports.messages.WaitForIdleStarted(timeout))
+        )
+        wait_for_idle(self.cmd_runner(), timeout)
+
+    def ensure_wait_satisfiable(self, wait: WaitType) -> int:
+        """
+        Convert WaitType to int. Returns wait timeout in seconds.
         Raise when wait is not supported or when wait is not valid wait value.
 
-        mixed wait can be False when waiting is not required or valid timeout
+        wait -- wait value. If False, it means wait is disabled, therefore -1
+            is returned. If None, wait is enabled without timeout, therefore 0
+            is returned. If string representing timeout or positive integer,
+            wait is enabled with timeout, therefore number of seconds is
+            returned. Otherwise a LibraryError is raised.
         """
-        self.get_wait_timeout(wait)
+        timeout = _wait_type_to_int(wait)
+        self._ensure_wait_satisfiable(timeout)
+        return timeout
 
-    def push_cib(self, custom_cib=None, wait=False):
+    def _ensure_wait_satisfiable(self, wait_timeout: int) -> None:
+        if wait_timeout >= 0 and not self.is_cib_live:
+            raise LibraryError(
+                ReportItem.error(reports.messages.WaitForIdleNotLiveCluster())
+            )
+
+    def push_cib(self, custom_cib=None, wait_timeout: int = -1):
         """
         Push previously loaded instance of CIB or a custom CIB
 
         etree custom_cib -- push a custom CIB instead of a loaded instance
             (allows to push an externally provided CIB and replace the one in
             the cluster completely)
-        mixed wait -- how many seconds to wait for pacemaker to process new CIB
-            or False for not waiting at all
+        wait_timeout -- wait timeout in seconds, if less than 0 wait will be
+            skipped, if 0 wait indefinitely
         """
+        self._ensure_wait_satisfiable(wait_timeout)
         if custom_cib is not None:
             if self.__loaded_cib_diff_source is not None:
                 raise AssertionError(
                     "CIB has been loaded, cannot push custom CIB"
                 )
-            return self.__push_cib_full(custom_cib, wait)
+            return self.__push_cib_full(custom_cib, wait_timeout)
         if self.__loaded_cib_diff_source is None:
             raise AssertionError("CIB has not been loaded")
-        # Push by diff works with crm_feature_set > 3.0.8, see
-        # https://bugzilla.redhat.com/show_bug.cgi?id=1488044 for details. We
-        # only check the version if a CIB has been loaded, otherwise the push
-        # fails anyway. By my testing it seems that only the source CIB's
-        # version matters.
-        if (
-            self.__loaded_cib_diff_source_feature_set
-            < MIN_FEATURE_SET_VERSION_FOR_DIFF
-        ):
-            current_set = str(
-                self.__loaded_cib_diff_source_feature_set.normalize()
-            )
-            self.report_processor.report(
-                ReportItem.warning(
-                    reports.messages.CibPushForcedFullDueToCrmFeatureSet(
-                        str(MIN_FEATURE_SET_VERSION_FOR_DIFF.normalize()),
-                        current_set,
-                    )
-                )
-            )
-            return self.__push_cib_full(self.__loaded_cib_to_modify, wait=wait)
-        return self.__push_cib_diff(wait=wait)
+        return self.__push_cib_diff(wait_timeout)
 
-    def __push_cib_full(self, cib_to_push, wait=False):
-        cmd_runner = self.cmd_runner()
+    def __push_cib_full(self, cib_to_push, wait_timeout: int):
         self.__do_push_cib(
-            cmd_runner,
-            lambda: replace_cib_configuration(cmd_runner, cib_to_push),
-            wait,
+            lambda: replace_cib_configuration(self.cmd_runner(), cib_to_push),
+            wait_timeout,
         )
 
-    def __push_cib_diff(self, wait=False):
-        cmd_runner = self.cmd_runner()
+    def __push_cib_diff(self, wait_timeout: int):
         self.__do_push_cib(
-            cmd_runner, lambda: self.__main_push_cib_diff(cmd_runner), wait
+            lambda: self.__main_push_cib_diff(self.cmd_runner()), wait_timeout
         )
 
     def __main_push_cib_diff(self, cmd_runner):
@@ -267,15 +273,13 @@ class LibraryEnvironment:
         if cib_diff_xml:
             push_cib_diff_xml(cmd_runner, cib_diff_xml)
 
-    def __do_push_cib(self, cmd_runner, push_strategy, wait):
-        timeout = self.get_wait_timeout(wait)
+    def __do_push_cib(self, push_strategy, wait_timeout: int):
         push_strategy()
         self._cib_upgrade_reported = False
         self.__loaded_cib_diff_source = None
-        self.__loaded_cib_diff_source_feature_set = None
         self.__loaded_cib_to_modify = None
-        if self.is_cib_live and timeout is not False:
-            wait_for_idle(cmd_runner, timeout)
+        if self.is_cib_live:
+            self.wait_for_idle(wait_timeout)
 
     @property
     def is_cib_live(self):
@@ -427,7 +431,9 @@ class LibraryEnvironment:
     def is_corosync_conf_live(self):
         return self._corosync_conf_data is None
 
-    def cmd_runner(self) -> CommandRunner:
+    def cmd_runner(
+        self, env: Optional[Mapping[str, str]] = None
+    ) -> CommandRunner:
         runner_env = {
             # make sure to get output of external processes in English and ASCII
             "LC_ALL": "C",
@@ -441,24 +447,14 @@ class LibraryEnvironment:
             # This way every called pacemaker tool can access the CIB and we
             # don't need to take care of it every time the runner is called.
             if not self._cib_data_tmp_file:
-                try:
-                    cib_data = self._cib_data
-                    self._cib_data_tmp_file = write_tmpfile(cib_data)
-                    self.report_processor.report(
-                        ReportItem.debug(
-                            reports.messages.TmpFileWrite(
-                                self._cib_data_tmp_file.name, cib_data
-                            )
-                        )
-                    )
-                except EnvironmentError as e:
-                    raise LibraryError(
-                        ReportItem.error(
-                            reports.messages.CibSaveTmpError(str(e))
-                        )
-                    ) from e
+                self._cib_data_tmp_file = create_tmp_cib(
+                    self.report_processor, self._cib_data
+                )
             runner_env["CIB_file"] = self._cib_data_tmp_file.name
 
+        if env:
+            runner_env.update(env)
+
         return CommandRunner(self.logger, self.report_processor, runner_env)
 
     @property
@@ -503,3 +499,14 @@ class LibraryEnvironment:
         if self.__loaded_dr_env is None:
             self.__loaded_dr_env = DrEnv()
         return self.__loaded_dr_env
+
+    def _get_service_manager(self) -> ServiceManagerInterface:
+        if self.__service_manager is None:
+            self.__service_manager = get_service_manager(
+                self.cmd_runner(), self.report_processor
+            )
+        return self.__service_manager
+
+    @property
+    def service_manager(self) -> ServiceManagerInterface:
+        return self._get_service_manager()
