@@ -1,6 +1,8 @@
 import os.path
 import re
 from typing import (
+    cast,
+    Dict,
     Iterable,
     List,
     Optional,
@@ -24,8 +26,12 @@ from pcs.common.types import CibRuleInEffectStatus
 from pcs.lib.cib.tools import get_pacemaker_version_by_which_cib_was_validated
 from pcs.lib.errors import LibraryError
 from pcs.lib.external import CommandRunner
+from pcs.lib.pacemaker import api_result
 from pcs.lib.pacemaker.state import ClusterState
-from pcs.lib.tools import write_tmpfile
+from pcs.lib.tools import (
+    get_tmp_cib,
+    get_tmp_file,
+)
 from pcs.lib.xml_tools import etree_to_str
 
 
@@ -46,22 +52,78 @@ class FenceHistoryCommandErrorException(Exception):
 ### status
 
 
-def get_cluster_status_xml(runner):
-    stdout, stderr, retval = runner.run(
-        [__exec("crm_mon"), "--one-shot", "--as-xml", "--inactive"]
+def get_cluster_status_dom(runner: CommandRunner) -> _Element:
+    def validate_dom(dom, rng):
+        try:
+            if os.path.isfile(rng):
+                etree.RelaxNG(file=rng).assertValid(dom)
+            return dom
+        except etree.DocumentInvalid as e:
+            raise LibraryError(
+                ReportItem.error(reports.messages.BadClusterStateFormat())
+            ) from e
+
+    def get_dom(xml, rng):
+        try:
+            return validate_dom(xml_fromstring(xml), rng)
+        except etree.XMLSyntaxError as e:
+            raise LibraryError(
+                ReportItem.error(reports.messages.BadClusterStateFormat())
+            ) from e
+
+    pcmk_supports_new_format = _is_in_pcmk_tool_help(
+        runner, "crm_mon", "--output-as="
     )
+    format_option = (
+        ["--output-as", "xml"] if pcmk_supports_new_format else ["--as-xml"]
+    )
+
+    stdout, stderr, retval = runner.run(
+        [__exec("crm_mon"), "--one-shot", "--inactive"] + format_option
+    )
+
     if retval != 0:
         klass = (
             PacemakerNotConnectedException
             if retval == __EXITCODE_NOT_CONNECTED
             else LibraryError
         )
-        raise klass(
-            ReportItem.error(
-                reports.messages.CrmMonError(join_multilines([stderr, stdout]))
-            )
-        )
-    return stdout
+        if pcmk_supports_new_format:
+            # Try to process the output as an XML. If it cannot be parsed, then
+            # process it as a plaintext. If it is an XML but it doesn't conform
+            # to the schema, raise an error (don't catch etree.DocumentInvalid
+            # exception).
+            try:
+                status = get_status_from_api_result(
+                    validate_dom(
+                        xml_fromstring(stdout),
+                        settings.pacemaker_api_result_schema,
+                    )
+                )
+                message = join_multilines(
+                    [status.message] + list(status.errors)
+                )
+            except etree.XMLSyntaxError:
+                message = join_multilines([stderr, stdout])
+        else:
+            message = join_multilines([stderr, stdout])
+        raise klass(ReportItem.error(reports.messages.CrmMonError(message)))
+
+    if pcmk_supports_new_format:
+        return get_dom(stdout, settings.pacemaker_api_result_schema)
+
+    dom = get_dom(stdout, settings.crm_mon_schema)
+    new_format_dom = etree.Element(
+        "pacemaker-result",
+        {
+            "api-version": "2.3",
+            "request": "crm_mon --as-xml",
+        },
+    )
+    for child in dom.getchildren():
+        new_format_dom.append(child)
+    etree.SubElement(new_format_dom, "status", {"code": "0", "message": "OK"})
+    return validate_dom(new_format_dom, settings.pacemaker_api_result_schema)
 
 
 def get_cluster_status_text(
@@ -218,51 +280,34 @@ def push_cib_diff_xml(runner, cib_diff_xml):
 def diff_cibs_xml(
     runner: CommandRunner,
     reporter: ReportProcessor,
-    cib_old_xml,
-    cib_new_xml,
-):
+    cib_old_xml: str,
+    cib_new_xml: str,
+) -> str:
     """
     Return xml diff of two CIBs
 
     runner
     reporter
-    string cib_old_xml -- original CIB
-    string cib_new_xml -- modified CIB
+    cib_old_xml -- original CIB
+    cib_new_xml -- modified CIB
     """
-    try:
-        cib_old_tmp_file = write_tmpfile(cib_old_xml)
-        reporter.report(
-            ReportItem.debug(
-                reports.messages.TmpFileWrite(
-                    cib_old_tmp_file.name, cib_old_xml
-                )
-            )
+    with get_tmp_cib(reporter, cib_old_xml) as cib_old_tmp_file, get_tmp_cib(
+        reporter, cib_new_xml
+    ) as cib_new_tmp_file:
+        stdout, stderr, retval = runner.run(
+            [
+                __exec("crm_diff"),
+                "--original",
+                cib_old_tmp_file.name,
+                "--new",
+                cib_new_tmp_file.name,
+                "--no-version",
+            ]
         )
-        cib_new_tmp_file = write_tmpfile(cib_new_xml)
-        reporter.report(
-            ReportItem.debug(
-                reports.messages.TmpFileWrite(
-                    cib_new_tmp_file.name, cib_new_xml
-                )
-            )
-        )
-    except EnvironmentError as e:
-        raise LibraryError(
-            ReportItem.error(reports.messages.CibSaveTmpError(str(e)))
-        ) from e
-    command = [
-        __exec("crm_diff"),
-        "--original",
-        cib_old_tmp_file.name,
-        "--new",
-        cib_new_tmp_file.name,
-        "--no-version",
-    ]
     #  0 (CRM_EX_OK) - success with no difference
     #  1 (CRM_EX_ERROR) - success with difference
     # 64 (CRM_EX_USAGE) - usage error
     # 65 (CRM_EX_DATAERR) - XML fragments not parseable
-    stdout, stderr, retval = runner.run(command)
     if retval == 0:
         return ""
     if retval > 1:
@@ -357,38 +402,28 @@ def simulate_cib_xml(runner, cib_xml):
     string cib_xml -- CIB XML to simulate
     """
     try:
-        new_cib_file = write_tmpfile(None)
-        transitions_file = write_tmpfile(None)
-    except OSError as e:
-        raise LibraryError(
-            ReportItem.error(
-                reports.messages.CibSimulateError(format_os_error(e))
-            )
-        ) from e
-
-    cmd = [
-        __exec("crm_simulate"),
-        "--simulate",
-        "--save-output",
-        new_cib_file.name,
-        "--save-graph",
-        transitions_file.name,
-        "--xml-pipe",
-    ]
-    stdout, stderr, retval = runner.run(cmd, stdin_string=cib_xml)
-    if retval != 0:
-        raise LibraryError(
-            ReportItem.error(reports.messages.CibSimulateError(stderr.strip()))
-        )
-
-    try:
-        new_cib_file.seek(0)
-        transitions_file.seek(0)
-        new_cib_xml = new_cib_file.read()
-        transitions_xml = transitions_file.read()
-        new_cib_file.close()
-        transitions_file.close()
-        return stdout, transitions_xml, new_cib_xml
+        with get_tmp_file() as new_cib_file, get_tmp_file() as transitions_file:
+            cmd = [
+                __exec("crm_simulate"),
+                "--simulate",
+                "--save-output",
+                new_cib_file.name,
+                "--save-graph",
+                transitions_file.name,
+                "--xml-pipe",
+            ]
+            stdout, stderr, retval = runner.run(cmd, stdin_string=cib_xml)
+            if retval != 0:
+                raise LibraryError(
+                    ReportItem.error(
+                        reports.messages.CibSimulateError(stderr.strip())
+                    )
+                )
+            new_cib_file.seek(0)
+            transitions_file.seek(0)
+            transitions = transitions_file.read()
+            new_cib = new_cib_file.read()
+            return stdout, transitions, new_cib
     except OSError as e:
         raise LibraryError(
             ReportItem.error(
@@ -423,15 +458,16 @@ def simulate_cib(runner, cib):
 ### wait for idle
 
 
-def wait_for_idle(runner, timeout=None):
+def wait_for_idle(runner: CommandRunner, timeout: int) -> None:
     """
     Run waiting command. Raise LibraryError if command failed.
 
-    runner is preconfigured object for running external programs
-    string timeout is waiting timeout
+    runner -- preconfigured object for running external programs
+    timeout -- waiting timeout in seconds, wait indefinitely if non-positive
+        integer
     """
     args = [__exec("crm_resource"), "--wait"]
-    if timeout is not None:
+    if timeout > 0:
         args.append("--timeout={0}".format(timeout))
     stdout, stderr, retval = runner.run(args)
     if retval != 0:
@@ -478,7 +514,7 @@ def get_local_node_name(runner):
 
 def get_local_node_status(runner):
     try:
-        cluster_status = ClusterState(get_cluster_status_xml(runner))
+        cluster_status = ClusterState(get_cluster_status_dom(runner))
         node_name = get_local_node_name(runner)
     except PacemakerNotConnectedException:
         return {"offline": True}
@@ -574,14 +610,12 @@ def resource_refresh(
     force: bool = False,
 ):
     if not force and not node and not resource:
-        summary = ClusterState(get_cluster_status_xml(runner)).summary
+        summary = ClusterState(get_cluster_status_dom(runner)).summary
         operations = summary.nodes.attrs.count * summary.resources.attrs.count
         if operations > __RESOURCE_REFRESH_OPERATION_COUNT_THRESHOLD:
             raise LibraryError(
                 ReportItem(
-                    reports.item.ReportItemSeverity.error(
-                        reports.codes.FORCE_LOAD_THRESHOLD
-                    ),
+                    reports.item.ReportItemSeverity.error(reports.codes.FORCE),
                     reports.messages.ResourceRefreshTooTimeConsuming(
                         __RESOURCE_REFRESH_OPERATION_COUNT_THRESHOLD
                     ),
@@ -749,6 +783,22 @@ def get_rule_in_effect_status(
     return translation_map.get(retval, CibRuleInEffectStatus.UNKNOWN)
 
 
+def get_status_from_api_result(dom: _Element) -> api_result.Status:
+    errors = []
+    status_el = cast(_Element, dom.find("./status"))
+    errors_el = status_el.find("errors")
+    if errors_el is not None:
+        errors = [
+            str((error_el.text or "")).strip()
+            for error_el in errors_el.iterfind("error")
+        ]
+    return api_result.Status(
+        code=int(str(status_el.get("code"))),
+        message=str(status_el.get("message")),
+        errors=errors,
+    )
+
+
 # shortcut for getting a full path to a pacemaker executable
 def __exec(name):
     return os.path.join(settings.pacemaker_binaries, name)
@@ -763,3 +813,80 @@ def _is_in_pcmk_tool_help(
     return all(text in stderr for text in text_list) or all(
         text in stdout for text in text_list
     )
+
+
+def is_getting_resource_digest_supported(runner):
+    return _is_in_pcmk_tool_help(runner, "crm_resource", "--digests")
+
+
+def get_resource_digests(
+    runner: CommandRunner,
+    resource_id: str,
+    node_name: str,
+    resource_options: Dict[str, str],
+    crm_meta_attributes: Optional[Dict[str, Optional[str]]] = None,
+) -> Dict[str, Optional[str]]:
+    """
+    Get set of digests for a resource using crm_resource utility. There are 3
+    types of digests: all, nonreloadable and nonprivate. Resource can have one
+    or more digests types depending on the resource parameters.
+
+    runner -- command runner instance
+    resource_id -- resource id
+    node_name -- name of the node where resource is running
+    resource_options -- resource options with updated values
+    crm_meta_attributes -- parameters of a monitor operation
+    """
+    # pylint: disable=too-many-locals
+    if crm_meta_attributes is None:
+        crm_meta_attributes = dict()
+    command = [
+        __exec("crm_resource"),
+        "--digests",
+        "--resource",
+        resource_id,
+        "--node",
+        node_name,
+        "--output-as",
+        "xml",
+        *[f"{key}={value}" for key, value in resource_options.items()],
+        *[
+            f"CRM_meta_{key}={value}"
+            for key, value in crm_meta_attributes.items()
+            if value is not None
+        ],
+    ]
+    stdout, stderr, retval = runner.run(command)
+
+    def error_exception(message):
+        return LibraryError(
+            ReportItem.error(
+                reports.messages.UnableToGetResourceOperationDigests(message)
+            )
+        )
+
+    try:
+        dom = xml_fromstring(stdout)
+        if os.path.isfile(settings.pacemaker_api_result_schema):
+            etree.RelaxNG(
+                file=settings.pacemaker_api_result_schema
+            ).assertValid(dom)
+    except (etree.XMLSyntaxError, etree.DocumentInvalid) as e:
+        raise error_exception(join_multilines([stderr, stdout])) from e
+
+    if retval != 0:
+        status = get_status_from_api_result(dom)
+        raise error_exception(
+            join_multilines([status.message] + list(status.errors))
+        )
+
+    digests = {}
+    for digest_type in ["all", "nonprivate", "nonreloadable"]:
+        xpath_result = cast(
+            List[str],
+            dom.xpath(f'./digests/digest[@type="{digest_type}"]/@hash'),
+        )
+        digests[digest_type] = xpath_result[0] if xpath_result else None
+    if not any(digests.values()):
+        raise error_exception(join_multilines([stderr, stdout]))
+    return digests
