@@ -1,7 +1,13 @@
 import re
+from typing import (
+    List,
+    Optional,
+    Union,
+)
 
 from pcs.common import reports
-from pcs.common.reports.item import ReportItem
+from pcs.common.reports.item import ReportItem, ReportItemList
+from pcs.common.tools import timeout_to_seconds
 from pcs.lib.errors import LibraryError
 
 
@@ -11,7 +17,6 @@ _BOOLEAN = _BOOLEAN_TRUE | _BOOLEAN_FALSE
 _ID_FIRST_CHAR_NOT_RE = re.compile("[^a-zA-Z_]")
 _ID_REST_CHARS_NOT_RE = re.compile("[^a-zA-Z0-9_.-]")
 SCORE_INFINITY = "INFINITY"
-RESOURCE_ROLES = ("Master", "Slave", "Started", "Stopped")
 
 
 def is_boolean(val) -> bool:
@@ -41,43 +46,16 @@ def is_false(val) -> bool:
     return val.lower() in _BOOLEAN_FALSE
 
 
-def is_score(value):
+def is_score(value: str) -> bool:
     if not value:
         return False
     unsigned_value = value[1:] if value[0] in ("+", "-") else value
     return unsigned_value == SCORE_INFINITY or unsigned_value.isdigit()
 
 
-def timeout_to_seconds(timeout, return_unknown=False):
-    """
-    Transform pacemaker style timeout to number of seconds
-    timeout timeout string
-    return_unknown if timeout is not valid then return None on False or timeout
-        on True (default False)
-    """
-    try:
-        candidate = int(timeout)
-        if candidate >= 0:
-            return candidate
-        return timeout if return_unknown else None
-    except ValueError:
-        pass
-    # now we know the timeout is not an integer nor an integer string
-    suffix_multiplier = {
-        "s": 1,
-        "sec": 1,
-        "m": 60,
-        "min": 60,
-        "h": 3600,
-        "hr": 3600,
-    }
-    for suffix, multiplier in suffix_multiplier.items():
-        if timeout.endswith(suffix) and timeout[: -len(suffix)].isdigit():
-            return int(timeout[: -len(suffix)]) * multiplier
-    return timeout if return_unknown else None
-
-
-def get_valid_timeout_seconds(timeout_candidate):
+def get_valid_timeout_seconds(
+    timeout_candidate: Union[str, int, None],
+) -> Optional[int]:
     """
     Transform pacemaker style timeout to number of seconds, raise LibraryError
         on invalid timeout
@@ -89,13 +67,17 @@ def get_valid_timeout_seconds(timeout_candidate):
     if wait_timeout is None:
         raise LibraryError(
             ReportItem.error(
-                reports.messages.InvalidTimeoutValue(timeout_candidate)
+                reports.messages.InvalidTimeoutValue(str(timeout_candidate))
             )
         )
     return wait_timeout
 
 
-def validate_id(id_candidate, description="id", reporter=None):
+def validate_id(
+    id_candidate: str,
+    description: Optional[str] = None,
+    reporter: Union[None, List, ReportItemList] = None,
+):
     """
     Validate a pacemaker id, raise LibraryError on invalid id.
 
@@ -105,6 +87,7 @@ def validate_id(id_candidate, description="id", reporter=None):
     # see NCName definition
     # http://www.w3.org/TR/REC-xml-names/#NT-NCName
     # http://www.w3.org/TR/REC-xml/#NT-Name
+    description = "id" if not description else description  # for mypy
     if not id_candidate:
         report_item = ReportItem.error(
             reports.messages.InvalidIdIsEmpty(description)
@@ -117,7 +100,10 @@ def validate_id(id_candidate, description="id", reporter=None):
     if _ID_FIRST_CHAR_NOT_RE.match(id_candidate[0]):
         report_item = ReportItem.error(
             reports.messages.InvalidIdBadChar(
-                id_candidate, description, id_candidate[0], True,
+                id_candidate,
+                description,
+                id_candidate[0],
+                True,
             )
         )
         if reporter is not None:
@@ -128,7 +114,10 @@ def validate_id(id_candidate, description="id", reporter=None):
         if _ID_REST_CHARS_NOT_RE.match(char):
             report_item = ReportItem.error(
                 reports.messages.InvalidIdBadChar(
-                    id_candidate, description, char, False,
+                    id_candidate,
+                    description,
+                    char,
+                    False,
                 )
             )
             if reporter is not None:
