@@ -8,13 +8,15 @@ from pcs.cli.common import parse_args
 from pcs.cli.common.errors import CmdLineInputError
 from pcs.cli.fencing_topology import target_type_map_cli_to_lib
 from pcs.cli.reports import process_library_reports
-from pcs.cli.reports.output import error
+from pcs.cli.reports.output import error, warn
 from pcs.cli.resource.parse_args import parse_create_simple as parse_create_args
+from pcs.common import reports
 from pcs.common.fencing_topology import (
     TARGET_TYPE_NODE,
     TARGET_TYPE_REGEXP,
     TARGET_TYPE_ATTRIBUTE,
 )
+from pcs.common.interface.dto import to_dict
 from pcs.common.str_tools import indent
 from pcs.lib.errors import LibraryError
 import pcs.lib.resource_agent as lib_ra
@@ -30,8 +32,9 @@ def stonith_show_cmd(lib, argv, modifiers):
 
 
 def stonith_status_cmd(lib, argv, modifiers):
-    resource.resource_status(lib, argv, modifiers, stonith=True)
-    print_stonith_levels(lib)
+    resource.resource_status(lib, argv[:], modifiers, stonith=True)
+    if not argv:
+        print_stonith_levels(lib)
 
 
 def stonith_config_cmd(lib, argv, modifiers):
@@ -192,7 +195,7 @@ def stonith_create(lib, argv, modifiers):
         )
 
 
-def stonith_level_parse_node(arg):
+def _stonith_level_parse_node(arg):
     """
     Commandline options: no options
     """
@@ -207,12 +210,52 @@ def stonith_level_parse_node(arg):
     return target_type, target_value
 
 
-def stonith_level_normalize_devices(argv):
+def _stonith_level_parse_target_and_stonith(argv):
+    target_type, target_value, devices = None, None, None
+    allowed_keywords = {"target", "stonith"}
+    missing_target_value, missing_stonith_value = False, False
+    groups = parse_args.group_by_keywords(
+        argv,
+        allowed_keywords,
+        only_found_keywords=True,
+    )
+    if "target" in groups:
+        if len(groups["target"]) > 1:
+            raise CmdLineInputError("At most one target can be specified")
+        if groups["target"]:
+            target_type, target_value = _stonith_level_parse_node(
+                groups["target"][0]
+            )
+        else:
+            missing_target_value = True
+    if "stonith" in groups:
+        if groups["stonith"]:
+            devices = groups["stonith"]
+        else:
+            missing_stonith_value = True
+
+    if missing_target_value and missing_stonith_value:
+        raise CmdLineInputError("Missing value after 'target' and 'stonith'")
+    if missing_target_value:
+        raise CmdLineInputError("Missing value after 'target'")
+    if missing_stonith_value:
+        raise CmdLineInputError("Missing value after 'stonith'")
+
+    return target_type, target_value, devices
+
+
+def _stonith_level_normalize_devices(argv):
     """
     Commandline options: no options
     """
     # normalize devices - previously it was possible to delimit devices by both
     # a comma and a space
+    if any("," in arg for arg in argv):
+        warn(
+            "Delimiting stonith devices with ',' is deprecated and will be "
+            "removed. Please use a space to delimit stonith devices.",
+            stderr=True,
+        )
     return ",".join(argv).split(",")
 
 
@@ -226,12 +269,12 @@ def stonith_level_add_cmd(lib, argv, modifiers):
     modifiers.ensure_only_supported("-f", "--force")
     if len(argv) < 3:
         raise CmdLineInputError()
-    target_type, target_value = stonith_level_parse_node(argv[1])
+    target_type, target_value = _stonith_level_parse_node(argv[1])
     lib.fencing_topology.add_level(
         argv[0],
         target_type,
         target_value,
-        stonith_level_normalize_devices(argv[2:]),
+        _stonith_level_normalize_devices(argv[2:]),
         force_device=modifiers.get("--force"),
         force_node=modifiers.get("--force"),
     )
@@ -243,15 +286,31 @@ def stonith_level_clear_cmd(lib, argv, modifiers):
       * -f - CIB file
     """
     modifiers.ensure_only_supported("-f")
-    if len(argv) > 1:
-        raise CmdLineInputError()
 
     if not argv:
         lib.fencing_topology.remove_all_levels()
         return
 
-    target_type, target_value = stonith_level_parse_node(argv[0])
-    # backward compatibility mode
+    allowed_keywords = {"target", "stonith"}
+    if len(argv) > 1 or (len(argv) == 1 and argv[0] in allowed_keywords):
+        (
+            target_type,
+            target_value,
+            devices,
+        ) = _stonith_level_parse_target_and_stonith(argv)
+        if devices is not None and target_value is not None:
+            raise CmdLineInputError(
+                "Only one of 'target' and 'stonith' can be used"
+            )
+        lib.fencing_topology.remove_levels_by_params(
+            None,
+            target_type,
+            target_value,
+            devices,
+        )
+        return
+
+    # TODO remove, deprecated backward compatibility mode for old syntax
     # Command parameters are: node, stonith-list
     # Both the node and the stonith list are optional. If the node is ommited
     # and the stonith list is present, there is no way to figure it out, since
@@ -259,6 +318,13 @@ def stonith_level_clear_cmd(lib, argv, modifiers):
     # code tried both. It deleted all levels having the first parameter as
     # either a node or a device list. Since it was only possible to specify
     # node as a target back then, this is enabled only in that case.
+    warn(
+        "Syntax 'pcs stonith level clear [<target> | <stonith id(s)>] is "
+        "deprecated and will be removed. Please use 'pcs stonith level clear "
+        "[target <target>] | [stonith <stonith id>...]'.",
+        stderr=True,
+    )
+    target_type, target_value = _stonith_level_parse_node(argv[0])
     was_error = False
     try:
         lib.fencing_topology.remove_levels_by_params(
@@ -309,10 +375,11 @@ def stonith_level_config_to_str(config):
             continue
         for target_value in sorted(config_data[target_type].keys()):
             lines.append(
-                "Target: {0}".format(
+                "Target{0}: {1}".format(
+                    " (regexp)" if target_type == TARGET_TYPE_REGEXP else "",
                     "=".join(target_value)
                     if target_type == TARGET_TYPE_ATTRIBUTE
-                    else target_value
+                    else target_value,
                 )
             )
             level_lines = []
@@ -354,10 +421,36 @@ def stonith_level_remove_cmd(lib, argv, modifiers):
         raise CmdLineInputError()
     target_type, target_value, devices = None, None, None
     level = argv[0]
-    if len(argv) > 1:
-        target_type, target_value = stonith_level_parse_node(argv[1])
-    if len(argv) > 2:
-        devices = stonith_level_normalize_devices(argv[2:])
+
+    allowed_keywords = {"target", "stonith"}
+    if len(argv) > 1 and argv[1] in allowed_keywords:
+        (
+            target_type,
+            target_value,
+            devices,
+        ) = _stonith_level_parse_target_and_stonith(argv[1:])
+        target_may_be_a_device = False
+    else:
+        # TODO remove, deprecated backward compatibility layer for old syntax
+        if len(argv) > 1:
+            warn(
+                "Syntax 'pcs stonith level delete | remove <level> [<target>] "
+                "[<stonith id>...]' is deprecated and will be removed. Please "
+                "use 'pcs stonith level delete | remove <level> "
+                "[target <target>] [stonith <stonith id>...]'.",
+                stderr=True,
+            )
+            if not parse_args.ARG_TYPE_DELIMITER in argv[1] and "," in argv[1]:
+                warn(
+                    "Delimiting stonith devices with ',' is deprecated and "
+                    "will be removed. Please use a space to delimit stonith "
+                    "devices.",
+                    stderr=True,
+                )
+            target_type, target_value = _stonith_level_parse_node(argv[1])
+        if len(argv) > 2:
+            devices = _stonith_level_normalize_devices(argv[2:])
+        target_may_be_a_device = True
 
     lib.fencing_topology.remove_levels_by_params(
         level,
@@ -365,7 +458,7 @@ def stonith_level_remove_cmd(lib, argv, modifiers):
         target_value,
         devices,
         # backward compatibility mode, see lib command for details
-        target_may_be_a_device=True,
+        target_may_be_a_device=target_may_be_a_device,
     )
 
 
@@ -454,7 +547,7 @@ def get_fence_agent_info(lib, argv, modifiers):
 
     try:
         metadata = lib_ra.StonithAgent(runner, agent[len("stonith:") :])
-        info = metadata.get_full_info()
+        info = to_dict(metadata.get_full_info())
         info["name"] = "stonith:{0}".format(info["name"])
         print(json.dumps(info))
     except lib_ra.ResourceAgentError as e:
@@ -793,3 +886,52 @@ def stonith_history_update_cmd(lib, argv, modifiers):
         raise CmdLineInputError()
 
     print(lib.stonith.history_update())
+
+
+def stonith_update_scsi_devices(lib, argv, modifiers):
+    """
+    Options:
+      * --request-timeout - timeout for HTTP requests
+      * --skip-offline - skip unreachable nodes
+    """
+    modifiers.ensure_only_supported("--request-timeout", "--skip-offline")
+    force_flags = []
+    if modifiers.get("--skip-offline"):
+        force_flags.append(reports.codes.SKIP_OFFLINE_NODES)
+
+    if len(argv) < 2:
+        raise CmdLineInputError()
+    stonith_id = argv[0]
+    parsed_args = parse_args.group_by_keywords(
+        argv[1:],
+        ["set", "add", "remove", "delete"],
+        keyword_repeat_allowed=False,
+        only_found_keywords=True,
+    )
+    cmd_exception = CmdLineInputError(
+        show_both_usage_and_message=True,
+        hint=(
+            "You must specify either list of set devices or at least one device"
+            " for add or delete/remove devices"
+        ),
+    )
+    if "set" in parsed_args and {"add", "remove", "delete"} & set(
+        parsed_args.keys()
+    ):
+        raise cmd_exception
+    if "set" in parsed_args:
+        if not parsed_args["set"]:
+            raise cmd_exception
+        lib.stonith.update_scsi_devices(
+            stonith_id, parsed_args["set"], force_flags=force_flags
+        )
+    else:
+        for key in ("add", "remove", "delete"):
+            if key in parsed_args and not parsed_args[key]:
+                raise cmd_exception
+        lib.stonith.update_scsi_devices_add_remove(
+            stonith_id,
+            parsed_args.get("add", []),
+            parsed_args.get("delete", []) + parsed_args.get("remove", []),
+            force_flags=force_flags,
+        )
