@@ -3,7 +3,10 @@ import os
 import sys
 import subprocess
 import xml.dom.minidom
-from xml.dom.minidom import parseString
+from xml.dom.minidom import (
+    parseString,
+    Document as DomDocument,
+)
 import xml.etree.ElementTree as ET
 import re
 import json
@@ -29,22 +32,29 @@ from typing import (
 from pcs import settings, usage
 
 from pcs.common import (
+    const,
     file as pcs_file,
     file_type_codes,
+    pacemaker as common_pacemaker,
     pcs_pycurl as pycurl,
-    reports,
 )
 from pcs.common.host import PcsKnownHost
 from pcs.common.reports import ReportProcessor
 from pcs.common.reports.item import ReportItemList
 from pcs.common.reports.messages import CibUpgradeFailedToMinimalRequiredVersion
-from pcs.common.str_tools import join_multilines
+from pcs.common.services.interfaces import ServiceManagerInterface
+from pcs.common.services.errors import ManageServiceError
+from pcs.common.tools import (
+    timeout_to_seconds,
+    Version,
+)
 
 from pcs.cli.common import middleware
 from pcs.cli.common.env_cli import Env
 from pcs.cli.common.errors import CmdLineInputError
 from pcs.cli.common.lib_wrapper import Library
 from pcs.cli.common.parse_args import InputModifiers
+from pcs.cli.common.tools import timeout_to_seconds_legacy
 from pcs.cli.reports import (
     output as reports_output,
     process_library_reports,
@@ -59,22 +69,21 @@ from pcs.lib.env import LibraryEnvironment
 from pcs.lib.errors import LibraryError
 from pcs.lib.external import (
     CommandRunner,
-    disable_service,
-    DisableServiceError,
-    enable_service,
-    EnableServiceError,
     is_proxy_set,
-    is_systemctl,
 )
 from pcs.lib.file.instance import FileInstance as LibFileInstance
 from pcs.lib.interface.config import ParserErrorException
+from pcs.lib.pacemaker.live import get_cluster_status_dom
 from pcs.lib.pacemaker.state import ClusterState
 from pcs.lib.pacemaker.values import (
     is_boolean,
     is_score as is_score_value,
-    timeout_to_seconds as get_timeout_seconds,
     validate_id,
 )
+from pcs.lib.services import (
+    get_service_manager as _get_service_manager,
+    service_exception_to_report,
+)
 
 # pylint: disable=invalid-name
 # pylint: disable=too-many-branches
@@ -94,7 +103,7 @@ class UnknownPropertyException(Exception):
     pass
 
 
-def getValidateWithVersion(dom):
+def getValidateWithVersion(dom) -> Version:
     """
     Commandline options: no options
     """
@@ -107,26 +116,28 @@ def getValidateWithVersion(dom):
     version = cib.getAttribute("validate-with")
     r = re.compile(r"pacemaker-(\d+)\.(\d+)\.?(\d+)?")
     m = r.match(version)
+    if m is None:
+        raise AssertionError()
     major = int(m.group(1))
     minor = int(m.group(2))
     rev = int(m.group(3) or 0)
-    return (major, minor, rev)
+    return Version(major, minor, rev)
+
+
+def isCibVersionSatisfied(cib_dom, required_version: Version) -> bool:
+    if not isinstance(cib_dom, DomDocument):
+        cib_dom = cib_dom.ownerDocument
+    return getValidateWithVersion(cib_dom) >= required_version
 
 
 # Check the current pacemaker version in cib and upgrade it if necessary
 # Returns False if not upgraded and True if upgraded
-def checkAndUpgradeCIB(major, minor, rev):
+def checkAndUpgradeCIB(required_version: Version) -> bool:
     """
     Commandline options:
       * -f - CIB file
     """
-    cmajor, cminor, crev = getValidateWithVersion(get_cib_dom())
-    # pylint: disable=too-many-boolean-expressions
-    if (
-        cmajor > major
-        or (cmajor == major and cminor > minor)
-        or (cmajor == major and cminor == minor and crev >= rev)
-    ):
+    if isCibVersionSatisfied(get_cib_dom(), required_version):
         return False
     cluster_upgrade()
     return True
@@ -148,19 +159,19 @@ def cluster_upgrade():
     print("Cluster CIB has been upgraded to latest version")
 
 
-def cluster_upgrade_to_version(required_version):
+def cluster_upgrade_to_version(required_version: Version) -> Any:
     """
     Commandline options:
       * -f - CIB file
     """
-    checkAndUpgradeCIB(*required_version)
+    checkAndUpgradeCIB(required_version)
     dom = get_cib_dom()
     current_version = getValidateWithVersion(dom)
     if current_version < required_version:
         err(
             CibUpgradeFailedToMinimalRequiredVersion(
-                ".".join([str(x) for x in current_version]),
-                ".".join([str(x) for x in required_version]),
+                str(current_version),
+                str(required_version),
             ).message
         )
     return dom
@@ -683,7 +694,7 @@ def get_corosync_conf_facade(conf_text=None):
             )
         )
     except corosync_conf_parser.CorosyncConfParserException as e:
-        err("Unable to parse corosync.conf: %s" % e)
+        return err("Unable to parse corosync.conf: %s" % e)
 
 
 def getNodeAttributesFromPacemaker():
@@ -693,10 +704,12 @@ def getNodeAttributesFromPacemaker():
     try:
         return [
             node.attrs
-            for node in ClusterState(getClusterStateXml()).node_section.nodes
+            for node in ClusterState(
+                get_cluster_status_dom(cmd_runner())
+            ).node_section.nodes
         ]
     except LibraryError as e:
-        process_library_reports(e.args)
+        return process_library_reports(e.args)
 
 
 def hasCorosyncConf():
@@ -714,11 +727,15 @@ def getCorosyncConf():
       * --corosync_conf - path to a mocked corosync.conf is set directly to
         settings
     """
+    corosync_conf_content = None
     try:
-        out = open(settings.corosync_conf_file, "r", encoding="utf-8").read()
+        with open(
+            settings.corosync_conf_file, "r", encoding="utf-8"
+        ) as corosync_conf_file:
+            corosync_conf_content = corosync_conf_file.read()
     except IOError as e:
         err("Unable to read %s: %s" % (settings.corosync_conf_file, e.strerror))
-    return out
+    return corosync_conf_content
 
 
 def reloadCorosync():
@@ -776,12 +793,10 @@ def need_to_handle_qdevice_service():
         is used
     """
     try:
-        cfg = corosync_conf_facade(
-            corosync_conf_parser.Parser.parse(
-                open(settings.corosync_conf_file, "rb").read()
-            )
-        )
-        return cfg.has_quorum_device()
+        with open(settings.corosync_conf_file, "rb") as corosync_conf_file:
+            return corosync_conf_facade(
+                corosync_conf_parser.Parser.parse(corosync_conf_file.read())
+            ).has_quorum_device()
     except (EnvironmentError, corosync_conf_parser.CorosyncConfParserException):
         # corosync.conf not present or not valid => no qdevice specified
         return False
@@ -833,9 +848,9 @@ def run(
         "iso8601",
         "stonith_admin",
     ]:
-        args[0] = settings.pacemaker_binaries + command
+        args[0] = os.path.join(settings.pacemaker_binaries, command)
     elif command[0:8] == "corosync":
-        args[0] = settings.corosync_binaries + command
+        args[0] = os.path.join(settings.corosync_binaries, command)
 
     try:
         if "--debug" in pcs_options:
@@ -850,7 +865,7 @@ def run(
         else:
             stdin_pipe = subprocess.DEVNULL
 
-        # pylint: disable=subprocess-popen-preexec-fn
+        # pylint: disable=subprocess-popen-preexec-fn, consider-using-with
         p = subprocess.Popen(
             args,
             stdin=stdin_pipe,
@@ -913,8 +928,7 @@ def run_pcsdcli(command, data=None):
     pcsd_dir_path = settings.pcsd_exec_location
     pcsdcli_path = os.path.join(pcsd_dir_path, "pcsd-cli.rb")
     if settings.pcsd_gem_path is not None:
-        gem_home = os.path.join(pcsd_dir_path, settings.pcsd_gem_path)
-        env_var["GEM_HOME"] = gem_home
+        env_var["GEM_HOME"] = settings.pcsd_gem_path
     stdout, dummy_stderr, retval = cmd_runner().run(
         [settings.ruby_executable, "-I" + pcsd_dir_path, pcsdcli_path, command],
         json.dumps(data),
@@ -1523,8 +1537,8 @@ def resource_running_on(resource, passed_state=None, stopped=False):
       * -f - has effect but doesn't make sense to check state of resource
     """
     nodes_started = []
-    nodes_master = []
-    nodes_slave = []
+    nodes_promoted = []
+    nodes_unpromoted = []
     state = passed_state if passed_state else getClusterState()
     resource_original = resource
     resource = get_resource_for_running_check(state, resource, stopped)
@@ -1538,20 +1552,21 @@ def resource_running_on(resource, passed_state=None, stopped=False):
         ) and res.getAttribute("failed") != "true":
             for node in res.getElementsByTagName("node"):
                 node_name = node.getAttribute("name")
-                if res.getAttribute("role") == "Started":
+                role = res.getAttribute("role")
+                if role == const.PCMK_ROLE_STARTED:
                     nodes_started.append(node_name)
-                elif res.getAttribute("role") == "Master":
-                    nodes_master.append(node_name)
-                elif res.getAttribute("role") == "Slave":
-                    nodes_slave.append(node_name)
-    if not nodes_started and not nodes_master and not nodes_slave:
+                elif role in const.PCMK_ROLES_PROMOTED:
+                    nodes_promoted.append(node_name)
+                elif role in const.PCMK_ROLES_UNPROMOTED:
+                    nodes_unpromoted.append(node_name)
+    if not nodes_started and not nodes_promoted and not nodes_unpromoted:
         message = "Resource '%s' is not running on any node" % resource_original
     else:
         message_parts = []
         for alist, label in (
             (nodes_started, "running"),
-            (nodes_master, "master"),
-            (nodes_slave, "slave"),
+            (nodes_promoted, str(const.PCMK_ROLE_PROMOTED_PRIMARY).lower()),
+            (nodes_unpromoted, str(const.PCMK_ROLE_UNPROMOTED_PRIMARY).lower()),
         ):
             if alist:
                 alist.sort()
@@ -1565,10 +1580,7 @@ def resource_running_on(resource, passed_state=None, stopped=False):
         )
     return {
         "message": message,
-        "is_running": bool(nodes_started or nodes_master or nodes_slave),
-        "nodes_started": nodes_started,
-        "nodes_master": nodes_master,
-        "nodes_slave": nodes_slave,
+        "is_running": bool(nodes_started or nodes_promoted or nodes_unpromoted),
     }
 
 
@@ -1583,7 +1595,7 @@ def validate_wait_get_timeout(need_cib_support=True):
     wait_timeout = pcs_options["--wait"]
     if wait_timeout is None:
         return wait_timeout
-    wait_timeout = get_timeout_seconds(wait_timeout)
+    wait_timeout = timeout_to_seconds(wait_timeout)
     if wait_timeout is None:
         err(
             "%s is not a valid number of seconds to wait"
@@ -1634,7 +1646,7 @@ def get_cib_dom(cib_xml=None):
         dom = parseString(cib_xml)
         return dom
     except:
-        err("unable to get cib")
+        return err("unable to get cib")
 
 
 def get_cib_etree(cib_xml=None):
@@ -1649,7 +1661,7 @@ def get_cib_etree(cib_xml=None):
         root = ET.fromstring(cib_xml)
         return root
     except:
-        err("unable to get cib")
+        return err("unable to get cib")
 
 
 def is_etree(var):
@@ -1762,11 +1774,11 @@ def operation_exists(operations_el, op_el):
     """
     existing = []
     op_name = op_el.getAttribute("name")
-    op_interval = get_timeout_seconds(op_el.getAttribute("interval"), True)
+    op_interval = timeout_to_seconds_legacy(op_el.getAttribute("interval"))
     for op in operations_el.getElementsByTagName("op"):
         if (
             op.getAttribute("name") == op_name
-            and get_timeout_seconds(op.getAttribute("interval"), True)
+            and timeout_to_seconds_legacy(op.getAttribute("interval"))
             == op_interval
         ):
             existing.append(op)
@@ -1777,9 +1789,16 @@ def operation_exists_by_name(operations_el, op_el):
     """
     Commandline options: no options
     """
+    new_roles_supported = isCibVersionSatisfied(
+        operations_el, const.PCMK_NEW_ROLES_CIB_VERSION
+    )
     existing = []
     op_name = op_el.getAttribute("name")
-    op_role = op_el.getAttribute("role") or "Started"
+    get_role_fn = lambda _el: common_pacemaker.role.get_value_for_cib(
+        _el.getAttribute("role") or const.PCMK_ROLE_STARTED,
+        new_roles_supported,
+    )
+    op_role = get_role_fn(op_el)
     ocf_check_level = None
     if op_name == "monitor":
         ocf_check_level = get_operation_ocf_check_level(op_el)
@@ -1788,8 +1807,8 @@ def operation_exists_by_name(operations_el, op_el):
         if op.getAttribute("name") == op_name:
             if op_name != "monitor":
                 existing.append(op)
-            elif (
-                op.getAttribute("role") or "Started"
+            elif get_role_fn(
+                op
             ) == op_role and ocf_check_level == get_operation_ocf_check_level(
                 op
             ):
@@ -1991,27 +2010,24 @@ def get_terminal_password(message="Password: "):
 
 
 # Returns an xml dom containing the current status of the cluster
-# DEPRECATED, please use ClusterState(getClusterStateXml()) instead
+# DEPRECATED, please use
+# ClusterState(lib.pacemaker.live.get_cluster_status_dom()) instead
 def getClusterState():
     """
     Commandline options:
       * -f - CIB file
     """
-    return parseString(getClusterStateXml())
-
-
-# DEPRECATED, please use lib.pacemaker.live.get_cluster_status_xml in new code
-def getClusterStateXml():
-    """
-    Commandline options:
-      * -f - CIB file
-    """
+    output, returncode = run(["crm_mon", "--help-all"])
+    format_option = (
+        "--output-as=xml" if "--output-as=" in output else "--as-xml"
+    )
     xml_string, returncode = run(
-        ["crm_mon", "--one-shot", "--as-xml", "--inactive"], ignore_stderr=True
+        ["crm_mon", "--one-shot", format_option, "--inactive"],
+        ignore_stderr=True,
     )
     if returncode != 0:
         err("error running crm_mon, is pacemaker running?")
-    return xml_string
+    return parseString(xml_string)
 
 
 # DEPRECATED
@@ -2025,12 +2041,13 @@ def getClusterName():
         settings
     """
     try:
-        f = open(settings.corosync_conf_file, "rb")
-        conf = corosync_conf_facade(corosync_conf_parser.Parser.parse(f.read()))
-        f.close()
-        cluster_name = conf.get_cluster_name()
-        if cluster_name:
-            return cluster_name
+        with open(settings.corosync_conf_file, "rb") as f:
+            conf = corosync_conf_facade(
+                corosync_conf_parser.Parser.parse(f.read())
+            )
+            cluster_name = conf.get_cluster_name()
+            if cluster_name:
+                return cluster_name
     except (IOError, corosync_conf_parser.CorosyncConfParserException):
         pass
 
@@ -2060,9 +2077,8 @@ def write_empty_cib(cibfile):
   </configuration>
   <status/>
 </cib>"""
-    f = open(cibfile, "w")
-    f.write(empty_xml)
-    f.close()
+    with open(cibfile, "w") as f:
+        f.write(empty_xml)
 
 
 # Test if 'var' is a score or option (contains an '=')
@@ -2105,44 +2121,17 @@ def is_iso8601_date(var):
     return retVal == 0
 
 
-def verify_cert_key_pair(cert, key):
-    """
-    Commandline options: no options
-    """
-    errors = []
-    cert_modulus = ""
-    key_modulus = ""
-
-    output, retval = run(
-        ["/usr/bin/openssl", "x509", "-modulus", "-noout"],
-        string_for_stdin=cert,
-    )
-    if retval != 0:
-        errors.append("Invalid certificate: {0}".format(output.strip()))
-    else:
-        cert_modulus = output.strip()
-
-    output, retval = run(
-        ["/usr/bin/openssl", "rsa", "-modulus", "-noout"], string_for_stdin=key
-    )
-    if retval != 0:
-        errors.append("Invalid key: {0}".format(output.strip()))
-    else:
-        key_modulus = output.strip()
-
-    if not errors and cert_modulus and key_modulus:
-        if cert_modulus != key_modulus:
-            errors.append("Certificate does not match the key")
-
-    return errors
-
-
 def err(errorText, exit_after_error=True):
     sys.stderr.write("Error: %s\n" % errorText)
     if exit_after_error:
         sys.exit(1)
 
 
+@lru_cache(typed=True)
+def get_service_manager() -> ServiceManagerInterface:
+    return _get_service_manager(cmd_runner(), get_report_processor())
+
+
 def enableServices():
     """
     Commandline options: no options
@@ -2151,21 +2140,14 @@ def enableServices():
     service_list = ["corosync", "pacemaker"]
     if need_to_handle_qdevice_service():
         service_list.append("corosync-qdevice")
+    service_manager = get_service_manager()
 
     report_item_list = []
     for service in service_list:
         try:
-            enable_service(cmd_runner(), service)
-        except EnableServiceError as e:
-            report_item_list.append(
-                reports.item.ReportItem.error(
-                    reports.messages.ServiceActionFailed(
-                        reports.const.SERVICE_ACTION_ENABLE,
-                        e.service,
-                        e.message,
-                    )
-                )
-            )
+            service_manager.enable(service)
+        except ManageServiceError as e:
+            report_item_list.append(service_exception_to_report(e))
     if report_item_list:
         raise LibraryError(*report_item_list)
 
@@ -2178,21 +2160,14 @@ def disableServices():
     service_list = ["corosync", "pacemaker"]
     if need_to_handle_qdevice_service():
         service_list.append("corosync-qdevice")
+    service_manager = get_service_manager()
 
     report_item_list = []
     for service in service_list:
         try:
-            disable_service(cmd_runner(), service)
-        except DisableServiceError as e:
-            report_item_list.append(
-                reports.item.ReportItem.error(
-                    reports.messages.ServiceActionFailed(
-                        reports.const.SERVICE_ACTION_DISABLE,
-                        e.service,
-                        e.message,
-                    )
-                )
-            )
+            service_manager.disable(service)
+        except ManageServiceError as e:
+            report_item_list.append(service_exception_to_report(e))
     if report_item_list:
         raise LibraryError(*report_item_list)
 
@@ -2201,30 +2176,24 @@ def start_service(service):
     """
     Commandline options: no options
     """
-    if is_systemctl():
-        stdout, stderr, retval = cmd_runner().run(
-            [settings.systemctl_binary, "start", service]
-        )
-    else:
-        stdout, stderr, retval = cmd_runner().run(
-            [settings.service_binary, service, "start"]
-        )
-    return join_multilines([stderr, stdout]), retval
+    service_manager = get_service_manager()
+
+    try:
+        service_manager.start(service)
+    except ManageServiceError as e:
+        raise LibraryError(service_exception_to_report(e)) from e
 
 
 def stop_service(service):
     """
     Commandline options: no options
     """
-    if is_systemctl():
-        stdout, stderr, retval = cmd_runner().run(
-            [settings.systemctl_binary, "stop", service]
-        )
-    else:
-        stdout, stderr, retval = cmd_runner().run(
-            [settings.service_binary, service, "stop"]
-        )
-    return join_multilines([stderr, stdout]), retval
+    service_manager = get_service_manager()
+
+    try:
+        service_manager.stop(service)
+    except ManageServiceError as e:
+        raise LibraryError(service_exception_to_report(e)) from e
 
 
 def write_file(path, data, permissions=0o644, binary=False):
@@ -2289,34 +2258,37 @@ def simulate_cib(cib_dom):
     """
     Commandline options: no options
     """
-    new_cib_file = tempfile.NamedTemporaryFile(mode="w+", suffix=".pcs")
-    transitions_file = tempfile.NamedTemporaryFile(mode="w+", suffix=".pcs")
-    output, retval = run(
-        [
-            "crm_simulate",
-            "--simulate",
-            "--save-output",
-            new_cib_file.name,
-            "--save-graph",
-            transitions_file.name,
-            "--xml-pipe",
-        ],
-        string_for_stdin=cib_dom.toxml(),
-    )
-    if retval != 0:
-        err("Unable to run crm_simulate:\n%s" % output)
     try:
-        new_cib_file.seek(0)
-        transitions_file.seek(0)
-        return (
-            output,
-            parseString(transitions_file.read()),
-            parseString(new_cib_file.read()),
-        )
+        with tempfile.NamedTemporaryFile(
+            mode="w+", suffix=".pcs"
+        ) as new_cib_file, tempfile.NamedTemporaryFile(
+            mode="w+", suffix=".pcs"
+        ) as transitions_file:
+            output, retval = run(
+                [
+                    "crm_simulate",
+                    "--simulate",
+                    "--save-output",
+                    new_cib_file.name,
+                    "--save-graph",
+                    transitions_file.name,
+                    "--xml-pipe",
+                ],
+                string_for_stdin=cib_dom.toxml(),
+            )
+            if retval != 0:
+                return err("Unable to run crm_simulate:\n%s" % output)
+            new_cib_file.seek(0)
+            transitions_file.seek(0)
+            return (
+                output,
+                parseString(transitions_file.read()),
+                parseString(new_cib_file.read()),
+            )
     except (EnvironmentError, xml.parsers.expat.ExpatError) as e:
-        err("Unable to run crm_simulate:\n%s" % e)
+        return err("Unable to run crm_simulate:\n%s" % e)
     except xml.etree.ElementTree.ParseError as e:
-        err("Unable to run crm_simulate:\n%s" % e)
+        return err("Unable to run crm_simulate:\n%s" % e)
 
 
 # DEPRECATED
@@ -2627,7 +2599,7 @@ def is_valid_cib_value(value_type, value, enum_options=()):
     if value_type == "integer":
         return is_score(value)
     if value_type == "time":
-        return get_timeout_seconds(value) is not None
+        return timeout_to_seconds(value) is not None
     return True
 
 
@@ -2776,7 +2748,8 @@ def get_lib_env() -> LibraryEnvironment:
     if "--corosync_conf" in pcs_options:
         conf = pcs_options["--corosync_conf"]
         try:
-            corosync_conf_data = open(conf).read()
+            with open(conf) as corosync_conf_file:
+                corosync_conf_data = corosync_conf_file.read()
         except IOError as e:
             err("Unable to read %s: %s" % (conf, e.strerror))
 
