@@ -538,3 +538,50 @@ class UnableToGetAgentMetadata(CliReportMessageTestBase):
             "Agent 'agent-name' is not installed or does not provide valid "
             "metadata: reason, on multiple lines",
         )
+
+
+class HostAlreadyInClusterConfig(CliReportMessageTestBase):
+    def test_message(self):
+        self.assert_message(
+            messages.HostAlreadyInClusterConfig("nodeX"),
+            "nodeX: The host seems to be in a cluster already as cluster "
+            "configuration files have been found on the host. If the host is "
+            "not part of a cluster, run 'pcs cluster destroy' on host 'nodeX' "
+            "to remove those configuration files",
+        )
+
+
+class CannotLeaveGroupEmptyAfterMove(CliReportMessageTestBase):
+    def test_single_resource(self):
+        self.assert_message(
+            messages.CannotLeaveGroupEmptyAfterMove("gr1", ["R"]),
+            "Unable to move resource 'R' as it would leave group 'gr1' empty. "
+            "Please, use the 'pcs resource ungroup gr1' command first.",
+        )
+
+    def test_multiple_resources(self):
+        self.assert_message(
+            messages.CannotLeaveGroupEmptyAfterMove("gr1", ["R3", "R1", "R2"]),
+            "Unable to move resources 'R1', 'R2', 'R3' as it would leave "
+            "group 'gr1' empty. Please, use the 'pcs resource ungroup gr1' "
+            "command first.",
+        )
+
+
+class StonithRestartlessUpdateUnableToPerform(CliReportMessageTestBase):
+    def test_other_reason(self):
+        report_msg = messages.StonithRestartlessUpdateUnableToPerform("reason")
+        self.assert_message(
+            report_msg,
+            report_msg.message,
+        )
+
+    def test_not_running_reason(self):
+        report_msg = messages.StonithRestartlessUpdateUnableToPerform(
+            "reason",
+            const.STONITH_RESTARTLESS_UPDATE_UNABLE_TO_PERFORM_REASON_NOT_RUNNING,
+        )
+        self.assert_message(
+            report_msg,
+            f"{report_msg.message}, please use command 'pcs stonith update' instead",
+        )
