@@ -1,3 +1,4 @@
+# pylint: disable=too-many-lines
 from unittest import TestCase
 from lxml import etree
 
@@ -8,42 +9,61 @@ from pcs_test.tools.assertions import (
 from pcs_test.tools import fixture
 from pcs_test.tools.xml import etree_to_str
 
-from pcs.common import report_codes
+from pcs.common.reports import codes as report_codes
 from pcs.lib.cib.resource import common
 from pcs.lib.cib.tools import IdProvider
 
 
-fixture_cib = etree.fromstring("""
-    <resources>
-        <primitive id="A" />
-        <clone id="B-clone">
-            <primitive id="B" />
-        </clone>
-        <master id="C-master">
-            <primitive id="C" />
-        </master>
-        <group id="D">
-            <primitive id="D1" />
-            <primitive id="D2" />
-        </group>
-        <clone id="E-clone">
-            <group id="E">
-                <primitive id="E1" />
-                <primitive id="E2" />
-            </group>
-        </clone>
-        <master id="F-master">
-            <group id="F">
-                <primitive id="F1" />
-                <primitive id="F2" />
-            </group>
-        </master>
-        <bundle id="G-bundle" />
-        <bundle id="H-bundle">
-            <primitive id="H" />
-        </bundle>
-    </resources>
-""")
+fixture_cib = etree.fromstring(
+    """
+    <cib>
+        <configuration>
+            <resources>
+                <primitive id="A" />
+                <clone id="B-clone">
+                    <primitive id="B" />
+                </clone>
+                <master id="C-master">
+                    <primitive id="C" />
+                </master>
+                <group id="D">
+                    <primitive id="D1" />
+                    <primitive id="D2" />
+                </group>
+                <clone id="E-clone">
+                    <group id="E">
+                        <primitive id="E1" />
+                        <primitive id="E2" />
+                    </group>
+                </clone>
+                <master id="F-master">
+                    <group id="F">
+                        <primitive id="F1" />
+                        <primitive id="F2" />
+                    </group>
+                </master>
+                <bundle id="G-bundle" />
+                <bundle id="H-bundle">
+                    <primitive id="H" />
+                </bundle>
+                <group id="I">
+                    <primitive id="I1" />
+                </group>
+                <clone id="J-clone">
+                    <group id="J">
+                        <primitive id="J1" />
+                    </group>
+                </clone>
+                <master id="K-master">
+                    <group id="K">
+                        <primitive id="K1" />
+                    </group>
+                </master>
+            </resources>
+        </configuration>
+    </cib>
+    """
+)
 
 
 class AreMetaDisabled(TestCase):
@@ -86,7 +106,8 @@ class IsCloneDeactivatedByMeta(TestCase):
 
 class FindOneOrMoreResources(TestCase):
     def setUp(self):
-        self.cib = etree.fromstring("""
+        self.cib = etree.fromstring(
+            """
             <resources>
                 <primitive id="R1" />
                 <primitive id="R2" />
@@ -94,7 +115,8 @@ class FindOneOrMoreResources(TestCase):
                 <primitive id="R1x" />
                 <primitive id="R2x" />
             </resources>
-        """)
+        """
+        )
 
         def searcher(resource_element):
             return [
@@ -102,116 +124,67 @@ class FindOneOrMoreResources(TestCase):
                     ".//*[@id='{0}x']".format(resource_element.get("id"))
                 )
             ]
+
         self.additional_search = searcher
 
     def test_one_existing(self):
-        report_list = []
-        resource = common.find_one_resource_and_report(
-            self.cib,
-            "R1",
-            report_list
-        )
+        resource, report_list = common.find_one_resource(self.cib, "R1")
         self.assertEqual("R1", resource.attrib.get("id"))
-        assert_report_item_list_equal(
-            report_list,
-            []
-        )
+        assert_report_item_list_equal(report_list, [])
 
     def test_one_nonexistant(self):
-        report_list = []
-        resource = common.find_one_resource_and_report(
-            self.cib,
-            "R-missing",
-            report_list
-        )
+        resource, report_list = common.find_one_resource(self.cib, "R-missing")
         self.assertIsNone(resource)
         assert_report_item_list_equal(
             report_list,
             [
                 fixture.report_not_found("R-missing", context_type="resources"),
-            ]
-        )
-
-    def test_one_additional_search(self):
-        report_list = []
-        resource = common.find_one_resource_and_report(
-            self.cib,
-            "R1",
-            report_list,
-            additional_search=self.additional_search,
-        )
-        self.assertEqual("R1x", resource.attrib.get("id"))
-        assert_report_item_list_equal(
-            report_list,
-            []
+            ],
         )
 
     def test_more_existing(self):
-        report_list = []
-        resource_list = common.find_resources_and_report(
-            self.cib,
-            ["R1", "R2"],
-            report_list
+        resource_list, report_list = common.find_resources(
+            self.cib, ["R1", "R2"]
         )
         self.assertEqual(
             ["R1", "R2"],
-            [resource.attrib.get("id") for resource in resource_list]
-        )
-        assert_report_item_list_equal(
-            report_list,
-            []
+            [resource.attrib.get("id") for resource in resource_list],
         )
+        assert_report_item_list_equal(report_list, [])
 
     def test_more_some_missing(self):
-        report_list = []
-        resource_list = common.find_resources_and_report(
-            self.cib,
-            ["R1", "R2", "RY1", "RY2"],
-            report_list
+        resource_list, report_list = common.find_resources(
+            self.cib, ["R1", "R2", "RY1", "RY2"]
         )
         self.assertEqual(
             ["R1", "R2"],
-            [resource.attrib.get("id") for resource in resource_list]
+            [resource.attrib.get("id") for resource in resource_list],
         )
         assert_report_item_list_equal(
             report_list,
             [
                 fixture.report_not_found("RY1", context_type="resources"),
                 fixture.report_not_found("RY2", context_type="resources"),
-            ]
-        )
-
-    def test_more_additional_search(self):
-        report_list = []
-        resource_list = common.find_resources_and_report(
-            self.cib,
-            ["R1", "R2"],
-            report_list,
-            additional_search=self.additional_search,
-        )
-        self.assertEqual(
-            ["R1x", "R2x"],
-            [resource.attrib.get("id") for resource in resource_list]
-        )
-        assert_report_item_list_equal(
-            report_list,
-            []
+            ],
         )
 
 
 class FindResourcesMixin:
+    _iterable_type = list
+
     def assert_find_resources(self, input_resource_id, output_resource_ids):
         self.assertEqual(
-            output_resource_ids,
-            [
-                element.get("id", "")
-                for element in
-                self._tested_fn(
-                    fixture_cib.find(
-                        './/*[@id="{0}"]'.format(input_resource_id)
+            self._iterable_type(output_resource_ids),
+            self._iterable_type(
+                [
+                    element.get("id", "")
+                    for element in self._tested_fn(
+                        fixture_cib.find(
+                            './/*[@id="{0}"]'.format(input_resource_id)
+                        )
                     )
-                )
-            ]
+                ]
+            ),
         )
 
     def test_group(self):
@@ -235,6 +208,27 @@ class FindResourcesMixin:
     def test_bundle_with_primitive(self):
         self.assert_find_resources("H-bundle", ["H"])
 
+    def test_primitive(self):
+        raise NotImplementedError()
+
+    def test_primitive_in_clone(self):
+        raise NotImplementedError()
+
+    def test_primitive_in_master(self):
+        raise NotImplementedError()
+
+    def test_primitive_in_group(self):
+        raise NotImplementedError()
+
+    def test_primitive_in_bundle(self):
+        raise NotImplementedError()
+
+    def test_cloned_group(self):
+        raise NotImplementedError()
+
+    def test_mastered_group(self):
+        raise NotImplementedError()
+
 
 class FindPrimitives(TestCase, FindResourcesMixin):
     _tested_fn = staticmethod(common.find_primitives)
@@ -266,6 +260,37 @@ class FindPrimitives(TestCase, FindResourcesMixin):
         self.assert_find_resources("F-master", ["F1", "F2"])
 
 
+class GetAllInnerResources(TestCase, FindResourcesMixin):
+    _iterable_type = set
+    _tested_fn = staticmethod(common.get_all_inner_resources)
+
+    def test_primitive(self):
+        self.assert_find_resources("A", set())
+
+    def test_primitive_in_clone(self):
+        self.assert_find_resources("B", set())
+
+    def test_primitive_in_master(self):
+        self.assert_find_resources("C", set())
+
+    def test_primitive_in_group(self):
+        self.assert_find_resources("D1", set())
+        self.assert_find_resources("D2", set())
+        self.assert_find_resources("E1", set())
+        self.assert_find_resources("E2", set())
+        self.assert_find_resources("F1", set())
+        self.assert_find_resources("F2", set())
+
+    def test_primitive_in_bundle(self):
+        self.assert_find_resources("H", set())
+
+    def test_cloned_group(self):
+        self.assert_find_resources("E-clone", {"E", "E1", "E2"})
+
+    def test_mastered_group(self):
+        self.assert_find_resources("F-master", {"F", "F1", "F2"})
+
+
 class GetInnerResources(TestCase, FindResourcesMixin):
     _tested_fn = staticmethod(common.get_inner_resources)
 
@@ -302,7 +327,7 @@ class IsWrapperResource(TestCase):
             is_wrapper,
             common.is_wrapper_resource(
                 fixture_cib.find('.//*[@id="{0}"]'.format(res_id))
-            )
+            ),
         )
 
     def test_primitive(self):
@@ -355,9 +380,9 @@ class IsWrapperResource(TestCase):
 
 class GetParentResource(TestCase):
     def assert_parent_resource(self, input_resource_id, output_resource_id):
-        res_el = common.get_parent_resource(fixture_cib.find(
-            './/*[@id="{0}"]'.format(input_resource_id)
-        ))
+        res_el = common.get_parent_resource(
+            fixture_cib.find('.//*[@id="{0}"]'.format(input_resource_id))
+        )
         self.assertEqual(
             output_resource_id, res_el.get("id") if res_el is not None else None
         )
@@ -416,13 +441,12 @@ class FindResourcesToEnable(TestCase):
             output_resource_ids,
             [
                 element.get("id", "")
-                for element in
-                common.find_resources_to_enable(
+                for element in common.find_resources_to_enable(
                     fixture_cib.find(
                         './/*[@id="{0}"]'.format(input_resource_id)
                     )
                 )
-            ]
+            ],
         )
 
     def test_primitive(self):
@@ -493,7 +517,7 @@ class Enable(TestCase):
                 <resource>
                     <meta_attributes />
                 </resource>
-            """
+            """,
         )
 
     def test_enabled(self):
@@ -505,7 +529,7 @@ class Enable(TestCase):
             """
                 <resource>
                 </resource>
-            """
+            """,
         )
 
     def test_only_first_meta(self):
@@ -530,7 +554,7 @@ class Enable(TestCase):
                         <nvpair name="target-role" value="something" />
                     </meta_attributes>
                 </resource>
-            """
+            """,
         )
 
 
@@ -565,7 +589,7 @@ class Disable(TestCase):
                             name="target-role" value="Stopped" />
                     </meta_attributes>
                 </resource>
-            """
+            """,
         )
 
     def test_only_first_meta(self):
@@ -590,7 +614,7 @@ class Disable(TestCase):
                     <meta_attributes id="R-meta_attributes-2">
                     </meta_attributes>
                 </resource>
-            """
+            """,
         )
 
 
@@ -600,13 +624,12 @@ class FindResourcesToManage(TestCase):
             output_resource_ids,
             [
                 element.get("id", "")
-                for element in
-                common.find_resources_to_manage(
+                for element in common.find_resources_to_manage(
                     fixture_cib.find(
                         './/*[@id="{0}"]'.format(input_resource_id)
                     )
                 )
-            ]
+            ],
         )
 
     def test_primitive(self):
@@ -663,13 +686,12 @@ class FindResourcesToUnmanage(TestCase):
             output_resource_ids,
             [
                 element.get("id", "")
-                for element in
-                common.find_resources_to_unmanage(
+                for element in common.find_resources_to_unmanage(
                     fixture_cib.find(
                         './/*[@id="{0}"]'.format(input_resource_id)
                     )
                 )
-            ]
+            ],
         )
 
     def test_primitive(self):
@@ -740,7 +762,7 @@ class Manage(TestCase):
                 <resource>
                     <meta_attributes />
                 </resource>
-            """
+            """,
         )
 
     def test_managed(self):
@@ -752,7 +774,7 @@ class Manage(TestCase):
             """
                 <resource>
                 </resource>
-            """
+            """,
         )
 
     def test_only_first_meta(self):
@@ -777,7 +799,7 @@ class Manage(TestCase):
                         <nvpair name="is-managed" value="something" />
                     </meta_attributes>
                 </resource>
-            """
+            """,
         )
 
 
@@ -812,7 +834,7 @@ class Unmanage(TestCase):
                             name="is-managed" value="false" />
                     </meta_attributes>
                 </resource>
-            """
+            """,
         )
 
     def test_only_first_meta(self):
@@ -837,26 +859,29 @@ class Unmanage(TestCase):
                     <meta_attributes id="R-meta_attributes-2">
                     </meta_attributes>
                 </resource>
-            """
+            """,
         )
 
 
-class ValidateMoveBanClearMixin():
-    #pylint: disable=too-many-public-methods
+class ValidateMoveBanClearMixin:
+    # pylint: disable=too-many-public-methods,line-too-long
     @staticmethod
     def _fixture_clone(promotable=False):
-        return etree.fromstring(f"""
+        return etree.fromstring(
+            f"""
             <clone id="R-clone">
                 <primitive id="R" />
                 <meta_attributes>
                     <nvpair name="promotable" value="{'true' if promotable else 'false'}" />
                 </meta_attributes>
             </clone>
-        """)
+            """
+        )
 
     @staticmethod
     def _fixture_group_clone(promotable=False):
-        return etree.fromstring(f"""
+        return etree.fromstring(
+            f"""
             <clone id="G-clone">
                 <group id="G">
                     <primitive id="R" />
@@ -865,39 +890,38 @@ class ValidateMoveBanClearMixin():
                     <nvpair name="promotable" value="{'true' if promotable else 'false'}" />
                 </meta_attributes>
             </clone>
-        """)
+            """
+        )
 
     @staticmethod
     def _fixture_master():
-        return etree.fromstring(f"""
+        return etree.fromstring(
+            """
             <master id="R-master">
                 <primitive id="R" />
             </master>
-        """)
+            """
+        )
 
     @staticmethod
     def _fixture_group_master():
-        return etree.fromstring(f"""
+        return etree.fromstring(
+            """
             <master id="G-master">
                 <group id="G">
                     <primitive id="R" />
                 </group>
             </master>
-        """)
+            """
+        )
 
     def test_master_true_promotable_clone(self):
         element = self._fixture_clone(True)
-        assert_report_item_list_equal(
-            self.validate(element, True),
-            []
-        )
+        assert_report_item_list_equal(self.validate(element, True), [])
 
     def test_master_false_promotable_clone(self):
         element = self._fixture_clone(True)
-        assert_report_item_list_equal(
-            self.validate(element, False),
-            []
-        )
+        assert_report_item_list_equal(self.validate(element, False), [])
 
     def test_master_true_clone(self):
         element = self._fixture_clone(False)
@@ -909,29 +933,20 @@ class ValidateMoveBanClearMixin():
                     resource_id="R-clone",
                     promotable_id=None,
                 ),
-            ]
+            ],
         )
 
     def test_master_false_clone(self):
         element = self._fixture_clone(False)
-        assert_report_item_list_equal(
-            self.validate(element, False),
-            []
-        )
+        assert_report_item_list_equal(self.validate(element, False), [])
 
     def test_master_true_master(self):
         element = self._fixture_master()
-        assert_report_item_list_equal(
-            self.validate(element, True),
-            []
-        )
+        assert_report_item_list_equal(self.validate(element, True), [])
 
     def test_master_false_master(self):
         element = self._fixture_master()
-        assert_report_item_list_equal(
-            self.validate(element, False),
-            []
-        )
+        assert_report_item_list_equal(self.validate(element, False), [])
 
     def test_master_true_promotable_clone_resource(self):
         element = self._fixture_clone(True)
@@ -943,14 +958,13 @@ class ValidateMoveBanClearMixin():
                     resource_id="R",
                     promotable_id="R-clone",
                 ),
-            ]
+            ],
         )
 
     def test_master_false_promotable_clone_resource(self):
         element = self._fixture_clone(True)
         assert_report_item_list_equal(
-            self.validate(element.find("./primitive"), False),
-            []
+            self.validate(element.find("./primitive"), False), []
         )
 
     def test_master_true_promotable_clone_group(self):
@@ -963,14 +977,13 @@ class ValidateMoveBanClearMixin():
                     resource_id="G",
                     promotable_id="G-clone",
                 ),
-            ]
+            ],
         )
 
     def test_master_false_promotable_clone_group(self):
         element = self._fixture_group_clone(True)
         assert_report_item_list_equal(
-            self.validate(element.find("./group"), False),
-            []
+            self.validate(element.find("./group"), False), []
         )
 
     def test_master_true_promotable_clone_group_resource(self):
@@ -983,14 +996,13 @@ class ValidateMoveBanClearMixin():
                     resource_id="R",
                     promotable_id="G-clone",
                 ),
-            ]
+            ],
         )
 
     def test_master_false_promotable_clone_group_resource(self):
         element = self._fixture_group_clone(True)
         assert_report_item_list_equal(
-            self.validate(element.find("./group/primitive"), False),
-            []
+            self.validate(element.find("./group/primitive"), False), []
         )
 
     def test_master_true_clone_resource(self):
@@ -1003,14 +1015,13 @@ class ValidateMoveBanClearMixin():
                     resource_id="R",
                     promotable_id=None,
                 ),
-            ]
+            ],
         )
 
     def test_master_false_clone_resource(self):
         element = self._fixture_clone(False)
         assert_report_item_list_equal(
-            self.validate(element.find("./primitive"), False),
-            []
+            self.validate(element.find("./primitive"), False), []
         )
 
     def test_master_true_clone_group(self):
@@ -1023,14 +1034,13 @@ class ValidateMoveBanClearMixin():
                     resource_id="G",
                     promotable_id=None,
                 ),
-            ]
+            ],
         )
 
     def test_master_false_clone_group(self):
         element = self._fixture_group_clone(False)
         assert_report_item_list_equal(
-            self.validate(element.find("./group"), False),
-            []
+            self.validate(element.find("./group"), False), []
         )
 
     def test_master_true_clone_group_resource(self):
@@ -1043,14 +1053,13 @@ class ValidateMoveBanClearMixin():
                     resource_id="R",
                     promotable_id=None,
                 ),
-            ]
+            ],
         )
 
     def test_master_false_clone_group_resource(self):
         element = self._fixture_group_clone(False)
         assert_report_item_list_equal(
-            self.validate(element.find("./group/primitive"), False),
-            []
+            self.validate(element.find("./group/primitive"), False), []
         )
 
     def test_master_true_master_resource(self):
@@ -1063,7 +1072,7 @@ class ValidateMoveBanClearMixin():
                     resource_id="R",
                     promotable_id="R-master",
                 ),
-            ]
+            ],
         )
 
     def test_master_true_master_group(self):
@@ -1076,7 +1085,7 @@ class ValidateMoveBanClearMixin():
                     resource_id="G",
                     promotable_id="G-master",
                 ),
-            ]
+            ],
         )
 
     def test_master_true_master_group_resource(self):
@@ -1089,7 +1098,7 @@ class ValidateMoveBanClearMixin():
                     resource_id="R",
                     promotable_id="G-master",
                 ),
-            ]
+            ],
         )
 
 
@@ -1101,23 +1110,26 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
 
     @staticmethod
     def _fixture_bundle():
-        return etree.fromstring(f"""
+        return etree.fromstring(
+            """
             <bundle id="R-bundle">
                 <primitive id="R" />
             </bundle>
-        """)
+            """
+        )
 
     def test_master_false_promotable_clone(self):
         element = self._fixture_clone(True)
         assert_report_item_list_equal(
             self.validate(element, False),
-            [
-                fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_PROMOTABLE_NOT_MASTER,
-                    resource_id="R-clone",
-                    promotable_id="R-clone",
-                ),
-            ]
+            [],
+        )
+
+    def test_master_true_promotable_clone(self):
+        element = self._fixture_clone(True)
+        assert_report_item_list_equal(
+            self.validate(element, True),
+            [],
         )
 
     def test_master_true_clone(self):
@@ -1129,7 +1141,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
                     report_codes.CANNOT_MOVE_RESOURCE_CLONE,
                     resource_id="R-clone",
                 ),
-            ]
+            ],
         )
 
     def test_master_false_clone(self):
@@ -1141,20 +1153,21 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
                     report_codes.CANNOT_MOVE_RESOURCE_CLONE,
                     resource_id="R-clone",
                 ),
-            ]
+            ],
         )
 
     def test_master_false_master(self):
         element = self._fixture_master()
         assert_report_item_list_equal(
             self.validate(element, False),
-            [
-                fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_PROMOTABLE_NOT_MASTER,
-                    resource_id="R-master",
-                    promotable_id="R-master",
-                ),
-            ]
+            [],
+        )
+
+    def test_master_true_master(self):
+        element = self._fixture_master()
+        assert_report_item_list_equal(
+            self.validate(element, True),
+            [],
         )
 
     def test_master_false_promotable_clone_resource(self):
@@ -1163,11 +1176,11 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             self.validate(element.find("./primitive"), False),
             [
                 fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_PROMOTABLE_NOT_MASTER,
+                    report_codes.CANNOT_MOVE_RESOURCE_PROMOTABLE_INNER,
                     resource_id="R",
                     promotable_id="R-clone",
                 ),
-            ]
+            ],
         )
 
     def test_master_false_promotable_clone_group(self):
@@ -1176,11 +1189,11 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             self.validate(element.find("./group"), False),
             [
                 fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_PROMOTABLE_NOT_MASTER,
+                    report_codes.CANNOT_MOVE_RESOURCE_PROMOTABLE_INNER,
                     resource_id="G",
                     promotable_id="G-clone",
                 ),
-            ]
+            ],
         )
 
     def test_master_false_promotable_clone_group_resource(self):
@@ -1189,11 +1202,11 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             self.validate(element.find("./group/primitive"), False),
             [
                 fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_PROMOTABLE_NOT_MASTER,
+                    report_codes.CANNOT_MOVE_RESOURCE_PROMOTABLE_INNER,
                     resource_id="R",
                     promotable_id="G-clone",
                 ),
-            ]
+            ],
         )
 
     def test_master_true_clone_resource(self):
@@ -1205,7 +1218,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
                     report_codes.CANNOT_MOVE_RESOURCE_CLONE,
                     resource_id="R",
                 ),
-            ]
+            ],
         )
 
     def test_master_false_clone_resource(self):
@@ -1217,7 +1230,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
                     report_codes.CANNOT_MOVE_RESOURCE_CLONE,
                     resource_id="R",
                 ),
-            ]
+            ],
         )
 
     def test_master_true_clone_group(self):
@@ -1229,7 +1242,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
                     report_codes.CANNOT_MOVE_RESOURCE_CLONE,
                     resource_id="G",
                 ),
-            ]
+            ],
         )
 
     def test_master_false_clone_group(self):
@@ -1241,7 +1254,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
                     report_codes.CANNOT_MOVE_RESOURCE_CLONE,
                     resource_id="G",
                 ),
-            ]
+            ],
         )
 
     def test_master_true_clone_group_resource(self):
@@ -1253,7 +1266,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
                     report_codes.CANNOT_MOVE_RESOURCE_CLONE,
                     resource_id="R",
                 ),
-            ]
+            ],
         )
 
     def test_master_false_clone_group_resource(self):
@@ -1265,7 +1278,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
                     report_codes.CANNOT_MOVE_RESOURCE_CLONE,
                     resource_id="R",
                 ),
-            ]
+            ],
         )
 
     def test_bundle(self):
@@ -1277,16 +1290,16 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
                     report_codes.CANNOT_MOVE_RESOURCE_BUNDLE,
                     resource_id="R-bundle",
                 ),
-            ]
+            ],
         )
 
     def test_bundle_resource(self):
         element = self._fixture_bundle()
         assert_report_item_list_equal(
-            self.validate(element.find("./primitive"), False),
-            []
+            self.validate(element.find("./primitive"), False), []
         )
 
+
 class ValidateBan(ValidateMoveBanClearMixin, TestCase):
     validate = staticmethod(common.validate_ban)
     report_code_bad_master = (
@@ -1297,6 +1310,97 @@ class ValidateBan(ValidateMoveBanClearMixin, TestCase):
 class ValidateUnmoveUnban(ValidateMoveBanClearMixin, TestCase):
     validate = staticmethod(common.validate_unmove_unban)
     report_code_bad_master = (
-        report_codes
-            .CANNOT_UNMOVE_UNBAN_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE
+        report_codes.CANNOT_UNMOVE_UNBAN_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE
     )
+
+
+class FindResourcesToDelete(TestCase):
+    # pylint: disable=too-many-public-methods
+    def assert_element2element_list(self, element_id, element_id_list):
+        self.assertEqual(
+            common.find_resources_to_delete(
+                fixture_cib.xpath(f'.//*[@id="{element_id}"]')[0]
+            ),
+            [
+                fixture_cib.xpath(f'.//*[@id="{_id}"]')[0]
+                for _id in element_id_list
+            ],
+        )
+
+    def test_primitive(self):
+        self.assert_element2element_list("A", ["A"])
+
+    def test_clone(self):
+        self.assert_element2element_list("B-clone", ["B-clone", "B"])
+
+    def test_primitive_in_clone(self):
+        self.assert_element2element_list("B", ["B-clone", "B"])
+
+    def test_master(self):
+        self.assert_element2element_list("C-master", ["C-master", "C"])
+
+    def test_primitive_in_master(self):
+        self.assert_element2element_list("C", ["C-master", "C"])
+
+    def test_group(self):
+        self.assert_element2element_list("D", ["D", "D1", "D2"])
+
+    def test_primitive_in_group(self):
+        self.assert_element2element_list("D1", ["D1"])
+
+    def test_clone_with_group(self):
+        self.assert_element2element_list(
+            "E-clone",
+            ["E-clone", "E", "E1", "E2"],
+        )
+
+    def test_group_in_clone(self):
+        self.assert_element2element_list("E", ["E-clone", "E", "E1", "E2"])
+
+    def test_primitive_in_cloned_group(self):
+        self.assert_element2element_list("E2", ["E2"])
+
+    def test_master_with_group(self):
+        self.assert_element2element_list(
+            "F-master",
+            ["F-master", "F", "F1", "F2"],
+        )
+
+    def test_group_in_master(self):
+        self.assert_element2element_list("F", ["F-master", "F", "F1", "F2"])
+
+    def test_primitive_in_mastered_group(self):
+        self.assert_element2element_list("F1", ["F1"])
+
+    def test_empty_bundle(self):
+        self.assert_element2element_list("G-bundle", ["G-bundle"])
+
+    def test_bundle_with_primitive(self):
+        self.assert_element2element_list("H-bundle", ["H-bundle", "H"])
+
+    def test_primitive_in_bundle(self):
+        self.assert_element2element_list("H", ["H"])
+
+    def test_group_with_single_primitive(self):
+        self.assert_element2element_list("I", ["I", "I1"])
+
+    def test_single_primitive_in_group(self):
+        self.assert_element2element_list("I1", ["I", "I1"])
+
+    def test_clone_with_group_with_single_primitive(self):
+        self.assert_element2element_list("J-clone", ["J-clone", "J", "J1"])
+
+    def test_group_with_single_primitive_in_clone(self):
+        self.assert_element2element_list("J", ["J-clone", "J", "J1"])
+
+    def test_single_primitive_in_cloned_group(self):
+        self.assert_element2element_list("J1", ["J-clone", "J", "J1"])
+
+    def test_master_with_group_with_single_primitive(self):
+        self.assert_element2element_list("K-master", ["K-master", "K", "K1"])
+
+    def test_group_with_single_primitive_in_master(self):
+        self.assert_element2element_list("K", ["K-master", "K", "K1"])
+
+    def test_single_primitive_in_mastered_group(self):
+        self.assert_element2element_list("K1", ["K-master", "K", "K1"])
