@@ -10,6 +10,7 @@ from pcs_test.tools import fixture
 from pcs_test.tools.command_env import get_env_tools
 from pcs_test.tools.misc import outdent
 
+from pcs import settings
 from pcs.common.reports import codes as report_codes
 from pcs.lib.commands import cluster
 
@@ -80,7 +81,7 @@ def corosync_conf_fixture(
 
         logging {{
             to_logfile: yes
-            logfile: /var/log/cluster/corosync.log
+            logfile: {logfile}
             to_syslog: yes
         }}
         """
@@ -89,6 +90,7 @@ def corosync_conf_fixture(
         nodes="\n".join(nodes),
         quorum=_corosync_options_fixture(quorum_options, indent_level=1),
         device=device,
+        logfile=settings.corosync_log_file,
     )
 
 
@@ -105,8 +107,7 @@ def node_fixture(node, node_id, addr_sufix=""):
 
 class LocalConfig:
     def __init__(self, call_collection, wrap_helper, config):
-        # pylint: disable=unused-argument
-        self.__calls = call_collection
+        del wrap_helper, call_collection
         self.config = config
         self.expected_reports = []
 
@@ -200,7 +201,9 @@ class SuccessMinimal(TestCase):
             )
             .http.host.check_auth(node_labels=self.existing_nodes)
             # SBD not installed
-            .runner.systemctl.list_unit_files({}, name=sbd_installed_check)
+            .services.is_installed(
+                "sbd", return_value=False, name=sbd_installed_check
+            )
             .http.host.get_quorum_status(
                 self.existing_nodes,
                 node_labels=self.nodes_to_remove[:1],
@@ -428,8 +431,8 @@ class SuccessAtbRequired(TestCase):
                 )
             )
             .http.host.check_auth(node_labels=self.existing_nodes)
-            .runner.systemctl.list_unit_files({"sbd": "enabled"})
-            .runner.systemctl.is_enabled("sbd", is_enabled=True)
+            .services.is_installed("sbd", return_value=True)
+            .services.is_enabled("sbd", return_value=True)
             .http.corosync.check_corosync_offline(
                 node_labels=self.nodes_to_stay,
             )
@@ -557,8 +560,8 @@ class FailureAtbRequired(TestCase):
                 )
             )
             .http.host.check_auth(node_labels=self.existing_nodes)
-            .runner.systemctl.list_unit_files({"sbd": "enabled"})
-            .runner.systemctl.is_enabled("sbd", is_enabled=True)
+            .services.is_installed("sbd", return_value=True)
+            .services.is_enabled("sbd", return_value=True)
         )
         self.expected_reports.extend(
             [
@@ -801,7 +804,7 @@ class QuorumCheck(TestCase):
             + [
                 fixture.error(
                     report_codes.COROSYNC_QUORUM_LOSS_UNABLE_TO_CHECK,
-                    force_code=report_codes.FORCE_QUORUM_LOSS,
+                    force_code=report_codes.FORCE,
                 )
             ]
         )
@@ -975,7 +978,7 @@ class FailureQuorumLoss(TestCase):
                 ),
                 fixture.error(
                     report_codes.COROSYNC_QUORUM_LOSS_UNABLE_TO_CHECK,
-                    force_code=report_codes.FORCE_QUORUM_LOSS,
+                    force_code=report_codes.FORCE,
                 ),
             ]
         )
@@ -1090,7 +1093,7 @@ class FailureQuorumLoss(TestCase):
             + [
                 fixture.error(
                     report_codes.COROSYNC_QUORUM_LOSS_UNABLE_TO_CHECK,
-                    force_code=report_codes.FORCE_QUORUM_LOSS,
+                    force_code=report_codes.FORCE,
                 ),
             ]
         )
@@ -1186,7 +1189,7 @@ class FailureQuorumLoss(TestCase):
             + [
                 fixture.error(
                     report_codes.COROSYNC_QUORUM_WILL_BE_LOST,
-                    force_code=report_codes.FORCE_QUORUM_LOSS,
+                    force_code=report_codes.FORCE,
                 ),
             ]
         )
@@ -2080,7 +2083,9 @@ class OfflineNodes(TestCase):
                 ]
             )
             # SBD not installed
-            .runner.systemctl.list_unit_files({}, name="is_sbd_installed")
+            .services.is_installed(
+                "sbd", return_value=False, name="is_sbd_installed"
+            )
             .http.host.get_quorum_status(
                 self.existing_nodes,
                 node_labels=self.nodes_to_remove[:1],
@@ -2131,7 +2136,9 @@ class OfflineNodes(TestCase):
                 ]
             )
             # SBD not installed
-            .runner.systemctl.list_unit_files({}, name="is_sbd_installed")
+            .services.is_installed(
+                "sbd", return_value=False, name="is_sbd_installed"
+            )
             .http.host.get_quorum_status(
                 self.existing_nodes,
                 node_labels=self.nodes_to_remove[:1],
@@ -2194,7 +2201,9 @@ class OfflineNodes(TestCase):
                 ]
             )
             # SBD not installed
-            .runner.systemctl.list_unit_files({}, name="is_sbd_installed")
+            .services.is_installed(
+                "sbd", return_value=False, name="is_sbd_installed"
+            )
             .http.host.get_quorum_status(
                 self.existing_nodes,
                 communication_list=[
@@ -2278,7 +2287,9 @@ class OfflineNodes(TestCase):
                 ]
             )
             # SBD not installed
-            .runner.systemctl.list_unit_files({}, name="is_sbd_installed")
+            .services.is_installed(
+                "sbd", return_value=False, name="is_sbd_installed"
+            )
             .http.host.get_quorum_status(
                 self.existing_nodes,
                 node_labels=self.nodes_to_remove[:1],
@@ -2331,7 +2342,11 @@ class OfflineNodes(TestCase):
                 ]
             )
             # SBD not installed
-            .runner.systemctl.list_unit_files({}, name="is_sbd_installed")
+            .services.is_installed(
+                "sbd",
+                return_value=False,
+                name="services.is_installed.sbd.False",
+            )
             .http.host.get_quorum_status(
                 self.existing_nodes,
                 communication_list=[
@@ -2476,7 +2491,11 @@ class OfflineNodes(TestCase):
                 node_labels=([self.nodes_to_stay[0]] + self.nodes_to_remove)
             )
             # SBD not installed
-            .runner.systemctl.list_unit_files({}, name="is_sbd_installed")
+            .services.is_installed(
+                "sbd",
+                return_value=False,
+                name="services.is_installed.sbd.False",
+            )
             .http.host.get_quorum_status(
                 self.existing_nodes,
                 node_labels=self.nodes_to_remove[:1],
@@ -2511,7 +2530,11 @@ class OfflineNodes(TestCase):
                 node_labels=([self.nodes_to_stay[0]] + self.nodes_to_remove)
             )
             # SBD not installed
-            .runner.systemctl.list_unit_files({}, name="is_sbd_installed")
+            .services.is_installed(
+                "sbd",
+                return_value=False,
+                name="services.is_installed.sbd.False",
+            )
             .http.host.get_quorum_status(
                 self.existing_nodes,
                 node_labels=self.nodes_to_remove[:1],
@@ -2554,7 +2577,11 @@ class OfflineNodes(TestCase):
             self.config.env.set_known_nodes(self.nodes_to_stay)
             .http.host.check_auth(node_labels=(self.nodes_to_stay))
             # SBD not installed
-            .runner.systemctl.list_unit_files({}, name="is_sbd_installed")
+            .services.is_installed(
+                "sbd",
+                return_value=False,
+                name="services.is_installed.sbd.False",
+            )
             .http.host.get_quorum_status(
                 self.existing_nodes,
                 node_labels=[],
@@ -2585,7 +2612,11 @@ class OfflineNodes(TestCase):
             self.config.env.set_known_nodes(self.nodes_to_stay)
             .http.host.check_auth(node_labels=(self.nodes_to_stay))
             # SBD not installed
-            .runner.systemctl.list_unit_files({}, name="is_sbd_installed")
+            .services.is_installed(
+                "sbd",
+                return_value=False,
+                name="services.is_installed.sbd.False",
+            )
             .http.host.get_quorum_status(
                 self.existing_nodes,
                 node_labels=[],
@@ -2629,7 +2660,11 @@ class OfflineNodes(TestCase):
                 node_labels=(self.nodes_to_stay + [self.nodes_to_remove[1]])
             )
             # SBD not installed
-            .runner.systemctl.list_unit_files({}, name="is_sbd_installed")
+            .services.is_installed(
+                "sbd",
+                return_value=False,
+                name="services.is_installed.sbd.False",
+            )
             .http.host.get_quorum_status(
                 self.existing_nodes,
                 node_labels=[self.nodes_to_remove[1]],
@@ -2664,7 +2699,11 @@ class OfflineNodes(TestCase):
                 node_labels=(self.nodes_to_stay + [self.nodes_to_remove[0]])
             )
             # SBD not installed
-            .runner.systemctl.list_unit_files({}, name="is_sbd_installed")
+            .services.is_installed(
+                "sbd",
+                return_value=False,
+                name="services.is_installed.sbd.False",
+            )
             .http.host.get_quorum_status(
                 self.existing_nodes,
                 node_labels=self.nodes_to_remove[:1],
