@@ -114,51 +114,6 @@ class ParametrizedContainerMixin(SetUpMixin):
             }
         )
 
-    def test_cib_upgrade_promoted_max(self):
-        (
-            self.config.runner.cib.load(
-                name="load_cib_old_version",
-                filename="cib-empty-2.8.xml",
-                resources=self.initial_resources,
-                before="runner.cib.load",
-            )
-            .runner.cib.upgrade(before="runner.cib.load")
-            .env.push_cib(
-                resources="""
-                    <resources>
-                        <bundle id="{bundle_id}">
-                            <{container_type}
-                                image="{image}"
-                                promoted-max="0"
-                            />
-                        </bundle>
-                    </resources>
-                """.format(
-                    container_type=self.container_type,
-                    bundle_id=self.bundle_id,
-                    image=self.image,
-                )
-            )
-        )
-
-        self.run_bundle_cmd(
-            container_options={
-                "image": self.image,
-                "promoted-max": "0",
-            }
-        )
-
-        self.env_assist.assert_reports(
-            [
-                (
-                    severities.INFO,
-                    report_codes.CIB_UPGRADE_SUCCESSFUL,
-                    {},
-                    None,
-                ),
-            ]
-        )
-
     def test_deprecated_options(self):
         # Setting both deprecated options and their new variants is tested in
         # self.test_options_errors. This shows deprecated options emit warning
@@ -323,7 +278,7 @@ class ParametrizedContainerMixin(SetUpMixin):
                         "allowed": sorted(list(GENERIC_CONTAINER_OPTIONS)),
                         "allowed_patterns": [],
                     },
-                    report_codes.FORCE_OPTIONS,
+                    report_codes.FORCE,
                 ),
             ]
         )
@@ -424,7 +379,7 @@ class NetworkMixin(SetUpMixin):
                 ),
                 fixture.error(
                     report_codes.INVALID_OPTION_VALUE,
-                    force_code=report_codes.FORCE_OPTIONS,
+                    force_code=report_codes.FORCE,
                     option_name="host-netmask",
                     option_value="abc",
                     allowed_values="a number of bits of the mask (1..32)",
@@ -433,7 +388,7 @@ class NetworkMixin(SetUpMixin):
                 ),
                 fixture.error(
                     report_codes.INVALID_OPTIONS,
-                    force_code=report_codes.FORCE_OPTIONS,
+                    force_code=report_codes.FORCE,
                     option_names=["extra"],
                     option_type="network",
                     allowed=sorted(NETWORK_OPTIONS),
@@ -679,11 +634,11 @@ class PortMapMixin(SetUpMixin):
                         "allowed": sorted(list(PORT_MAP_OPTIONS)),
                         "allowed_patterns": [],
                     },
-                    report_codes.FORCE_OPTIONS,
+                    report_codes.FORCE,
                 ),
                 fixture.error(
                     report_codes.INVALID_OPTION_VALUE,
-                    force_code=report_codes.FORCE_OPTIONS,
+                    force_code=report_codes.FORCE,
                     option_name="range",
                     option_value="3000",
                     allowed_values="port-port",
@@ -914,7 +869,7 @@ class StorageMapMixin(SetUpMixin):
                         "allowed": sorted(list(STORAGE_MAP_OPTIONS)),
                         "allowed_patterns": [],
                     },
-                    report_codes.FORCE_OPTIONS,
+                    report_codes.FORCE,
                 ),
             ]
         )
@@ -1260,7 +1215,9 @@ class WaitMixin(FixturesMixin, SetUpMixin):
         )
 
     @mock.patch.object(
-        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+        settings,
+        "pacemaker_api_result_schema",
+        rc("pcmk_api_rng/api-result.rng"),
     )
     def test_wait_ok_run_ok(self):
         (
@@ -1278,7 +1235,9 @@ class WaitMixin(FixturesMixin, SetUpMixin):
         )
 
     @mock.patch.object(
-        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+        settings,
+        "pacemaker_api_result_schema",
+        rc("pcmk_api_rng/api-result.rng"),
     )
     def test_wait_ok_run_fail(self):
         (
@@ -1298,7 +1257,9 @@ class WaitMixin(FixturesMixin, SetUpMixin):
         )
 
     @mock.patch.object(
-        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+        settings,
+        "pacemaker_api_result_schema",
+        rc("pcmk_api_rng/api-result.rng"),
     )
     def test_disabled_wait_ok_run_ok(self):
         (
@@ -1322,7 +1283,9 @@ class WaitMixin(FixturesMixin, SetUpMixin):
         )
 
     @mock.patch.object(
-        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+        settings,
+        "pacemaker_api_result_schema",
+        rc("pcmk_api_rng/api-result.rng"),
     )
     def test_disabled_wait_ok_run_fail(self):
         (
