@@ -3,7 +3,6 @@ from unittest import TestCase
 from pcs_test.tier0.lib.commands.resource.bundle_common import (
     FixturesMixin,
     SetUpMixin,
-    UpgradeMixin,
     ParametrizedContainerMixin,
     NetworkMixin,
     PortMapMixin,
@@ -68,7 +67,9 @@ class MinimalMixin(BaseMixin, SetUpMixin):
                 ),
             }
         )
-        self.bundle_reset(container_options={"image": new_image},)
+        self.bundle_reset(
+            container_options={"image": new_image},
+        )
 
     def test_noexistent_id(self):
         self.env_assist.assert_raise_library_error(
@@ -186,7 +187,9 @@ class FullMixin(SetUpMixin, BaseMixin):
             }
         )
 
-        self.bundle_reset(container_options={"image": new_image},)
+        self.bundle_reset(
+            container_options={"image": new_image},
+        )
 
     def test_success_full(self):
         new_image = "{0}:new".format(self.image)
@@ -266,7 +269,9 @@ class FullMixin(SetUpMixin, BaseMixin):
                     "target-dir": f"/tmp/{self.container_type}2bb",
                 },
             ],
-            meta_attributes={"target-role": "Started",},
+            meta_attributes={
+                "target-role": "Started",
+            },
         )
 
     def test_success_keep_map_ids(self):
@@ -336,13 +341,13 @@ class FullMixin(SetUpMixin, BaseMixin):
                     "target-dir": f"/tmp/{self.container_type}2bb",
                 },
             ],
-            meta_attributes={"target-role": "Stopped",},
+            meta_attributes={
+                "target-role": "Stopped",
+            },
         )
 
 
-class ResetParametrizedContainerMixin(
-    BaseMixin, ParametrizedContainerMixin, UpgradeMixin
-):
+class ResetParametrizedContainerMixin(BaseMixin, ParametrizedContainerMixin):
     pass
 
 
@@ -372,17 +377,14 @@ class FullDocker(FullMixin, TestCase):
 
 class ResetParametrizedPodman(ResetParametrizedContainerMixin, TestCase):
     container_type = "podman"
-    old_version_cib_filename = "cib-empty-2.6.xml"
 
 
 class ResetParametrizedDocker(ResetParametrizedContainerMixin, TestCase):
     container_type = "docker"
-    old_version_cib_filename = "cib-empty-2.0.xml"
 
 
 class ResetParametrizedRkt(ResetParametrizedContainerMixin, TestCase):
     container_type = "rkt"
-    old_version_cib_filename = "cib-empty-2.6.xml"
 
 
 class ResetWithNetwork(BaseMixin, NetworkMixin, TestCase):
@@ -424,7 +426,10 @@ class ResetWithMetaMap(BaseMixin, MetaMixin, TestCase):
             )
         )
         self.run_bundle_cmd(
-            meta_attributes={"target-role": "Stopped", "is-managed": "false",}
+            meta_attributes={
+                "target-role": "Stopped",
+                "is-managed": "false",
+            }
         )
 
 
@@ -502,7 +507,9 @@ class NoMetaIdRegenerationMixin(BaseMixin, SetUpMixin):
                 "replicas": "1",
                 "replicas-per-host": "1",
             },
-            meta_attributes={"target-role": "Stopped",},
+            meta_attributes={
+                "target-role": "Stopped",
+            },
         )
 
 
