@@ -102,35 +102,6 @@ class Basics(TestCase):
         )
         resource.bundle_update(self.env_assist.get_env(), "B1")
 
-    def test_cib_upgrade(self):
-        (
-            self.config.runner.cib.load(
-                filename="cib-empty-2.0.xml", name="load_cib_old_version"
-            )
-            .runner.cib.upgrade()
-            .runner.cib.load(
-                resources="""
-                    <resources>
-                        <bundle id="B1">
-                            <docker image="pcs:test" />
-                        </bundle>
-                    </resources>
-                """
-            )
-            .env.push_cib()
-        )
-        resource.bundle_update(self.env_assist.get_env(), "B1")
-        self.env_assist.assert_reports(
-            [
-                (
-                    severities.INFO,
-                    report_codes.CIB_UPGRADE_SUCCESSFUL,
-                    {},
-                    None,
-                ),
-            ]
-        )
-
 
 class ContainerParametrized(TestCase):
     allowed_options = [
@@ -286,7 +257,7 @@ class ContainerParametrized(TestCase):
                         "allowed": self.allowed_options,
                         "allowed_patterns": [],
                     },
-                    report_codes.FORCE_OPTIONS,
+                    report_codes.FORCE,
                 ),
             ]
         )
@@ -341,53 +312,6 @@ class ContainerParametrized(TestCase):
             force_options=True,
         )
 
-    def _test_cib_upgrade_on_promoted_max(self):
-        (
-            self.config.runner.cib.load(
-                filename="cib-empty-2.8.xml", name="load_cib_old_version"
-            )
-            .runner.cib.upgrade()
-            .runner.cib.load(
-                resources="""
-                    <resources>
-                        <bundle id="B1">
-                            <{container_type} image="pcs:test" />
-                        </bundle>
-                    </resources>
-                """.format(
-                    container_type=self.container_type
-                )
-            )
-            .env.push_cib(
-                resources="""
-                    <resources>
-                        <bundle id="B1">
-                            <{container_type} image="pcs:test" promoted-max="1" />
-                        </bundle>
-                    </resources>
-                """.format(
-                    container_type=self.container_type
-                )
-            )
-        )
-        resource.bundle_update(
-            self.env_assist.get_env(),
-            "B1",
-            container_options={
-                "promoted-max": "1",
-            },
-        )
-        self.env_assist.assert_reports(
-            [
-                (
-                    severities.INFO,
-                    report_codes.CIB_UPGRADE_SUCCESSFUL,
-                    {},
-                    None,
-                ),
-            ]
-        )
-
     def _test_options_error(self):
         self.config.runner.cib.load(
             resources=fixture_resources_minimal(self.container_type)
@@ -899,7 +823,7 @@ class Network(TestCase):
                         "allowed": self.allowed_options,
                         "allowed_patterns": [],
                     },
-                    report_codes.FORCE_OPTIONS,
+                    report_codes.FORCE,
                 ),
             ]
         )
@@ -1453,7 +1377,9 @@ class Wait(TestCase):
         )
 
     @mock.patch.object(
-        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+        settings,
+        "pacemaker_api_result_schema",
+        rc("pcmk_api_rng/api-result.rng"),
     )
     def test_wait_ok_running(self):
         (
@@ -1471,7 +1397,9 @@ class Wait(TestCase):
         )
 
     @mock.patch.object(
-        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+        settings,
+        "pacemaker_api_result_schema",
+        rc("pcmk_api_rng/api-result.rng"),
     )
     def test_wait_ok_not_running(self):
         (
@@ -1590,7 +1518,7 @@ class WithPrimitive(TestCase):
                     report_codes.RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE,
                     bundle_id="B1",
                     inner_resource_id="P",
-                    force_code=report_codes.FORCE_OPTIONS,
+                    force_code=report_codes.FORCE,
                 )
             ]
         )
@@ -1704,7 +1632,7 @@ class WithPrimitive(TestCase):
                     report_codes.RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE,
                     bundle_id="B1",
                     inner_resource_id="P",
-                    force_code=report_codes.FORCE_OPTIONS,
+                    force_code=report_codes.FORCE,
                 )
             ]
         )
@@ -1762,7 +1690,7 @@ class WithPrimitive(TestCase):
                     report_codes.RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE,
                     bundle_id="B1",
                     inner_resource_id="P",
-                    force_code=report_codes.FORCE_OPTIONS,
+                    force_code=report_codes.FORCE,
                 )
             ]
         )
