@@ -1,12 +1,9 @@
 from textwrap import dedent
 from unittest import mock, TestCase
 
-from lxml import etree
-
 from pcs_test.tools import fixture
 from pcs_test.tools.command_env import get_env_tools
 from pcs_test.tools.misc import get_test_resource as rc
-from pcs_test.tools.xml import etree_to_str
 
 from pcs import settings
 from pcs.common.reports import ReportItemSeverity as severities
@@ -275,11 +272,14 @@ class MoveBanWaitMixin:
     # pylint does not and can not know setUp is a method of TestCase
     # pylint: disable=invalid-name
     def setUp(self):
+        self.timeout = 10
         self.env_assist, self.config = get_env_tools(self)
         self.config.runner.cib.load(resources=resources_primitive)
 
     @mock.patch.object(
-        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+        settings,
+        "pacemaker_api_result_schema",
+        rc("pcmk_api_rng/api-result.rng"),
     )
     def test_state_before_action_fail(self):
         self.config.runner.pcmk.load_state(
@@ -297,12 +297,16 @@ class MoveBanWaitMixin:
         )
 
     @mock.patch.object(
-        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+        settings,
+        "pacemaker_api_result_schema",
+        rc("pcmk_api_rng/api-result.rng"),
     )
     def test_state_before_action_not_xml(self):
         self.config.runner.pcmk.load_state(stdout="state stdout")
         self.env_assist.assert_raise_library_error(
-            lambda: self.lib_action(self.env_assist.get_env(), "A", wait="10"),
+            lambda: self.lib_action(
+                self.env_assist.get_env(), "A", wait=str(self.timeout)
+            ),
             [
                 fixture.error(
                     report_codes.BAD_CLUSTER_STATE_FORMAT,
@@ -312,13 +316,17 @@ class MoveBanWaitMixin:
         )
 
     @mock.patch.object(
-        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+        settings,
+        "pacemaker_api_result_schema",
+        rc("pcmk_api_rng/api-result.rng"),
     )
     def test_pcmk_fail(self):
         self.config.runner.pcmk.load_state()
         self.config_pcmk_action(returncode=1)
         self.env_assist.assert_raise_library_error(
-            lambda: self.lib_action(self.env_assist.get_env(), "A", wait="10"),
+            lambda: self.lib_action(
+                self.env_assist.get_env(), "A", wait=str(self.timeout)
+            ),
             [
                 fixture.error(
                     self.report_code_pcmk_error,
@@ -331,17 +339,21 @@ class MoveBanWaitMixin:
         )
 
     @mock.patch.object(
-        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+        settings,
+        "pacemaker_api_result_schema",
+        rc("pcmk_api_rng/api-result.rng"),
     )
     def test_wait_fail(self):
         self.config.runner.pcmk.load_state()
         self.config_pcmk_action()
         self.config.runner.pcmk.wait(
-            timeout=10, stderr="wait error", returncode=1
+            timeout=self.timeout, stderr="wait error", returncode=1
         )
 
         self.env_assist.assert_raise_library_error(
-            lambda: self.lib_action(self.env_assist.get_env(), "A", wait="10"),
+            lambda: self.lib_action(
+                self.env_assist.get_env(), "A", wait=str(self.timeout)
+            ),
             [
                 fixture.error(
                     report_codes.WAIT_FOR_IDLE_ERROR,
@@ -358,16 +370,22 @@ class MoveBanWaitMixin:
                     stdout="pcmk std out",
                     stderr="pcmk std err",
                 ),
+                fixture.info(
+                    report_codes.WAIT_FOR_IDLE_STARTED,
+                    timeout=self.timeout,
+                ),
             ]
         )
 
     @mock.patch.object(
-        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+        settings,
+        "pacemaker_api_result_schema",
+        rc("pcmk_api_rng/api-result.rng"),
     )
     def test_state_after_action_fail(self):
         self.config.runner.pcmk.load_state()
         self.config_pcmk_action()
-        self.config.runner.pcmk.wait(timeout=10)
+        self.config.runner.pcmk.wait(timeout=self.timeout)
         self.config.runner.pcmk.load_state(
             name="runner.pcmk.load_state.after",
             stdout="state stdout",
@@ -375,7 +393,9 @@ class MoveBanWaitMixin:
             returncode=1,
         )
         self.env_assist.assert_raise_library_error(
-            lambda: self.lib_action(self.env_assist.get_env(), "A", wait="10"),
+            lambda: self.lib_action(
+                self.env_assist.get_env(), "A", wait=self.timeout
+            ),
             [
                 fixture.error(
                     report_codes.CRM_MON_ERROR,
@@ -392,21 +412,29 @@ class MoveBanWaitMixin:
                     stdout="pcmk std out",
                     stderr="pcmk std err",
                 ),
+                fixture.info(
+                    report_codes.WAIT_FOR_IDLE_STARTED,
+                    timeout=self.timeout,
+                ),
             ]
         )
 
     @mock.patch.object(
-        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+        settings,
+        "pacemaker_api_result_schema",
+        rc("pcmk_api_rng/api-result.rng"),
     )
     def test_state_after_action_not_xml(self):
         self.config.runner.pcmk.load_state()
         self.config_pcmk_action()
-        self.config.runner.pcmk.wait(timeout=10)
+        self.config.runner.pcmk.wait(timeout=self.timeout)
         self.config.runner.pcmk.load_state(
             name="runner.pcmk.load_state.after", stdout="state stdout"
         )
         self.env_assist.assert_raise_library_error(
-            lambda: self.lib_action(self.env_assist.get_env(), "A", wait="10"),
+            lambda: self.lib_action(
+                self.env_assist.get_env(), "A", wait=self.timeout
+            ),
             [
                 fixture.error(
                     report_codes.BAD_CLUSTER_STATE_FORMAT,
@@ -422,13 +450,19 @@ class MoveBanWaitMixin:
                     stdout="pcmk std out",
                     stderr="pcmk std err",
                 ),
+                fixture.info(
+                    report_codes.WAIT_FOR_IDLE_STARTED,
+                    timeout=self.timeout,
+                ),
             ]
         )
 
     def test_was_running_now_stopped(self):
         self.success_config(self.state_running_node1, self.state_not_running)
         self.env_assist.assert_raise_library_error(
-            lambda: self.lib_action(self.env_assist.get_env(), "A", wait="10")
+            lambda: self.lib_action(
+                self.env_assist.get_env(), "A", wait=self.timeout
+            )
         )
         self.env_assist.assert_reports(
             [
@@ -438,6 +472,10 @@ class MoveBanWaitMixin:
                     stdout="pcmk std out",
                     stderr="pcmk std err",
                 ),
+                fixture.info(
+                    report_codes.WAIT_FOR_IDLE_STARTED,
+                    timeout=self.timeout,
+                ),
                 fixture.report_resource_not_running(
                     "A", severity=severities.ERROR
                 ),
@@ -446,7 +484,7 @@ class MoveBanWaitMixin:
 
     def test_was_stopped_now_stopped(self):
         self.success_config(self.state_not_running, self.state_not_running)
-        self.lib_action(self.env_assist.get_env(), "A", wait="10")
+        self.lib_action(self.env_assist.get_env(), "A", wait=self.timeout)
         self.env_assist.assert_reports(
             [
                 fixture.info(
@@ -455,6 +493,10 @@ class MoveBanWaitMixin:
                     stdout="pcmk std out",
                     stderr="pcmk std err",
                 ),
+                fixture.info(
+                    report_codes.WAIT_FOR_IDLE_STARTED,
+                    timeout=self.timeout,
+                ),
                 fixture.report_resource_not_running(
                     "A",
                 ),
@@ -464,7 +506,9 @@ class MoveBanWaitMixin:
     def test_running_on_same_node_no_node_specified(self):
         self.success_config(self.state_running_node1, self.state_running_node1)
         self.env_assist.assert_raise_library_error(
-            lambda: self.lib_action(self.env_assist.get_env(), "A", wait="10")
+            lambda: self.lib_action(
+                self.env_assist.get_env(), "A", wait=self.timeout
+            )
         )
         self.env_assist.assert_reports(
             [
@@ -474,6 +518,10 @@ class MoveBanWaitMixin:
                     stdout="pcmk std out",
                     stderr="pcmk std err",
                 ),
+                fixture.info(
+                    report_codes.WAIT_FOR_IDLE_STARTED,
+                    timeout=self.timeout,
+                ),
                 fixture.report_resource_running(
                     "A", {"Started": ["node1"]}, severity=severities.ERROR
                 ),
@@ -482,7 +530,7 @@ class MoveBanWaitMixin:
 
     def test_running_on_onther_node_no_node_specified(self):
         self.success_config(self.state_running_node1, self.state_running_node2)
-        self.lib_action(self.env_assist.get_env(), "A", wait="10")
+        self.lib_action(self.env_assist.get_env(), "A", wait=self.timeout)
         self.env_assist.assert_reports(
             [
                 fixture.info(
@@ -491,6 +539,10 @@ class MoveBanWaitMixin:
                     stdout="pcmk std out",
                     stderr="pcmk std err",
                 ),
+                fixture.info(
+                    report_codes.WAIT_FOR_IDLE_STARTED,
+                    timeout=self.timeout,
+                ),
                 fixture.report_resource_running(
                     "A",
                     {"Started": ["node2"]},
@@ -498,25 +550,19 @@ class MoveBanWaitMixin:
             ]
         )
 
-    @staticmethod
-    def _prepare_state(state):
-        return etree_to_str(
-            fixture.complete_state_resources(etree.fromstring(state))
-        )
-
     def success_config(self, state_before, state_after, action_node=None):
-        self.config.runner.pcmk.load_state(
-            resources=self._prepare_state(state_before)
-        )
+        self.config.runner.pcmk.load_state(resources=state_before)
         self.config_pcmk_action(node=action_node)
-        self.config.runner.pcmk.wait(timeout=10)
+        self.config.runner.pcmk.wait(timeout=self.timeout)
         self.config.runner.pcmk.load_state(
             name="runner.pcmk.load_state.after",
-            resources=self._prepare_state(state_after),
+            resources=state_after,
         )
 
 
-@mock.patch.object(settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng"))
+@mock.patch.object(
+    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+)
 class MoveWait(MoveMixin, MoveBanWaitMixin, TestCase):
     def test_running_on_specified_node(self):
         self.success_config(
@@ -524,7 +570,9 @@ class MoveWait(MoveMixin, MoveBanWaitMixin, TestCase):
             self.state_running_node2,
             action_node="node2",
         )
-        self.lib_action(self.env_assist.get_env(), "A", node="node2", wait="10")
+        self.lib_action(
+            self.env_assist.get_env(), "A", node="node2", wait=self.timeout
+        )
         self.env_assist.assert_reports(
             [
                 fixture.info(
@@ -533,6 +581,10 @@ class MoveWait(MoveMixin, MoveBanWaitMixin, TestCase):
                     stdout="pcmk std out",
                     stderr="pcmk std err",
                 ),
+                fixture.info(
+                    report_codes.WAIT_FOR_IDLE_STARTED,
+                    timeout=self.timeout,
+                ),
                 fixture.report_resource_running(
                     "A",
                     {"Started": ["node2"]},
@@ -548,7 +600,7 @@ class MoveWait(MoveMixin, MoveBanWaitMixin, TestCase):
         )
         self.env_assist.assert_raise_library_error(
             lambda: self.lib_action(
-                self.env_assist.get_env(), "A", node="node2", wait="10"
+                self.env_assist.get_env(), "A", node="node2", wait=self.timeout
             )
         )
         self.env_assist.assert_reports(
@@ -559,6 +611,10 @@ class MoveWait(MoveMixin, MoveBanWaitMixin, TestCase):
                     stdout="pcmk std out",
                     stderr="pcmk std err",
                 ),
+                fixture.info(
+                    report_codes.WAIT_FOR_IDLE_STARTED,
+                    timeout=self.timeout,
+                ),
                 fixture.report_resource_running(
                     "A", {"Started": ["node1"]}, severity=severities.ERROR
                 ),
@@ -566,7 +622,9 @@ class MoveWait(MoveMixin, MoveBanWaitMixin, TestCase):
         )
 
 
-@mock.patch.object(settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng"))
+@mock.patch.object(
+    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+)
 class BanWait(BanMixin, MoveBanWaitMixin, TestCase):
     def test_running_on_specified_node(self):
         self.success_config(
@@ -576,7 +634,7 @@ class BanWait(BanMixin, MoveBanWaitMixin, TestCase):
         )
         self.env_assist.assert_raise_library_error(
             lambda: self.lib_action(
-                self.env_assist.get_env(), "A", node="node1", wait="10"
+                self.env_assist.get_env(), "A", node="node1", wait=self.timeout
             )
         )
         self.env_assist.assert_reports(
@@ -587,6 +645,10 @@ class BanWait(BanMixin, MoveBanWaitMixin, TestCase):
                     stdout="pcmk std out",
                     stderr="pcmk std err",
                 ),
+                fixture.info(
+                    report_codes.WAIT_FOR_IDLE_STARTED,
+                    timeout=self.timeout,
+                ),
                 fixture.report_resource_running(
                     "A", {"Started": ["node1"]}, severity=severities.ERROR
                 ),
@@ -599,7 +661,9 @@ class BanWait(BanMixin, MoveBanWaitMixin, TestCase):
             self.state_running_node2,
             action_node="node1",
         )
-        self.lib_action(self.env_assist.get_env(), "A", node="node1", wait="10")
+        self.lib_action(
+            self.env_assist.get_env(), "A", node="node1", wait=self.timeout
+        )
         self.env_assist.assert_reports(
             [
                 fixture.info(
@@ -608,6 +672,10 @@ class BanWait(BanMixin, MoveBanWaitMixin, TestCase):
                     stdout="pcmk std out",
                     stderr="pcmk std err",
                 ),
+                fixture.info(
+                    report_codes.WAIT_FOR_IDLE_STARTED,
+                    timeout=self.timeout,
+                ),
                 fixture.report_resource_running(
                     "A",
                     {"Started": ["node2"]},
@@ -616,31 +684,28 @@ class BanWait(BanMixin, MoveBanWaitMixin, TestCase):
         )
 
 
-@mock.patch.object(settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng"))
+@mock.patch.object(
+    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+)
 class UnmoveUnbanWait(UnmoveUnbanMixin, TestCase):
     def setUp(self):
+        self.timeout = 10
         self.env_assist, self.config = get_env_tools(self)
         self.config.runner.cib.load(resources=resources_primitive)
         self.config_pcmk_action()
 
     def test_success(self):
-        resources_state = etree_to_str(
-            fixture.complete_state_resources(
-                etree.fromstring(
-                    """
-                <resources>
-                    <resource id="A" role="Started" nodes_running_on="1">
-                         <node name="node1" id="1" cached="false" />
-                     </resource>
-                </resources>
-            """
-                )
-            )
-        )
-        self.config.runner.pcmk.wait(timeout=10)
+        resources_state = """
+            <resources>
+                <resource id="A" role="Started" nodes_running_on="1">
+                     <node name="node1" id="1" cached="false" />
+                 </resource>
+            </resources>
+        """
+        self.config.runner.pcmk.wait(timeout=self.timeout)
         self.config.runner.pcmk.load_state(resources=resources_state)
 
-        self.lib_action(self.env_assist.get_env(), "A", wait="10")
+        self.lib_action(self.env_assist.get_env(), "A", wait=self.timeout)
         self.env_assist.assert_reports(
             [
                 fixture.info(
@@ -649,17 +714,23 @@ class UnmoveUnbanWait(UnmoveUnbanMixin, TestCase):
                     stdout="pcmk std out",
                     stderr="pcmk std err",
                 ),
+                fixture.info(
+                    report_codes.WAIT_FOR_IDLE_STARTED,
+                    timeout=self.timeout,
+                ),
                 fixture.report_resource_running("A", {"Started": ["node1"]}),
             ]
         )
 
     def test_get_state_fail(self):
-        self.config.runner.pcmk.wait(timeout=10)
+        self.config.runner.pcmk.wait(timeout=self.timeout)
         self.config.runner.pcmk.load_state(
             stdout="state stdout", stderr="state stderr", returncode=1
         )
         self.env_assist.assert_raise_library_error(
-            lambda: self.lib_action(self.env_assist.get_env(), "A", wait="10"),
+            lambda: self.lib_action(
+                self.env_assist.get_env(), "A", wait=self.timeout
+            ),
             [
                 fixture.error(
                     report_codes.CRM_MON_ERROR,
@@ -676,14 +747,20 @@ class UnmoveUnbanWait(UnmoveUnbanMixin, TestCase):
                     stdout="pcmk std out",
                     stderr="pcmk std err",
                 ),
+                fixture.info(
+                    report_codes.WAIT_FOR_IDLE_STARTED,
+                    timeout=self.timeout,
+                ),
             ]
         )
 
     def test_get_state_not_xml(self):
-        self.config.runner.pcmk.wait(timeout=10)
+        self.config.runner.pcmk.wait(timeout=self.timeout)
         self.config.runner.pcmk.load_state(stdout="state stdout")
         self.env_assist.assert_raise_library_error(
-            lambda: self.lib_action(self.env_assist.get_env(), "A", wait="10"),
+            lambda: self.lib_action(
+                self.env_assist.get_env(), "A", wait=self.timeout
+            ),
             [
                 fixture.error(
                     report_codes.BAD_CLUSTER_STATE_FORMAT,
@@ -699,16 +776,22 @@ class UnmoveUnbanWait(UnmoveUnbanMixin, TestCase):
                     stdout="pcmk std out",
                     stderr="pcmk std err",
                 ),
+                fixture.info(
+                    report_codes.WAIT_FOR_IDLE_STARTED,
+                    timeout=self.timeout,
+                ),
             ]
         )
 
     def test_wait_fail(self):
         self.config.runner.pcmk.wait(
-            timeout=10, stderr="wait error", returncode=1
+            timeout=self.timeout, stderr="wait error", returncode=1
         )
 
         self.env_assist.assert_raise_library_error(
-            lambda: self.lib_action(self.env_assist.get_env(), "A", wait="10"),
+            lambda: self.lib_action(
+                self.env_assist.get_env(), "A", wait=self.timeout
+            ),
             [
                 fixture.error(
                     report_codes.WAIT_FOR_IDLE_ERROR,
@@ -725,5 +808,9 @@ class UnmoveUnbanWait(UnmoveUnbanMixin, TestCase):
                     stdout="pcmk std out",
                     stderr="pcmk std err",
                 ),
+                fixture.info(
+                    report_codes.WAIT_FOR_IDLE_STARTED,
+                    timeout=self.timeout,
+                ),
             ]
         )
