@@ -1,4 +1,3 @@
-import logging
 from unittest import mock, TestCase
 
 from pcs_test.tools import fixture
@@ -6,9 +5,8 @@ from pcs_test.tools.assertions import (
     assert_raise_library_error,
     assert_report_item_list_equal,
 )
-from pcs_test.tools.custom_mock import MockLibraryReportProcessor
-from pcs_test.tools.integration_lib import Runner
-from pcs_test.tools.command_env.mock_runner import Call
+from pcs_test.tools.command_env import get_env_tools
+from pcs_test.tools.misc import outdent
 
 from pcs import settings
 from pcs.common import reports
@@ -18,15 +16,11 @@ from pcs.common.reports import (
     ReportItemSeverity as Severities,
 )
 from pcs.lib.errors import LibraryError
-from pcs.lib.env import LibraryEnvironment
 import pcs.lib.commands.sbd as cmd_sbd
 
 # pylint: disable=protected-access
 
 
-runner = Runner()
-
-
 def _assert_equal_list_of_dictionaries_without_order(expected, actual):
     for item in actual:
         if item not in expected:
@@ -86,7 +80,7 @@ class ValidateSbdOptionsTest(TestCase):
             [
                 fixture.error(
                     reports.codes.INVALID_OPTION_VALUE,
-                    force_code=reports.codes.FORCE_OPTIONS,
+                    force_code=reports.codes.FORCE,
                     option_name="SBD_TIMEOUT_ACTION",
                     option_value="flush,noflush",
                     allowed_values=self.timeout_action_allowed_values,
@@ -135,7 +129,7 @@ class ValidateSbdOptionsTest(TestCase):
                     option_type=None,
                     allowed=self.allowed_sbd_options,
                     allowed_patterns=[],
-                    force_code=reports.codes.FORCE_OPTIONS,
+                    force_code=reports.codes.FORCE,
                 ),
             ],
         )
@@ -215,7 +209,7 @@ class ValidateSbdOptionsTest(TestCase):
                     option_type=None,
                     allowed=self.allowed_sbd_options,
                     allowed_patterns=[],
-                    force_code=reports.codes.FORCE_OPTIONS,
+                    force_code=reports.codes.FORCE,
                 ),
             ],
         )
@@ -380,18 +374,23 @@ class GetFullTargetDictTest(TestCase):
         )
 
 
-@mock.patch("pcs.lib.sbd.get_local_sbd_config")
 class GetLocalSbdConfigTest(TestCase):
     def setUp(self):
-        self.mock_env = mock.MagicMock(spec_set=LibraryEnvironment)
+        self.env_assist, self.config = get_env_tools(self)
 
-    def test_success(self, mock_config):
-        mock_config.return_value = """
-# This file has been generated by pcs.
-SBD_OPTS="-n node1"
-SBD_WATCHDOG_DEV=/dev/watchdog
-SBD_WATCHDOG_TIMEOUT=0
-"""
+    def test_success(self):
+        config_content = outdent(
+            """\
+            # This file has been generated by pcs.
+            SBD_OPTS="-n node1"
+            SBD_WATCHDOG_DEV=/dev/watchdog
+            SBD_WATCHDOG_TIMEOUT=0
+            """
+        )
+        self.config.fs.open(
+            settings.sbd_config,
+            mock.mock_open(read_data=config_content)(),
+        )
 
         self.assertEqual(
             {
@@ -399,20 +398,22 @@ SBD_WATCHDOG_TIMEOUT=0
                 "SBD_WATCHDOG_DEV": "/dev/watchdog",
                 "SBD_WATCHDOG_TIMEOUT": "0",
             },
-            cmd_sbd.get_local_sbd_config(self.mock_env),
+            cmd_sbd.get_local_sbd_config(self.env_assist.get_env()),
         )
-        self.assertEqual(1, mock_config.call_count)
 
-    def test_file_error(self, mock_config):
+    def test_file_error(self):
         node = "node"
         reason = "reason"
-        mock_config.side_effect = LibraryError(
-            ReportItem.error(
-                reports.messages.UnableToGetSbdConfig(node, reason)
-            )
+        self.config.fs.open(
+            settings.sbd_config,
+            side_effect=LibraryError(
+                ReportItem.error(
+                    reports.messages.UnableToGetSbdConfig(node, reason)
+                )
+            ),
         )
         assert_raise_library_error(
-            lambda: cmd_sbd.get_local_sbd_config(self.mock_env),
+            lambda: cmd_sbd.get_local_sbd_config(self.env_assist.get_env()),
             (
                 Severities.ERROR,
                 reports.codes.UNABLE_TO_GET_SBD_CONFIG,
@@ -424,38 +425,9 @@ SBD_WATCHDOG_TIMEOUT=0
         )
 
 
-class CommonTest(TestCase):
-    @classmethod
-    def setUpClass(cls):
-        cls.patcher = mock.patch.object(
-            LibraryEnvironment, "cmd_runner", lambda self: runner
-        )
-        cls.patcher.start()
-
-    @classmethod
-    def tearDownClass(cls):
-        cls.patcher.stop()
-
+class InitializeBlockDevicesTest(TestCase):
     def setUp(self):
-        self.env = LibraryEnvironment(
-            mock.MagicMock(logging.Logger), MockLibraryReportProcessor()
-        )
-
-
-class InitializeBlockDevicesTest(CommonTest):
-    @staticmethod
-    def fixture_sbd_init(
-        device_list, options, stdout="", stderr="", return_code=0
-    ):
-        cmd = ["sbd"]
-        for device in device_list:
-            cmd += ["-d", device]
-
-        for opt, val in options:
-            cmd += [opt, val]
-
-        cmd.append("create")
-        return [Call(cmd, stdout, stderr, return_code)]
+        self.env_assist, self.config = get_env_tools(self)
 
     @staticmethod
     def fixture_invalid_value(option, value):
@@ -476,20 +448,11 @@ class InitializeBlockDevicesTest(CommonTest):
             "allocate-timeout": "3",
             "msgwait-timeout": "2",
         }
-        runner.set_runs(
-            self.fixture_sbd_init(
-                device_list,
-                [
-                    ("-2", "3"),
-                    ("-3", "10"),
-                    ("-4", "2"),
-                    ("-1", "1"),
-                ],
-            )
+        self.config.runner.sbd.initialize_devices(device_list, option_dict)
+        cmd_sbd.initialize_block_devices(
+            self.env_assist.get_env(), device_list, option_dict
         )
-        cmd_sbd.initialize_block_devices(self.env, device_list, option_dict)
-        runner.assert_everything_launched()
-        self.env.report_processor.assert_reports(
+        self.env_assist.assert_reports(
             [
                 (
                     Severities.INFO,
@@ -506,10 +469,11 @@ class InitializeBlockDevicesTest(CommonTest):
 
     def test_no_options(self):
         device_list = ["dev1", "dev2"]
-        runner.set_runs(self.fixture_sbd_init(device_list, {}))
-        cmd_sbd.initialize_block_devices(self.env, device_list, {})
-        runner.assert_everything_launched()
-        self.env.report_processor.assert_reports(
+        self.config.runner.sbd.initialize_devices(device_list, {})
+        cmd_sbd.initialize_block_devices(
+            self.env_assist.get_env(), device_list, {}
+        )
+        self.env_assist.assert_reports(
             [
                 (
                     Severities.INFO,
@@ -539,11 +503,12 @@ class InitializeBlockDevicesTest(CommonTest):
             "allocate-timeout",
             "msgwait-timeout",
         ]
-        assert_raise_library_error(
-            lambda: cmd_sbd.initialize_block_devices(self.env, [], option_dict)
+        self.env_assist.assert_raise_library_error(
+            lambda: cmd_sbd.initialize_block_devices(
+                self.env_assist.get_env(), [], option_dict
+            )
         )
-        assert_report_item_list_equal(
-            self.env.report_processor.report_item_list,
+        self.env_assist.assert_reports(
             [
                 (
                     Severities.ERROR,
@@ -571,34 +536,20 @@ class InitializeBlockDevicesTest(CommonTest):
         )
 
 
-@mock.patch("os.path.exists")
-@mock.patch("pcs.lib.sbd.get_local_sbd_config")
-@mock.patch("pcs.lib.external.is_systemctl", lambda: True)
-class GetLocalDevicesInfoTest(CommonTest):
-    @staticmethod
-    def fixture_sbd_enabled(enabled):
-        cmd = [settings.systemctl_binary, "is-enabled", "sbd.service"]
-        return [Call(cmd, returncode=0 if enabled else 1)]
+class GetLocalDevicesInfoTest(TestCase):
+    def setUp(self):
+        self.env_assist, self.config = get_env_tools(self)
 
-    @staticmethod
-    def fixture_sbd_info(device, stdout="", return_code=0):
-        cmd = ["sbd", "-d", device, "list"]
-        return [Call(cmd, stdout, returncode=return_code)]
-
-    @staticmethod
-    def fixture_sbd_dump(device, stdout="", return_code=0):
-        cmd = ["sbd", "-d", device, "dump"]
-        return [Call(cmd, stdout, returncode=return_code)]
-
-    def test_success(self, mock_config, mock_config_exists):
-        mock_config_exists.return_value = True
-        mock_config.return_value = """
-SBD_DEVICE="/dev1;/dev2"
-        """
-        runner.set_runs(
-            self.fixture_sbd_enabled(True)
-            + self.fixture_sbd_info("/dev1", "1")
-            + self.fixture_sbd_info("/dev2", "2")
+    def test_success(self):
+        config_data = 'SBD_DEVICE="/dev1;/dev2"\n'
+        self.config.services.is_enabled("sbd")
+        self.config.fs.exists(settings.sbd_config, return_value=True)
+        self.config.fs.open(
+            settings.sbd_config, mock.mock_open(read_data=config_data)()
+        )
+        self.config.runner.sbd.get_device_info("/dev1", stdout="1")
+        self.config.runner.sbd.get_device_info(
+            "/dev2", stdout="2", name="list2"
         )
         expected_output = [
             {
@@ -613,71 +564,78 @@ SBD_DEVICE="/dev1;/dev2"
             },
         ]
         self.assertEqual(
-            expected_output, cmd_sbd.get_local_devices_info(self.env)
+            expected_output,
+            cmd_sbd.get_local_devices_info(self.env_assist.get_env()),
         )
-        runner.assert_everything_launched()
-        mock_config.assert_called_once_with()
-        mock_config_exists.assert_called_once_with(settings.sbd_config)
 
-    def test_with_dump(self, mock_config, mock_config_exists):
-        mock_config_exists.return_value = True
-        mock_config.return_value = """
-SBD_DEVICE="/dev1;/dev2"
-        """
-        runner.set_runs(
-            self.fixture_sbd_enabled(True)
-            + self.fixture_sbd_info("/dev1", "1")
-            + self.fixture_sbd_dump("/dev1", "3")
-            + self.fixture_sbd_info("/dev2", "2")
-            + self.fixture_sbd_dump("/dev2", "4")
+    def test_with_dump(self):
+        config_data = 'SBD_DEVICE="/dev1;/dev2"\n'
+        self.config.services.is_enabled("sbd")
+        self.config.fs.exists(settings.sbd_config, return_value=True)
+        self.config.fs.open(
+            settings.sbd_config, mock.mock_open(read_data=config_data)()
+        )
+        self.config.runner.sbd.get_device_info("/dev1", stdout="1")
+        self.config.runner.sbd.get_device_dump("/dev1", stdout="2")
+        self.config.runner.sbd.get_device_info(
+            "/dev2", stdout="3", name="list2"
+        )
+        self.config.runner.sbd.get_device_dump(
+            "/dev2", stdout="4", name="dump2"
         )
         expected_output = [
             {
                 "device": "/dev1",
                 "list": "1",
-                "dump": "3",
+                "dump": "2",
             },
             {
                 "device": "/dev2",
-                "list": "2",
+                "list": "3",
                 "dump": "4",
             },
         ]
         self.assertEqual(
-            expected_output, cmd_sbd.get_local_devices_info(self.env, dump=True)
+            expected_output,
+            cmd_sbd.get_local_devices_info(
+                self.env_assist.get_env(), dump=True
+            ),
         )
-        runner.assert_everything_launched()
-        mock_config.assert_called_once_with()
-        mock_config_exists.assert_called_once_with(settings.sbd_config)
 
-    def test_no_config(self, mock_config, mock_config_exists):
-        mock_config_exists.return_value = False
-        runner.set_runs(self.fixture_sbd_enabled(True))
-        self.assertEqual([], cmd_sbd.get_local_devices_info(self.env))
-        runner.assert_everything_launched()
-        self.assertEqual(0, mock_config.call_count)
-        mock_config_exists.assert_called_once_with(settings.sbd_config)
+    def test_no_config(self):
+        self.config.services.is_enabled("sbd")
+        self.config.fs.exists(settings.sbd_config, return_value=False)
+        self.assertEqual(
+            [], cmd_sbd.get_local_devices_info(self.env_assist.get_env())
+        )
 
-    def test_sbd_disabled(self, mock_config, mock_config_exists):
-        mock_config_exists.return_value = True
-        runner.set_runs(self.fixture_sbd_enabled(False))
-        self.assertEqual([], cmd_sbd.get_local_devices_info(self.env))
-        runner.assert_everything_launched()
-        self.assertEqual(0, mock_config.call_count)
-        self.assertEqual(0, mock_config_exists.call_count)
+    def test_sbd_disabled(self):
+        self.config.services.is_enabled("sbd", return_value=False)
+        self.assertEqual(
+            [], cmd_sbd.get_local_devices_info(self.env_assist.get_env())
+        )
 
-    def test_with_failures(self, mock_config, mock_config_exists):
-        mock_config_exists.return_value = True
-        mock_config.return_value = """
-SBD_DEVICE="/dev1;/dev2;/dev3"
-        """
-        runner.set_runs(
-            self.fixture_sbd_enabled(True)
-            + self.fixture_sbd_info("/dev1", "1", 1)
-            + self.fixture_sbd_info("/dev2", "2")
-            + self.fixture_sbd_dump("/dev2", "4", 1)
-            + self.fixture_sbd_info("/dev3", "5")
-            + self.fixture_sbd_dump("/dev3", "6")
+    def test_with_failures(self):
+        config_data = 'SBD_DEVICE="/dev1;/dev2;/dev3"\n'
+        self.config.services.is_enabled("sbd")
+        self.config.fs.exists(settings.sbd_config, return_value=True)
+        self.config.fs.open(
+            settings.sbd_config, mock.mock_open(read_data=config_data)()
+        )
+        self.config.runner.sbd.get_device_info(
+            "/dev1", stdout="1", return_code=1
+        )
+        self.config.runner.sbd.get_device_info(
+            "/dev2", stdout="2", name="list2"
+        )
+        self.config.runner.sbd.get_device_dump(
+            "/dev2", stdout="4", return_code=1
+        )
+        self.config.runner.sbd.get_device_info(
+            "/dev3", stdout="5", name="list3"
+        )
+        self.config.runner.sbd.get_device_dump(
+            "/dev3", stdout="6", name="dump2"
         )
         expected_output = [
             {
@@ -697,9 +655,12 @@ SBD_DEVICE="/dev1;/dev2;/dev3"
             },
         ]
         self.assertEqual(
-            expected_output, cmd_sbd.get_local_devices_info(self.env, dump=True)
+            expected_output,
+            cmd_sbd.get_local_devices_info(
+                self.env_assist.get_env(), dump=True
+            ),
         )
-        self.env.report_processor.assert_reports(
+        self.env_assist.assert_reports(
             [
                 (
                     Severities.WARNING,
@@ -713,30 +674,17 @@ SBD_DEVICE="/dev1;/dev2;/dev3"
                 ),
             ]
         )
-        runner.assert_everything_launched()
-        mock_config.assert_called_once_with()
-        mock_config_exists.assert_called_once_with(settings.sbd_config)
 
 
-class SetMessageTest(CommonTest):
-    @staticmethod
-    def fixture_call_sbd_message(
-        device, node, message, stderr="", return_code=0
-    ):
-        return [
-            Call(
-                ["sbd", "-d", device, "message", node, message],
-                stderr=stderr,
-                returncode=return_code,
-            )
-        ]
+class SetMessageTest(TestCase):
+    def setUp(self):
+        self.env_assist, self.config = get_env_tools(self)
 
     def test_empty_options(self):
-        assert_raise_library_error(
-            lambda: cmd_sbd.set_message(self.env, "", "", "")
+        self.env_assist.assert_raise_library_error(
+            lambda: cmd_sbd.set_message(self.env_assist.get_env(), "", "", "")
         )
-        assert_report_item_list_equal(
-            self.env.report_processor.report_item_list,
+        self.env_assist.assert_reports(
             [
                 (
                     Severities.ERROR,
@@ -758,11 +706,12 @@ class SetMessageTest(CommonTest):
         )
 
     def test_invalid_message_type(self):
-        assert_raise_library_error(
-            lambda: cmd_sbd.set_message(self.env, "device", "node1", "message")
+        self.env_assist.assert_raise_library_error(
+            lambda: cmd_sbd.set_message(
+                self.env_assist.get_env(), "device", "node1", "message"
+            )
         )
-        assert_report_item_list_equal(
-            self.env.report_processor.report_item_list,
+        self.env_assist.assert_reports(
             [
                 fixture.error(
                     reports.codes.INVALID_OPTION_VALUE,
@@ -776,25 +725,28 @@ class SetMessageTest(CommonTest):
         )
 
     def test_success(self):
-        runner.set_runs(self.fixture_call_sbd_message("device", "node", "test"))
-        cmd_sbd.set_message(self.env, "device", "node", "test")
-        runner.assert_everything_launched()
+        self.config.runner.sbd.set_device_message("device", "node", "test")
+        cmd_sbd.set_message(self.env_assist.get_env(), "device", "node", "test")
 
-    def test_failuer(self):
-        runner.set_runs(
-            self.fixture_call_sbd_message("device", "node", "test", "error", 1)
+    def test_failure(self):
+        self.config.runner.sbd.set_device_message(
+            "device", "node", "test", stderr="error", return_code=1
         )
-        assert_raise_library_error(
-            lambda: cmd_sbd.set_message(self.env, "device", "node", "test"),
-            (
-                Severities.ERROR,
-                reports.codes.SBD_DEVICE_MESSAGE_ERROR,
-                {
-                    "device": "device",
-                    "node": "node",
-                    "sbd_message": "test",
-                    "reason": "error",
-                },
+        self.env_assist.assert_raise_library_error(
+            lambda: cmd_sbd.set_message(
+                self.env_assist.get_env(), "device", "node", "test"
             ),
+            [
+                (
+                    Severities.ERROR,
+                    reports.codes.SBD_DEVICE_MESSAGE_ERROR,
+                    {
+                        "device": "device",
+                        "node": "node",
+                        "sbd_message": "test",
+                        "reason": "error",
+                    },
+                )
+            ],
+            expected_in_processor=False,
         )
-        runner.assert_everything_launched()
