@@ -4,7 +4,7 @@ from textwrap import dedent
 from unittest import mock, TestCase
 
 from pcs_test.tools.assertions import assert_raise_library_error
-from pcs_test.tools.misc import get_test_resource
+from pcs_test.tools.misc import get_test_resource, get_tmp_dir
 
 from pcs import settings
 from pcs.common import reports
@@ -17,11 +17,15 @@ import pcs.lib.corosync.qdevice_net as lib
 
 # pylint: disable=no-self-use
 
-_qnetd_cert_dir = "/etc/corosync/qnetd/nssdb"
-_qnetd_cert_tool = "/usr/bin/corosync-qnetd-certutil"
-_qnetd_tool = "/usr/bin/corosync-qnetd-tool"
-_client_cert_dir = "/etc/corosync/qdevice/net/nssdb"
-_client_cert_tool = "/usr/sbin/corosync-qdevice-net-certutil"
+_qnetd_cert_tool = os.path.join(
+    settings.corosync_qnet_binaries, "corosync-qnetd-certutil"
+)
+_qnetd_tool = os.path.join(
+    settings.corosync_qnet_binaries, "corosync-qnetd-tool"
+)
+_client_cert_tool = os.path.join(
+    settings.corosync_qdevice_binaries, "corosync-qdevice-net-certutil"
+)
 
 
 def cert_to_url(cert):
@@ -73,7 +77,10 @@ class QdeviceSetupTest(TestCase):
             (
                 severity.ERROR,
                 report_codes.QDEVICE_INITIALIZATION_ERROR,
-                {"model": "net", "reason": "test error\nstdout",},
+                {
+                    "model": "net",
+                    "reason": "test error\nstdout",
+                },
             ),
         )
 
@@ -87,7 +94,9 @@ class QdeviceDestroyTest(TestCase):
     def test_success(self, mock_initialized, mock_rmtree):
         mock_initialized.return_value = True
         lib.qdevice_destroy()
-        mock_rmtree.assert_called_once_with(_qnetd_cert_dir)
+        mock_rmtree.assert_called_once_with(
+            settings.corosync_qdevice_net_server_certs_dir
+        )
 
     def test_not_initialized(self, mock_initialized, mock_rmtree):
         mock_initialized.return_value = False
@@ -102,10 +111,15 @@ class QdeviceDestroyTest(TestCase):
             (
                 severity.ERROR,
                 report_codes.QDEVICE_DESTROY_ERROR,
-                {"model": "net", "reason": "test message",},
+                {
+                    "model": "net",
+                    "reason": "test message",
+                },
             ),
         )
-        mock_rmtree.assert_called_once_with(_qnetd_cert_dir)
+        mock_rmtree.assert_called_once_with(
+            settings.corosync_qdevice_net_server_certs_dir
+        )
 
 
 class QdeviceStatusGenericTest(TestCase):
@@ -134,7 +148,10 @@ class QdeviceStatusGenericTest(TestCase):
             (
                 severity.ERROR,
                 report_codes.QDEVICE_GET_STATUS_ERROR,
-                {"model": "net", "reason": "status error\nsome info",},
+                {
+                    "model": "net",
+                    "reason": "status error\nsome info",
+                },
             ),
         )
         self.mock_runner.run.assert_called_once_with([_qnetd_tool, "-s"])
@@ -186,7 +203,10 @@ class QdeviceStatusClusterTest(TestCase):
             (
                 severity.ERROR,
                 report_codes.QDEVICE_GET_STATUS_ERROR,
-                {"model": "net", "reason": "status error\nsome info",},
+                {
+                    "model": "net",
+                    "reason": "status error\nsome info",
+                },
             ),
         )
         self.mock_runner.run.assert_called_once_with([_qnetd_tool, "-l"])
@@ -255,7 +275,8 @@ class QdeviceSignCertificateRequestTest(CertificateTestCase):
         self.assertEqual(result, mock_get_cert.return_value)
 
         mock_tmp_store.assert_called_once_with(
-            "certificate request", reports.messages.QdeviceCertificateSignError,
+            "certificate request",
+            reports.messages.QdeviceCertificateSignError,
         )
         self.mock_runner.run.assert_called_once_with(
             [
@@ -284,7 +305,9 @@ class QdeviceSignCertificateRequestTest(CertificateTestCase):
             (
                 severity.ERROR,
                 report_codes.QDEVICE_NOT_INITIALIZED,
-                {"model": "net",},
+                {
+                    "model": "net",
+                },
             ),
         )
         mock_tmp_store.assert_not_called()
@@ -321,12 +344,15 @@ class QdeviceSignCertificateRequestTest(CertificateTestCase):
             (
                 severity.ERROR,
                 report_codes.QDEVICE_CERTIFICATE_SIGN_ERROR,
-                {"reason": "tool output error\nstdout",},
+                {
+                    "reason": "tool output error\nstdout",
+                },
             ),
         )
 
         mock_tmp_store.assert_called_once_with(
-            "certificate request", reports.messages.QdeviceCertificateSignError,
+            "certificate request",
+            reports.messages.QdeviceCertificateSignError,
         )
         self.mock_runner.run.assert_called_once_with(
             [
@@ -356,7 +382,8 @@ class QdeviceSignCertificateRequestTest(CertificateTestCase):
         )
 
         mock_tmp_store.assert_called_once_with(
-            "certificate request", reports.messages.QdeviceCertificateSignError,
+            "certificate request",
+            reports.messages.QdeviceCertificateSignError,
         )
         self.mock_runner.run.assert_called_once_with(
             [
@@ -381,7 +408,9 @@ class ClientDestroyTest(TestCase):
     def test_success(self, mock_initialized, mock_rmtree):
         mock_initialized.return_value = True
         lib.client_destroy()
-        mock_rmtree.assert_called_once_with(_client_cert_dir)
+        mock_rmtree.assert_called_once_with(
+            settings.corosync_qdevice_net_client_certs_dir
+        )
 
     def test_not_initialized(self, mock_initialized, mock_rmtree):
         mock_initialized.return_value = False
@@ -396,26 +425,33 @@ class ClientDestroyTest(TestCase):
             (
                 severity.ERROR,
                 report_codes.QDEVICE_DESTROY_ERROR,
-                {"model": "net", "reason": "test message",},
+                {
+                    "model": "net",
+                    "reason": "test message",
+                },
             ),
         )
-        mock_rmtree.assert_called_once_with(_client_cert_dir)
+        mock_rmtree.assert_called_once_with(
+            settings.corosync_qdevice_net_client_certs_dir
+        )
 
 
 class ClientSetupTest(TestCase):
     def setUp(self):
         self.mock_runner = mock.MagicMock(spec_set=CommandRunner)
         self.original_path = settings.corosync_qdevice_net_client_certs_dir
-        settings.corosync_qdevice_net_client_certs_dir = get_test_resource(
-            "qdevice-certs"
-        )
+        self.cert_dir = get_tmp_dir("tier0_lib_corosync_qdevice_net")
+        settings.corosync_qdevice_net_client_certs_dir = self.cert_dir.name
         self.ca_file_path = os.path.join(
             settings.corosync_qdevice_net_client_certs_dir,
             settings.corosync_qdevice_net_client_ca_file_name,
         )
+        with open(self.ca_file_path, "w") as my_file:
+            my_file.write("to be overwritten")
 
     def tearDown(self):
         settings.corosync_qdevice_net_client_certs_dir = self.original_path
+        self.cert_dir.cleanup()
 
     @mock.patch("pcs.lib.corosync.qdevice_net.client_destroy")
     def test_success(self, mock_destroy):
@@ -444,7 +480,10 @@ class ClientSetupTest(TestCase):
             (
                 severity.ERROR,
                 report_codes.QDEVICE_INITIALIZATION_ERROR,
-                {"model": "net", "reason": "tool output error\nstdout",},
+                {
+                    "model": "net",
+                    "reason": "tool output error\nstdout",
+                },
             ),
         )
         with open(self.ca_file_path, "rb") as a_file:
@@ -474,7 +513,8 @@ class ClientGenerateCertificateRequestTest(CertificateTestCase):
         )
         self.assertEqual(1, len(mock_get_cert.mock_calls))
         self.assertEqual(
-            "tool output", mock_get_cert.call_args[0][0],
+            "tool output",
+            mock_get_cert.call_args[0][0],
         )
         self.assertEqual(
             reports.messages.QdeviceInitializationError("net", "tool output"),
@@ -492,7 +532,9 @@ class ClientGenerateCertificateRequestTest(CertificateTestCase):
             (
                 severity.ERROR,
                 report_codes.QDEVICE_NOT_INITIALIZED,
-                {"model": "net",},
+                {
+                    "model": "net",
+                },
             ),
         )
         self.mock_runner.run.assert_not_called()
@@ -509,7 +551,10 @@ class ClientGenerateCertificateRequestTest(CertificateTestCase):
             (
                 severity.ERROR,
                 report_codes.QDEVICE_INITIALIZATION_ERROR,
-                {"model": "net", "reason": "tool output error\nstdout",},
+                {
+                    "model": "net",
+                    "reason": "tool output error\nstdout",
+                },
             ),
         )
         self.mock_runner.run.assert_called_once_with(
@@ -556,7 +601,9 @@ class ClientCertRequestToPk12Test(CertificateTestCase):
             (
                 severity.ERROR,
                 report_codes.QDEVICE_NOT_INITIALIZED,
-                {"model": "net",},
+                {
+                    "model": "net",
+                },
             ),
         )
         mock_tmp_store.assert_not_called()
@@ -593,7 +640,9 @@ class ClientCertRequestToPk12Test(CertificateTestCase):
             (
                 severity.ERROR,
                 report_codes.QDEVICE_CERTIFICATE_IMPORT_ERROR,
-                {"reason": "tool output error\nstdout",},
+                {
+                    "reason": "tool output error\nstdout",
+                },
             ),
         )
 
@@ -645,7 +694,8 @@ class ClientImportCertificateAndKeyTest(CertificateTestCase):
         )
 
         mock_tmp_store.assert_called_once_with(
-            "pk12 certificate", reports.messages.QdeviceCertificateImportError,
+            "pk12 certificate",
+            reports.messages.QdeviceCertificateImportError,
         )
         self.mock_runner.run.assert_called_once_with(
             [_client_cert_tool, "-m", "-c", self.mock_tmpfile.name]
@@ -662,7 +712,9 @@ class ClientImportCertificateAndKeyTest(CertificateTestCase):
             (
                 severity.ERROR,
                 report_codes.QDEVICE_NOT_INITIALIZED,
-                {"model": "net",},
+                {
+                    "model": "net",
+                },
             ),
         )
 
@@ -681,7 +733,8 @@ class ClientImportCertificateAndKeyTest(CertificateTestCase):
         )
 
         mock_tmp_store.assert_called_once_with(
-            "pk12 certificate", reports.messages.QdeviceCertificateImportError,
+            "pk12 certificate",
+            reports.messages.QdeviceCertificateImportError,
         )
         self.mock_runner.run.assert_not_called()
 
@@ -697,15 +750,19 @@ class ClientImportCertificateAndKeyTest(CertificateTestCase):
             (
                 severity.ERROR,
                 report_codes.QDEVICE_CERTIFICATE_IMPORT_ERROR,
-                {"reason": "tool output error\nstdout",},
+                {
+                    "reason": "tool output error\nstdout",
+                },
             ),
         )
 
         mock_tmp_store.assert_called_once_with(
-            "pk12 certificate", reports.messages.QdeviceCertificateImportError,
+            "pk12 certificate",
+            reports.messages.QdeviceCertificateImportError,
         )
         mock_tmp_store.assert_called_once_with(
-            "pk12 certificate", reports.messages.QdeviceCertificateImportError,
+            "pk12 certificate",
+            reports.messages.QdeviceCertificateImportError,
         )
         self.mock_runner.run.assert_called_once_with(
             [_client_cert_tool, "-m", "-c", self.mock_tmpfile.name]
@@ -761,12 +818,15 @@ class GetOutputCertificateTest(TestCase):
 
         assert_raise_library_error(
             lambda: lib._get_output_certificate(
-                cert_tool_output, report_item_message,
+                cert_tool_output,
+                report_item_message,
             ),
             (
                 severity.ERROR,
                 report_codes.QDEVICE_CERTIFICATE_IMPORT_ERROR,
-                {"reason": cert_tool_output,},
+                {
+                    "reason": cert_tool_output,
+                },
             ),
         )
 
@@ -784,7 +844,8 @@ class GetOutputCertificateTest(TestCase):
 
         assert_raise_library_error(
             lambda: lib._get_output_certificate(
-                cert_tool_output, report_item_message,
+                cert_tool_output,
+                report_item_message,
             ),
             (
                 severity.ERROR,
