@@ -15,10 +15,7 @@ from pcs_test.tools.custom_mock import (
 from pcs_test.tools.misc import outdent
 
 from pcs import settings
-from pcs.common import (
-    pcs_pycurl as pycurl,
-    report_codes,
-)
+from pcs.common import pcs_pycurl as pycurl
 from pcs.common.host import (
     Destination,
     PcsKnownHost,
@@ -29,7 +26,8 @@ from pcs.common.node_communicator import (
     RequestTarget,
     Response,
 )
-from pcs.lib.errors import ReportItemSeverity as severity
+from pcs.common.reports import ReportItemSeverity as severity
+from pcs.common.reports import codes as report_codes
 import pcs.lib.node_communication as lib
 
 
@@ -42,9 +40,11 @@ class NodeTargetLibFactory(TestCase):
                 [
                     Destination(
                         "addr{}{}".format(i, j), "port{}{}".format(i, j)
-                    ) for j in range(2)
-                ]
-            ) for i in range(2)
+                    )
+                    for j in range(2)
+                ],
+            )
+            for i in range(2)
         }
         self.report_processor = MockLibraryReportProcessor()
         self.factory = lib.NodeTargetLibFactory(
@@ -59,8 +59,7 @@ class NodeTargetLibFactory(TestCase):
     def test_one_host(self):
         host = "host0"
         self.assert_equal_known_host_target(
-            self.known_hosts[host],
-            self.factory.get_target_list([host])[0]
+            self.known_hosts[host], self.factory.get_target_list([host])[0]
         )
         self.report_processor.assert_reports([])
 
@@ -79,11 +78,10 @@ class NodeTargetLibFactory(TestCase):
         report = fixture.error(
             report_codes.HOST_NOT_FOUND,
             force_code=report_codes.SKIP_OFFLINE_NODES,
-            host_list=unknown_hosts
+            host_list=unknown_hosts,
         )
         assert_raise_library_error(
-            lambda: self.factory.get_target_list([host] + unknown_hosts),
-            report
+            lambda: self.factory.get_target_list([host] + unknown_hosts)
         )
         self.report_processor.assert_reports([report])
 
@@ -91,14 +89,13 @@ class NodeTargetLibFactory(TestCase):
         host = "host0"
         unknown_hosts = ["node0", "node1"]
         report = fixture.error(
-            report_codes.HOST_NOT_FOUND,
-            host_list=unknown_hosts
+            report_codes.HOST_NOT_FOUND, host_list=unknown_hosts
         )
         assert_raise_library_error(
             lambda: self.factory.get_target_list(
-                [host] + unknown_hosts, allow_skip=False,
-            ),
-            report
+                [host] + unknown_hosts,
+                allow_skip=False,
+            )
         )
         self.report_processor.assert_reports([report])
 
@@ -111,9 +108,9 @@ class NodeTargetLibFactory(TestCase):
         self.assert_equal_known_host_target(
             self.known_hosts[host], target_list[0]
         )
-        self.report_processor.assert_reports([
-            fixture.warn(report_codes.HOST_NOT_FOUND, host_list=unknown_hosts)
-        ])
+        self.report_processor.assert_reports(
+            [fixture.warn(report_codes.HOST_NOT_FOUND, host_list=unknown_hosts)]
+        )
 
     def test_no_host_found(self):
         unknown_hosts = ["node0", "node1"]
@@ -121,13 +118,12 @@ class NodeTargetLibFactory(TestCase):
             fixture.error(
                 report_codes.HOST_NOT_FOUND,
                 force_code=report_codes.SKIP_OFFLINE_NODES,
-                host_list=unknown_hosts
+                host_list=unknown_hosts,
             ),
-            fixture.error(report_codes.NONE_HOST_FOUND)
+            fixture.error(report_codes.NONE_HOST_FOUND),
         ]
         assert_raise_library_error(
             lambda: self.factory.get_target_list(unknown_hosts),
-            *report_list
         )
         self.report_processor.assert_reports(report_list)
 
@@ -135,13 +131,12 @@ class NodeTargetLibFactory(TestCase):
         unknown_hosts = ["node0", "node1"]
         report_list = [
             fixture.warn(report_codes.HOST_NOT_FOUND, host_list=unknown_hosts),
-            fixture.error(report_codes.NONE_HOST_FOUND)
+            fixture.error(report_codes.NONE_HOST_FOUND),
         ]
         assert_raise_library_error(
             lambda: self.factory.get_target_list(
                 unknown_hosts, skip_non_existing=True
-            ),
-            report_list[1]
+            )
         )
         self.report_processor.assert_reports(report_list)
 
@@ -186,10 +181,10 @@ class ResponseToReportItemTest(TestCase):
                 {
                     "node": self.host,
                     "command": self.request,
-                    "reason": self.data.decode("utf-8")
+                    "reason": self.data.decode("utf-8"),
                 },
-                None
-            )
+                None,
+            ),
         )
 
     def test_code_401(self):
@@ -201,10 +196,10 @@ class ResponseToReportItemTest(TestCase):
                 {
                     "node": self.host,
                     "command": self.request,
-                    "reason": "HTTP error: 401"
+                    "reason": "HTTP error: 401",
                 },
-                None
-            )
+                None,
+            ),
         )
 
     def test_code_403(self):
@@ -216,10 +211,10 @@ class ResponseToReportItemTest(TestCase):
                 {
                     "node": self.host,
                     "command": self.request,
-                    "reason": "HTTP error: 403"
+                    "reason": "HTTP error: 403",
                 },
-                None
-            )
+                None,
+            ),
         )
 
     def test_code_404(self):
@@ -231,10 +226,10 @@ class ResponseToReportItemTest(TestCase):
                 {
                     "node": self.host,
                     "command": self.request,
-                    "reason": "HTTP error: 404"
+                    "reason": "HTTP error: 404",
                 },
-                None
-            )
+                None,
+            ),
         )
 
     def test_code_other(self):
@@ -246,10 +241,10 @@ class ResponseToReportItemTest(TestCase):
                 {
                     "node": self.host,
                     "command": self.request,
-                    "reason": "HTTP error: 500"
+                    "reason": "HTTP error: 500",
                 },
-                None
-            )
+                None,
+            ),
         )
 
     def test_timed_out(self):
@@ -261,13 +256,9 @@ class ResponseToReportItemTest(TestCase):
             (
                 severity.ERROR,
                 report_codes.NODE_COMMUNICATION_ERROR_TIMED_OUT,
-                {
-                    "node": self.host,
-                    "command": self.request,
-                    "reason": "err"
-                },
-                None
-            )
+                {"node": self.host, "command": self.request, "reason": "err"},
+                None,
+            ),
         )
 
     def test_timedouted(self):
@@ -279,13 +270,9 @@ class ResponseToReportItemTest(TestCase):
             (
                 severity.ERROR,
                 report_codes.NODE_COMMUNICATION_ERROR_TIMED_OUT,
-                {
-                    "node": self.host,
-                    "command": self.request,
-                    "reason": "err"
-                },
-                None
-            )
+                {"node": self.host, "command": self.request, "reason": "err"},
+                None,
+            ),
         )
 
     def test_unable_to_connect(self):
@@ -297,75 +284,111 @@ class ResponseToReportItemTest(TestCase):
             (
                 severity.ERROR,
                 report_codes.NODE_COMMUNICATION_ERROR_UNABLE_TO_CONNECT,
-                {
-                    "node": self.host,
-                    "command": self.request,
-                    "reason": "err"
-                },
-                None
-            )
+                {"node": self.host, "command": self.request, "reason": "err"},
+                None,
+            ),
         )
 
 
 class IsProxySetTest(TestCase):
     def test_without_proxy(self):
-        self.assertFalse(lib.is_proxy_set({
-            "var1": "value",
-            "var2": "val",
-        }))
+        self.assertFalse(
+            lib.is_proxy_set(
+                {
+                    "var1": "value",
+                    "var2": "val",
+                }
+            )
+        )
 
     def test_multiple(self):
-        self.assertTrue(lib.is_proxy_set({
-            "var1": "val",
-            "https_proxy": "test.proxy",
-            "var2": "val",
-            "all_proxy": "test2.proxy",
-            "var3": "val",
-        }))
+        self.assertTrue(
+            lib.is_proxy_set(
+                {
+                    "var1": "val",
+                    "https_proxy": "test.proxy",
+                    "var2": "val",
+                    "all_proxy": "test2.proxy",
+                    "var3": "val",
+                }
+            )
+        )
 
     def test_empty_string(self):
-        self.assertFalse(lib.is_proxy_set({
-            "all_proxy": "",
-        }))
+        self.assertFalse(
+            lib.is_proxy_set(
+                {
+                    "all_proxy": "",
+                }
+            )
+        )
 
     def test_http_proxy(self):
-        self.assertFalse(lib.is_proxy_set({
-            "http_proxy": "test.proxy",
-        }))
+        self.assertFalse(
+            lib.is_proxy_set(
+                {
+                    "http_proxy": "test.proxy",
+                }
+            )
+        )
 
     def test_HTTP_PROXY(self):
         # pylint: disable=invalid-name
-        self.assertFalse(lib.is_proxy_set({
-            "HTTP_PROXY": "test.proxy",
-        }))
+        self.assertFalse(
+            lib.is_proxy_set(
+                {
+                    "HTTP_PROXY": "test.proxy",
+                }
+            )
+        )
 
     def test_https_proxy(self):
-        self.assertTrue(lib.is_proxy_set({
-            "https_proxy": "test.proxy",
-        }))
+        self.assertTrue(
+            lib.is_proxy_set(
+                {
+                    "https_proxy": "test.proxy",
+                }
+            )
+        )
 
     def test_HTTPS_PROXY(self):
         # pylint: disable=invalid-name
-        self.assertTrue(lib.is_proxy_set({
-            "HTTPS_PROXY": "test.proxy",
-        }))
+        self.assertTrue(
+            lib.is_proxy_set(
+                {
+                    "HTTPS_PROXY": "test.proxy",
+                }
+            )
+        )
 
     def test_all_proxy(self):
-        self.assertTrue(lib.is_proxy_set({
-            "all_proxy": "test.proxy",
-        }))
+        self.assertTrue(
+            lib.is_proxy_set(
+                {
+                    "all_proxy": "test.proxy",
+                }
+            )
+        )
 
     def test_ALL_PROXY(self):
         # pylint: disable=invalid-name
-        self.assertTrue(lib.is_proxy_set({
-            "ALL_PROXY": "test.proxy",
-        }))
+        self.assertTrue(
+            lib.is_proxy_set(
+                {
+                    "ALL_PROXY": "test.proxy",
+                }
+            )
+        )
 
     def test_no_proxy(self):
-        self.assertTrue(lib.is_proxy_set({
-            "no_proxy": "*",
-            "all_proxy": "test.proxy",
-        }))
+        self.assertTrue(
+            lib.is_proxy_set(
+                {
+                    "no_proxy": "*",
+                    "all_proxy": "test.proxy",
+                }
+            )
+        )
 
 
 def fixture_logger_call_send(url, data):
@@ -376,7 +399,8 @@ def fixture_logger_call_send(url, data):
 
 
 def fixture_logger_call_debug_data(url, data):
-    send_msg = outdent("""\
+    send_msg = outdent(
+        """\
         Communication debug info for calling: {url}
         --Debug Communication Info Start--
         {data}
@@ -390,9 +414,9 @@ def fixture_logger_call_connected(url, response_code, response_data):
         "Finished calling: {url}\nResponse Code: {code}"
         + "\n--Debug Response Start--\n{response}\n--Debug Response End--"
     )
-    return mock.call.debug(result_msg.format(
-        url=url, code=response_code, response=response_data
-    ))
+    return mock.call.debug(
+        result_msg.format(url=url, code=response_code, response=response_data)
+    )
 
 
 def fixture_logger_call_not_connected(node, reason):
@@ -412,72 +436,81 @@ def fixture_logger_calls_on_success(
         fixture_logger_call_debug_data(url, debug_data),
     ]
 
+
 def fixture_report_item_list_send(url, data):
-    return [(
-        severity.DEBUG,
-        report_codes.NODE_COMMUNICATION_STARTED,
-        {
-            "target": url,
-            "data": data,
-        }
-    )]
+    return [
+        (
+            severity.DEBUG,
+            report_codes.NODE_COMMUNICATION_STARTED,
+            {
+                "target": url,
+                "data": data,
+            },
+        )
+    ]
 
 
 def fixture_report_item_list_debug(url, data):
-    return [(
-        severity.DEBUG,
-        report_codes.NODE_COMMUNICATION_DEBUG_INFO,
-        {
-            "target": url,
-            "data": data,
-        }
-    )]
+    return [
+        (
+            severity.DEBUG,
+            report_codes.NODE_COMMUNICATION_DEBUG_INFO,
+            {
+                "target": url,
+                "data": data,
+            },
+        )
+    ]
 
 
 def fixture_report_item_list_connected(url, response_code, response_data):
-    return [(
-        severity.DEBUG,
-        report_codes.NODE_COMMUNICATION_FINISHED,
-        {
-            "target": url,
-            "response_code": response_code,
-            "response_data": response_data,
-        }
-    )]
+    return [
+        (
+            severity.DEBUG,
+            report_codes.NODE_COMMUNICATION_FINISHED,
+            {
+                "target": url,
+                "response_code": response_code,
+                "response_data": response_data,
+            },
+        )
+    ]
 
 
 def fixture_report_item_list_not_connected(node, reason):
-    return [(
-        severity.DEBUG,
-        report_codes.NODE_COMMUNICATION_NOT_CONNECTED,
-        {
-            "node": node,
-            "reason": reason,
-        },
-        None
-    )]
+    return [
+        (
+            severity.DEBUG,
+            report_codes.NODE_COMMUNICATION_NOT_CONNECTED,
+            {
+                "node": node,
+                "reason": reason,
+            },
+            None,
+        )
+    ]
 
 
 def fixture_report_item_list_proxy_set(node, address):
-    return [(
-        severity.WARNING,
-        report_codes.NODE_COMMUNICATION_PROXY_IS_SET,
-        {
-            "node": node,
-            "address": address,
-        },
-        None
-    )]
+    return [
+        (
+            severity.WARNING,
+            report_codes.NODE_COMMUNICATION_PROXY_IS_SET,
+            {
+                "node": node,
+                "address": address,
+            },
+            None,
+        )
+    ]
 
 
 def fixture_report_item_list_on_success(
     url, response_code, response_data, debug_data
 ):
-    return (
-        fixture_report_item_list_connected(url, response_code, response_data)
-        +
-        fixture_report_item_list_debug(url, debug_data)
-    )
+    return fixture_report_item_list_connected(
+        url, response_code, response_data
+    ) + fixture_report_item_list_debug(url, debug_data)
 
 
 def fixture_request():
@@ -498,7 +531,7 @@ class CommunicatorLoggerTest(TestCase):
         )
         self.assertEqual(
             [fixture_logger_call_send(request.url, request.data)],
-            self.logger.mock_calls
+            self.logger.mock_calls,
         )
 
     def test_log_response_connected(self):
@@ -519,14 +552,14 @@ class CommunicatorLoggerTest(TestCase):
                 response.request.url,
                 expected_code,
                 expected_data,
-                expected_debug_data
+                expected_debug_data,
             )
         )
         logger_calls = fixture_logger_calls_on_success(
             response.request.url,
             expected_code,
             expected_data,
-            expected_debug_data
+            expected_debug_data,
         )
         self.assertEqual(logger_calls, self.logger.mock_calls)
 
@@ -548,8 +581,7 @@ class CommunicatorLoggerTest(TestCase):
             fixture_report_item_list_not_connected(
                 response.request.host_label, error_msg
             )
-            +
-            fixture_report_item_list_debug(
+            + fixture_report_item_list_debug(
                 response.request.url, expected_debug_data
             )
         )
@@ -559,7 +591,7 @@ class CommunicatorLoggerTest(TestCase):
             ),
             fixture_logger_call_debug_data(
                 response.request.url, expected_debug_data
-            )
+            ),
         ]
         self.assertEqual(logger_calls, self.logger.mock_calls)
 
@@ -581,12 +613,10 @@ class CommunicatorLoggerTest(TestCase):
             fixture_report_item_list_not_connected(
                 response.request.host_label, error_msg
             )
-            +
-            fixture_report_item_list_proxy_set(
+            + fixture_report_item_list_proxy_set(
                 response.request.host_label, response.request.host_label
             )
-            +
-            fixture_report_item_list_debug(
+            + fixture_report_item_list_debug(
                 response.request.url, expected_debug_data
             )
         )
@@ -597,7 +627,7 @@ class CommunicatorLoggerTest(TestCase):
             fixture_logger_call_proxy_set(),
             fixture_logger_call_debug_data(
                 response.request.url, expected_debug_data
-            )
+            ),
         ]
         self.assertEqual(logger_calls, self.logger.mock_calls)
 
@@ -611,19 +641,23 @@ class CommunicatorLoggerTest(TestCase):
             "e",
         )
         self.com_logger.log_retry(response, prev_host)
-        self.reporter.assert_reports([(
-            severity.WARNING,
-            report_codes.NODE_COMMUNICATION_RETRYING,
-            {
-                "node": response.request.host_label,
-                "failed_address": prev_addr,
-                "failed_port": prev_port,
-                "next_address": response.request.dest.addr,
-                "next_port": settings.pcsd_default_port,
-                "request": response.request.url,
-            },
-            None
-        )])
+        self.reporter.assert_reports(
+            [
+                (
+                    severity.WARNING,
+                    report_codes.NODE_COMMUNICATION_RETRYING,
+                    {
+                        "node": response.request.host_label,
+                        "failed_address": prev_addr,
+                        "failed_port": prev_port,
+                        "next_address": response.request.dest.addr,
+                        "next_port": settings.pcsd_default_port,
+                        "request": response.request.url,
+                    },
+                    None,
+                )
+            ]
+        )
         logger_call = mock.call.warning(
             (
                 "Unable to connect to '{label}' via address '{old_addr}' and "
@@ -644,18 +678,22 @@ class CommunicatorLoggerTest(TestCase):
         response = Response.connection_failure(
             MockCurlSimple(request=fixture_request()),
             pycurl.E_HTTP_POST_ERROR,
-            "e"
+            "e",
         )
         self.com_logger.log_no_more_addresses(response)
-        self.reporter.assert_reports([(
-            severity.WARNING,
-            report_codes.NODE_COMMUNICATION_NO_MORE_ADDRESSES,
-            {
-                "node": response.request.host_label,
-                "request": response.request.url,
-            },
-            None
-        )])
+        self.reporter.assert_reports(
+            [
+                (
+                    severity.WARNING,
+                    report_codes.NODE_COMMUNICATION_NO_MORE_ADDRESSES,
+                    {
+                        "node": response.request.host_label,
+                        "request": response.request.url,
+                    },
+                    None,
+                )
+            ]
+        )
         logger_call = mock.call.warning(
             "No more addresses for node {label} to run '{req}'".format(
                 label=response.request.host_label,
