@@ -4,14 +4,12 @@ from unittest import mock, TestCase
 from pcs_test.tier1.cib_resource.common import ResourceTest
 from pcs_test.tools.assertions import AssertPcsMixin
 from pcs_test.tools.bin_mock import get_mock_settings
-from pcs_test.tools.misc import (
-    get_test_resource as rc,
-    skip_unless_pacemaker_supports_bundle,
-)
 from pcs_test.tools.pcs_runner import PcsRunner
 
 from pcs import resource
 from pcs.cli.common.parse_args import InputModifiers
+from pcs.common import const
+from pcs.common.str_tools import format_list
 
 # pylint: disable=invalid-name
 # pylint: disable=no-self-use
@@ -803,10 +801,7 @@ class Promotable(TestCase, AssertPcsMixin):
         )
 
 
-@skip_unless_pacemaker_supports_bundle()
 class Bundle(ResourceTest):
-    empty_cib = rc("cib-empty-2.8.xml")
-
     def fixture_primitive(self, name, bundle=None):
         if bundle:
             self.assert_pcs_success(
@@ -931,24 +926,35 @@ class FailOrWarn(ResourceTest):
         )
 
     def test_fail_when_nonexisting_agent(self):
+        # pacemaker 2.0.5 adds 'crm_resource:'
+        # The exact message returned form pacemaker differs from version to
+        # version (sometimes from commit to commit), so we don't check for the
+        # whole of it.
+        stdout_regexp = re.compile(
+            "^"
+            "Error: Agent 'ocf:heartbeat:NoExisting' is not installed or "
+            "does not provide valid metadata:( crm_resource:)? Metadata "
+            "query for ocf:heartbeat:NoExisting failed:.+"
+            ", use --force to override\n$",
+            re.MULTILINE,
+        )
         self.assert_pcs_fail(
             "resource create R ocf:heartbeat:NoExisting".split(),
-            # pacemaker 1.1.18 changes -5 to Input/output error
-            # pacemaker 2.0.5 adds 'crm_resource:' and
-            #   'Error performing operation: Input/output error'
-            stdout_regexp=re.compile(
-                "^"
-                "Error: Agent 'ocf:heartbeat:NoExisting' is not installed or "
-                "does not provide valid metadata:( crm_resource:)? Metadata "
-                "query for ocf:heartbeat:NoExisting failed: "
-                "(-5|Input/output error)(, Error performing operation: "
-                "Input/output error)?, use --force to override\n"
-                "$",
-                re.MULTILINE,
-            ),
+            stdout_regexp=stdout_regexp,
         )
 
     def test_warn_when_forcing_noexistent_agent(self):
+        # pacemaker 2.0.5 adds 'crm_resource:'
+        # The exact message returned form pacemaker differs from version to
+        # version (sometimes from commit to commit), so we don't check for the
+        # whole of it.
+        output_regexp = re.compile(
+            "^"
+            "Warning: Agent 'ocf:heartbeat:NoExisting' is not installed or "
+            "does not provide valid metadata:( crm_resource:)? Metadata "
+            "query for ocf:heartbeat:NoExisting failed:.+",
+            re.MULTILINE,
+        )
         self.assert_effect(
             "resource create R ocf:heartbeat:NoExisting --force".split(),
             """<resources>
@@ -962,19 +968,7 @@ class FailOrWarn(ResourceTest):
                     </operations>
                 </primitive>
             </resources>""",
-            # pacemaker 1.1.18 changes -5 to Input/output error
-            # pacemaker 2.0.5 adds 'crm_resource:' and
-            #   'Error performing operation: Input/output error'
-            output_regexp=re.compile(
-                "^"
-                "Warning: Agent 'ocf:heartbeat:NoExisting' is not installed or "
-                "does not provide valid metadata:( crm_resource:)? Metadata "
-                "query for ocf:heartbeat:NoExisting failed: "
-                "(-5|Input/output error)(, Error performing operation: "
-                "Input/output error)?\n"
-                "$",
-                re.MULTILINE,
-            ),
+            output_regexp=output_regexp,
         )
 
     def test_fail_on_invalid_resource_agent_name(self):
@@ -1251,8 +1245,10 @@ class FailOrWarnOp(ResourceTest):
                 "op monitor role=abc"
             ).split(),
             (
-                "Error: 'abc' is not a valid role value, use 'Master', 'Slave',"
-                " 'Started', 'Stopped'\n" + ERRORS_HAVE_OCURRED
+                "Error: 'abc' is not a valid role value, use {}\n".format(
+                    format_list(const.PCMK_ROLES)
+                )
+                + ERRORS_HAVE_OCURRED
             ),
         )
 
@@ -1263,8 +1259,10 @@ class FailOrWarnOp(ResourceTest):
                 "op monitor role=abc --force"
             ).split(),
             (
-                "Error: 'abc' is not a valid role value, use 'Master', 'Slave',"
-                " 'Started', 'Stopped'\n" + ERRORS_HAVE_OCURRED
+                "Error: 'abc' is not a valid role value, use {}\n".format(
+                    format_list(const.PCMK_ROLES)
+                )
+                + ERRORS_HAVE_OCURRED
             ),
         )
 
