@@ -1,20 +1,22 @@
 # pylint: disable=too-many-lines
 import shutil
 from textwrap import dedent
+from threading import Lock
 from unittest import TestCase
 
 from pcs.common.str_tools import indent
 from pcs_test.tier1.cib_resource.common import ResourceTest
 from pcs_test.tools.assertions import AssertPcsMixin
 from pcs_test.tools.bin_mock import get_mock_settings
+from pcs_test.tools.fixture_cib import CachedCibFixture
 from pcs_test.tools.misc import (
     get_test_resource as rc,
     get_tmp_file,
     is_minimum_pacemaker_version,
-    skip_unless_pacemaker_version,
     skip_unless_crm_rule,
     outdent,
     ParametrizedTestMetaClass,
+    write_data_to_tmpfile,
     write_file_to_tmpfile,
 )
 from pcs_test.tools.pcs_runner import (
@@ -32,21 +34,6 @@ ERRORS_HAVE_OCURRED = (
 
 empty_cib = rc("cib-empty.xml")
 
-# target-pattern attribute was added in pacemaker 1.1.13 with validate-with 2.3.
-# However in pcs this was implemented much later together with target-attribute
-# support. In that time pacemaker 1.1.12 was quite old. To keep tests simple we
-# do not run fencing topology tests on pacemaker older that 1.1.13 even if it
-# supports targeting by node names.
-skip_unless_fencing_level_supported = skip_unless_pacemaker_version(
-    (1, 1, 13), "fencing levels"
-)
-# target-attribute and target-value attributes were added in pacemaker 1.1.14
-# with validate-with 2.4.
-fencing_level_attribute_supported = is_minimum_pacemaker_version(1, 1, 14)
-skip_unless_fencing_level_attribute_supported = skip_unless_pacemaker_version(
-    (1, 1, 14), "fencing levels with attribute targets"
-)
-
 
 class StonithDescribeTest(TestCase, AssertPcsMixin):
     def setUp(self):
@@ -103,14 +90,17 @@ class StonithTest(TestCase, AssertPcsMixin):
     def setUp(self):
         self.temp_cib = get_tmp_file("tier1_test_stonith")
         write_file_to_tmpfile(empty_cib, self.temp_cib)
+        self.temp_corosync_conf = get_tmp_file("tier1_test_stonith")
+        write_file_to_tmpfile(rc("corosync.conf"), self.temp_corosync_conf)
         self.pcs_runner = PcsRunner(self.temp_cib.name)
         self.pcs_runner.mock_settings = get_mock_settings("crm_resource_binary")
-        self.pcs_runner.mock_settings["corosync_conf_file"] = rc(
-            "corosync.conf"
-        )
+        self.pcs_runner.mock_settings[
+            "corosync_conf_file"
+        ] = self.temp_corosync_conf.name
 
     def tearDown(self):
         self.temp_cib.close()
+        self.temp_corosync_conf.close()
 
     @skip_unless_crm_rule()
     def testStonithCreation(self):
@@ -527,7 +517,7 @@ class StonithTest(TestCase, AssertPcsMixin):
         )
 
     def testStonithDeleteRemovesLevel(self):
-        shutil.copy(rc("cib-empty-with3nodes.xml"), self.temp_cib.name)
+        shutil.copyfile(rc("cib-empty-with3nodes.xml"), self.temp_cib.name)
 
         self.assert_pcs_success(
             "stonith create n1-ipmi fence_apc --force".split(),
@@ -819,7 +809,7 @@ class StonithTest(TestCase, AssertPcsMixin):
 
     def testNoStonithWarning(self):
         # pylint: disable=unused-variable
-        corosync_conf = rc("corosync.conf")
+        corosync_conf = self.temp_corosync_conf.name
         o, r = pcs(
             self.temp_cib.name, ["status"], corosync_conf_opt=corosync_conf
         )
@@ -847,17 +837,54 @@ class StonithTest(TestCase, AssertPcsMixin):
         self.assertIn("No stonith devices and stonith-enabled is not false", o)
 
 
+_fixture_stonith_level_cache = None
+_fixture_stonith_level_cache_lock = Lock()
+
+
+class StonithLevelTestCibFixture(CachedCibFixture):
+    def _fixture_stonith_resource(self, name):
+        self.assert_pcs_success(
+            [
+                "stonith",
+                "create",
+                name,
+                "fence_apc",
+                "pcmk_host_list=rh7-1 rh7-2",
+                "ip=i",
+                "username=u",
+            ]
+        )
+
+    def _setup_cib(self):
+        self._fixture_stonith_resource("F1")
+        self._fixture_stonith_resource("F2")
+        self._fixture_stonith_resource("F3")
+
+        self.assert_pcs_success("stonith level add 1 rh7-1 F1".split())
+        self.assert_pcs_success("stonith level add 2 rh7-1 F2".split())
+        self.assert_pcs_success("stonith level add 2 rh7-2 F1".split())
+        self.assert_pcs_success("stonith level add 1 rh7-2 F2".split())
+        self.assert_pcs_success("stonith level add 4 regexp%rh7-\\d F3".split())
+        self.assert_pcs_success(
+            "stonith level add 3 regexp%rh7-\\d F2 F1".split()
+        )
+        self.assert_pcs_success(
+            "stonith level add 5 attrib%fencewith=levels1 F3 F2".split()
+        )
+        self.assert_pcs_success(
+            "stonith level add 6 attrib%fencewith=levels2 F3 F1".split()
+        )
+
+
+STONITH_LEVEL_TEST_CIB_FIXTURE = StonithLevelTestCibFixture(
+    "fixture_tier1_stonith_level_tests", rc("cib-empty-withnodes.xml")
+)
+
+
 class LevelTestsBase(TestCase, AssertPcsMixin):
     def setUp(self):
         self.temp_cib = get_tmp_file("tier1_test_stonith_level")
-        if fencing_level_attribute_supported:
-            write_file_to_tmpfile(
-                rc("cib-empty-2.5-withnodes.xml"), self.temp_cib
-            )
-        else:
-            write_file_to_tmpfile(
-                rc("cib-empty-2.3-withnodes.xml"), self.temp_cib
-            )
+        write_file_to_tmpfile(rc("cib-empty-withnodes.xml"), self.temp_cib)
         self.pcs_runner = PcsRunner(self.temp_cib.name)
         self.pcs_runner.mock_settings = get_mock_settings("crm_resource_binary")
         self.config = ""
@@ -880,20 +907,23 @@ class LevelTestsBase(TestCase, AssertPcsMixin):
         )
 
     def fixture_full_configuration(self):
-        self.fixture_stonith_resource("F1")
-        self.fixture_stonith_resource("F2")
-        self.fixture_stonith_resource("F3")
+        cib, self.config, self.config_lines = self.fixture_cib_config_cache()
+        write_data_to_tmpfile(cib, self.temp_cib)
 
-        self.assert_pcs_success("stonith level add 1 rh7-1 F1".split())
-        self.assert_pcs_success("stonith level add 2 rh7-1 F2".split())
-        self.assert_pcs_success("stonith level add 2 rh7-2 F1".split())
-        self.assert_pcs_success("stonith level add 1 rh7-2 F2".split())
-        self.assert_pcs_success("stonith level add 4 regexp%rh7-\\d F3".split())
-        self.assert_pcs_success(
-            "stonith level add 3 regexp%rh7-\\d F2 F1".split()
-        )
+    def fixture_cib_config_cache(self):
+        # pylint: disable=global-statement
+        global _fixture_stonith_level_cache, _fixture_stonith_level_cache_lock
+        with _fixture_stonith_level_cache_lock:
+            if _fixture_stonith_level_cache is None:
+                _fixture_stonith_level_cache = self.fixture_cib_config()
+            return _fixture_stonith_level_cache
 
-        self.config = outdent(
+    @staticmethod
+    def fixture_cib_config():
+        cib_content = ""
+        with open(STONITH_LEVEL_TEST_CIB_FIXTURE.cache_path, "r") as cib_file:
+            cib_content = cib_file.read()
+        config = outdent(
             """\
             Target: rh7-1
               Level 1 - F1
@@ -901,33 +931,19 @@ class LevelTestsBase(TestCase, AssertPcsMixin):
             Target: rh7-2
               Level 1 - F2
               Level 2 - F1
-            Target: rh7-\\d
+            Target (regexp): rh7-\\d
               Level 3 - F2,F1
               Level 4 - F3
-            """
-        )
-        self.config_lines = self.config.splitlines()
-
-        if not fencing_level_attribute_supported:
-            return
-        self.assert_pcs_success(
-            "stonith level add 5 attrib%fencewith=levels1 F3 F2".split()
-        )
-        self.assert_pcs_success(
-            "stonith level add 6 attrib%fencewith=levels2 F3 F1".split()
-        )
-        self.config += outdent(
-            """\
             Target: fencewith=levels1
               Level 5 - F3,F2
             Target: fencewith=levels2
               Level 6 - F3,F1
             """
         )
-        self.config_lines = self.config.splitlines()
+        config_lines = config.splitlines()
+        return cib_content, config, config_lines
 
 
-@skip_unless_fencing_level_supported
 class LevelBadCommand(LevelTestsBase):
     def test_success(self):
         self.assert_pcs_fail(
@@ -936,51 +952,6 @@ class LevelBadCommand(LevelTestsBase):
         )
 
 
-@skip_unless_fencing_level_supported
-class LevelAddTargetUpgradesCib(LevelTestsBase):
-    def setUp(self):
-        self.temp_cib = get_tmp_file("tier1_test_stonith_level")
-        write_file_to_tmpfile(rc("cib-empty-withnodes.xml"), self.temp_cib)
-        self.pcs_runner = PcsRunner(self.temp_cib.name)
-
-    def tearDown(self):
-        self.temp_cib.close()
-
-    @skip_unless_fencing_level_attribute_supported
-    def test_attribute(self):
-        self.fixture_stonith_resource("F1")
-        self.assert_pcs_success(
-            "stonith level add 1 attrib%fencewith=levels F1".split(),
-            "CIB has been upgraded to the latest schema version.\n",
-        )
-        self.assert_pcs_success(
-            "stonith level".split(),
-            outdent(
-                """\
-                Target: fencewith=levels
-                  Level 1 - F1
-                """
-            ),
-        )
-
-    def test_regexp(self):
-        self.fixture_stonith_resource("F1")
-        self.assert_pcs_success(
-            "stonith level add 1 regexp%node-\\d+ F1".split(),
-            "CIB has been upgraded to the latest schema version.\n",
-        )
-        self.assert_pcs_success(
-            "stonith level".split(),
-            outdent(
-                """\
-                Target: node-\\d+
-                  Level 1 - F1
-                """
-            ),
-        )
-
-
-@skip_unless_fencing_level_supported
 class LevelAdd(LevelTestsBase):
     def test_not_enough_params(self):
         self.assert_pcs_fail(
@@ -1129,7 +1100,7 @@ class LevelAdd(LevelTestsBase):
             "stonith level".split(),
             outdent(
                 """\
-                Target: rh7-\\d
+                Target (regexp): rh7-\\d
                   Level 1 - F1
                 """
             ),
@@ -1146,13 +1117,12 @@ class LevelAdd(LevelTestsBase):
             "stonith level".split(),
             outdent(
                 """\
-                Target: rh7-\\d
+                Target (regexp): rh7-\\d
                   Level 1 - F1
                 """
             ),
         )
 
-    @skip_unless_fencing_level_attribute_supported
     def test_add_node_attribute(self):
         self.fixture_stonith_resource("F1")
         self.assert_pcs_success(
@@ -1204,7 +1174,11 @@ class LevelAdd(LevelTestsBase):
         self.fixture_stonith_resource("F2")
         self.fixture_stonith_resource("F3")
 
-        self.assert_pcs_success("stonith level add 1 rh7-1 F1,F2".split())
+        self.assert_pcs_success(
+            "stonith level add 1 rh7-1 F1,F2".split(),
+            "Warning: Delimiting stonith devices with ',' is deprecated and "
+            "will be removed. Please use a space to delimit stonith devices.\n",
+        )
         self.assert_pcs_success(
             "stonith level".split(),
             outdent(
@@ -1215,7 +1189,11 @@ class LevelAdd(LevelTestsBase):
             ),
         )
 
-        self.assert_pcs_success("stonith level add 2 rh7-1 F1,F2 F3".split())
+        self.assert_pcs_success(
+            "stonith level add 2 rh7-1 F1,F2 F3".split(),
+            "Warning: Delimiting stonith devices with ',' is deprecated and "
+            "will be removed. Please use a space to delimit stonith devices.\n",
+        )
         self.assert_pcs_success(
             "stonith level".split(),
             outdent(
@@ -1227,7 +1205,11 @@ class LevelAdd(LevelTestsBase):
             ),
         )
 
-        self.assert_pcs_success("stonith level add 3 rh7-1 F1 F2,F3".split())
+        self.assert_pcs_success(
+            "stonith level add 3 rh7-1 F1 F2,F3".split(),
+            "Warning: Delimiting stonith devices with ',' is deprecated and "
+            "will be removed. Please use a space to delimit stonith devices.\n",
+        )
         self.assert_pcs_success(
             "stonith level".split(),
             outdent(
@@ -1309,7 +1291,6 @@ class LevelAdd(LevelTestsBase):
         )
 
 
-@skip_unless_fencing_level_supported
 @skip_unless_crm_rule()
 class LevelConfig(LevelTestsBase):
     full_config = outdent(
@@ -1406,8 +1387,13 @@ class LevelConfig(LevelTestsBase):
         )
 
 
-@skip_unless_fencing_level_supported
-class LevelClear(LevelTestsBase):
+class LevelClearDeprecatedSyntax(LevelTestsBase):
+    deprecated_syntax = (
+        "Warning: Syntax 'pcs stonith level clear [<target> | <stonith id(s)>] "
+        "is deprecated and will be removed. Please use 'pcs stonith level "
+        "clear [target <target>] | [stonith <stonith id>...]'.\n"
+    )
+
     def setUp(self):
         super().setUp()
         self.fixture_full_configuration()
@@ -1417,35 +1403,45 @@ class LevelClear(LevelTestsBase):
         self.assert_pcs_success("stonith level config".split(), "")
 
     def test_clear_nonexistant_node_or_device(self):
-        self.assert_pcs_success("stonith level clear rh-X".split())
+        self.assert_pcs_success(
+            "stonith level clear rh-X".split(), self.deprecated_syntax
+        )
         self.assert_pcs_success("stonith level config".split(), self.config)
 
     def test_clear_nonexistant_devices(self):
-        self.assert_pcs_success("stonith level clear F1,F5".split())
+        self.assert_pcs_success(
+            "stonith level clear F1,F5".split(), self.deprecated_syntax
+        )
         self.assert_pcs_success("stonith level config".split(), self.config)
 
     def test_pattern_is_not_device(self):
-        self.assert_pcs_success("stonith level clear regexp%F1".split())
+        self.assert_pcs_success(
+            "stonith level clear regexp%F1".split(), self.deprecated_syntax
+        )
         self.assert_pcs_success("stonith level config".split(), self.config)
 
     def test_clear_node(self):
-        self.assert_pcs_success("stonith level clear rh7-1".split())
+        self.assert_pcs_success(
+            "stonith level clear rh7-1".split(), self.deprecated_syntax
+        )
         self.assert_pcs_success(
             "stonith level config".split(),
             "\n".join(self.config_lines[3:]) + "\n",
         )
 
     def test_clear_pattern(self):
-        self.assert_pcs_success("stonith level clear regexp%rh7-\\d".split())
+        self.assert_pcs_success(
+            "stonith level clear regexp%rh7-\\d".split(), self.deprecated_syntax
+        )
         self.assert_pcs_success(
             "stonith level config".split(),
             "\n".join(self.config_lines[:6] + self.config_lines[9:]) + "\n",
         )
 
-    @skip_unless_fencing_level_attribute_supported
     def test_clear_attribute(self):
         self.assert_pcs_success(
-            "stonith level clear attrib%fencewith=levels2".split()
+            "stonith level clear attrib%fencewith=levels2".split(),
+            self.deprecated_syntax,
         )
         self.assert_pcs_success(
             "stonith level config".split(),
@@ -1453,7 +1449,9 @@ class LevelClear(LevelTestsBase):
         )
 
     def test_clear_device(self):
-        self.assert_pcs_success("stonith level clear F1".split())
+        self.assert_pcs_success(
+            "stonith level clear F1".split(), self.deprecated_syntax
+        )
         self.assert_pcs_success(
             "stonith level config".split(),
             "\n".join(
@@ -1465,13 +1463,317 @@ class LevelClear(LevelTestsBase):
         )
 
     def test_clear_devices(self):
-        self.assert_pcs_success("stonith level clear F2,F1".split())
+        self.assert_pcs_success(
+            "stonith level clear F2,F1".split(), self.deprecated_syntax
+        )
         self.assert_pcs_success(
             "stonith level config".split(),
             "\n".join(self.config_lines[:7] + self.config_lines[8:]) + "\n",
         )
 
 
+class LevelClear(LevelTestsBase):
+    def setUp(self):
+        super().setUp()
+        self.fixture_full_configuration()
+
+    def test_missing_target(self):
+        self.assert_pcs_fail(
+            "stonith level clear target".split(),
+            "Error: Missing value after 'target'\n",
+        )
+
+    def test_missing_device(self):
+        self.assert_pcs_fail(
+            "stonith level clear stonith".split(),
+            "Error: Missing value after 'stonith'\n",
+        )
+
+    def test_target_and_device(self):
+        self.assert_pcs_fail(
+            "stonith level clear target rh7-1 stonith F1".split(),
+            "Error: Only one of 'target' and 'stonith' can be used\n",
+        )
+
+    def test_clear_all(self):
+        self.assert_pcs_success("stonith level clear".split())
+        self.assert_pcs_success("stonith level config".split(), "")
+
+    def test_clear_nonexistant_node(self):
+        self.assert_pcs_fail(
+            "stonith level clear target rh-X".split(),
+            "Error: Fencing level for 'rh-X' does not exist\n"
+            + ERRORS_HAVE_OCURRED,
+        )
+        self.assert_pcs_success("stonith level config".split(), self.config)
+
+    def test_clear_nonexistant_devices(self):
+        self.assert_pcs_fail(
+            "stonith level clear stonith F1 F5".split(),
+            "Error: Fencing level with device(s) 'F1', 'F5' does not exist\n"
+            + ERRORS_HAVE_OCURRED,
+        )
+        self.assert_pcs_success("stonith level config".split(), self.config)
+
+    def test_clear_node(self):
+        self.assert_pcs_success("stonith level clear target rh7-1".split())
+        self.assert_pcs_success(
+            "stonith level config".split(),
+            "\n".join(self.config_lines[3:]) + "\n",
+        )
+
+    def test_clear_pattern(self):
+        self.assert_pcs_success(
+            "stonith level clear target regexp%rh7-\\d".split()
+        )
+        self.assert_pcs_success(
+            "stonith level config".split(),
+            "\n".join(self.config_lines[:6] + self.config_lines[9:]) + "\n",
+        )
+
+    def test_clear_attribute(self):
+        self.assert_pcs_success(
+            "stonith level clear target attrib%fencewith=levels2".split()
+        )
+        self.assert_pcs_success(
+            "stonith level config".split(),
+            "\n".join(self.config_lines[:11]) + "\n",
+        )
+
+    def test_clear_device(self):
+        self.assert_pcs_success("stonith level clear stonith F1".split())
+        self.assert_pcs_success(
+            "stonith level config".split(),
+            "\n".join(
+                self.config_lines[0:1]
+                + self.config_lines[2:5]
+                + self.config_lines[6:]
+            )
+            + "\n",
+        )
+
+    def test_clear_devices(self):
+        self.assert_pcs_success("stonith level clear stonith F2 F1".split())
+        self.assert_pcs_success(
+            "stonith level config".split(),
+            "\n".join(self.config_lines[:7] + self.config_lines[8:]) + "\n",
+        )
+
+    def test_clear_devices_comma(self):
+        # test that old syntax doesn't work in the new command
+        self.assert_pcs_fail(
+            "stonith level clear stonith F2,F1".split(),
+            "Error: invalid stonith id 'F2,F1', ',' is not a valid character "
+            "for a stonith id\n" + ERRORS_HAVE_OCURRED,
+        )
+        self.assert_pcs_success("stonith level config".split(), self.config)
+
+
+class LevelDeleteRemoveDeprecatedSyntax(LevelTestsBase):
+    command = None
+    deprecation_warning = (
+        "Warning: Syntax 'pcs stonith level delete | remove <level> [<target>] "
+        "[<stonith id>...]' is deprecated and will be removed. Please use 'pcs "
+        "stonith level delete | remove <level> [target <target>] [stonith "
+        "<stonith id>...]'.\n"
+    )
+
+    def setUp(self):
+        super().setUp()
+        self.fixture_full_configuration()
+
+    def _test_usage(self):
+        self.assert_pcs_fail(
+            ["stonith", "level", self.command],
+            stdout_start=outdent(
+                f"""
+                Usage: pcs stonith level {self.command}...
+                    level {self.command} <"""
+            ),
+        )
+
+    def _test_nonexisting_level_node_device(self):
+        self.assert_pcs_fail(
+            ["stonith", "level", self.command, "1", "rh7-1", "F3"],
+            self.deprecation_warning
+            + outdent(
+                """\
+                Error: Fencing level for 'rh7-1' at level '1' with device(s) 'F3' does not exist
+                Error: Fencing level at level '1' with device(s) 'F3', 'rh7-1' does not exist
+                """
+            )
+            + ERRORS_HAVE_OCURRED,
+        )
+        self.assert_pcs_success("stonith level config".split(), self.config)
+
+    def _test_nonexisting_level_pattern_device(self):
+        self.assert_pcs_fail(
+            ["stonith", "level", self.command, "1", r"regexp%rh7-\d", "F3"],
+            (
+                self.deprecation_warning
+                + "Error: Fencing level for 'rh7-\\d' at level '1' with "
+                "device(s) 'F3' does not exist\n" + ERRORS_HAVE_OCURRED
+            ),
+        )
+        self.assert_pcs_success("stonith level config".split(), self.config)
+
+        self.assert_pcs_fail(
+            ["stonith", "level", self.command, "3", r"regexp%rh7-\d", "F1,F2"],
+            (
+                self.deprecation_warning
+                + "Warning: Delimiting stonith devices with ',' is deprecated "
+                "and will be removed. Please use a space to delimit stonith "
+                "devices.\n"
+                "Error: Fencing level for 'rh7-\\d' at level '3' with "
+                "device(s) 'F1', 'F2' does not exist\n" + ERRORS_HAVE_OCURRED
+            ),
+        )
+        self.assert_pcs_success("stonith level config".split(), self.config)
+
+    def _test_nonexisting_level(self):
+        self.assert_pcs_fail(
+            ["stonith", "level", self.command, "9"],
+            (
+                "Error: Fencing level at level '9' does not exist\n"
+                + ERRORS_HAVE_OCURRED
+            ),
+        )
+        self.assert_pcs_success("stonith level config".split(), self.config)
+
+    def _test_remove_level(self):
+        self.assert_pcs_success(["stonith", "level", self.command, "1"])
+        self.assert_pcs_success(
+            "stonith level config".split(),
+            "\n".join(
+                self.config_lines[0:1]
+                + self.config_lines[2:4]
+                + self.config_lines[5:]
+            )
+            + "\n",
+        )
+
+    def _test_remove_level_node(self):
+        self.assert_pcs_success(
+            ["stonith", "level", self.command, "1", "rh7-2"],
+            self.deprecation_warning,
+        )
+        self.assert_pcs_success(
+            "stonith level config".split(),
+            "\n".join(self.config_lines[:4] + self.config_lines[5:]) + "\n",
+        )
+
+    def _test_remove_level_pattern(self):
+        self.assert_pcs_success(
+            ["stonith", "level", self.command, "3", r"regexp%rh7-\d"],
+            self.deprecation_warning,
+        )
+        self.assert_pcs_success(
+            "stonith level config".split(),
+            "\n".join(self.config_lines[:7] + self.config_lines[8:]) + "\n",
+        )
+
+    def _test_remove_level_attrib(self):
+        self.assert_pcs_success(
+            ["stonith", "level", self.command, "6", "attrib%fencewith=levels2"],
+            self.deprecation_warning,
+        )
+        self.assert_pcs_success(
+            "stonith level config".split(),
+            "\n".join(self.config_lines[:11]) + "\n",
+        )
+
+    def _test_remove_level_device(self):
+        self.assert_pcs_success(
+            ["stonith", "level", self.command, "1", "F2"],
+            self.deprecation_warning,
+        )
+        self.assert_pcs_success(
+            "stonith level config".split(),
+            "\n".join(self.config_lines[:4] + self.config_lines[5:]) + "\n",
+        )
+
+    def _test_remove_level_devices(self):
+        self.assert_pcs_success(
+            ["stonith", "level", self.command, "3", "F2", "F1"],
+            self.deprecation_warning,
+        )
+        self.assert_pcs_success(
+            "stonith level config".split(),
+            "\n".join(self.config_lines[:7] + self.config_lines[8:]) + "\n",
+        )
+
+    def _test_remove_level_devices_old_syntax(self):
+        self.assert_pcs_success(
+            ["stonith", "level", self.command, "3", "F2,F1"],
+            self.deprecation_warning
+            + "Warning: Delimiting stonith devices with ',' is deprecated "
+            "and will be removed. Please use a space to delimit stonith "
+            "devices.\n",
+        )
+        self.assert_pcs_success(
+            "stonith level config".split(),
+            "\n".join(self.config_lines[:7] + self.config_lines[8:]) + "\n",
+        )
+
+    def _test_remove_level_node_device(self):
+        self.assert_pcs_success(
+            ["stonith", "level", self.command, "1", "rh7-2", "F2"],
+            self.deprecation_warning,
+        )
+        self.assert_pcs_success(
+            "stonith level config".split(),
+            "\n".join(self.config_lines[:4] + self.config_lines[5:]) + "\n",
+        )
+
+    def _test_remove_level_pattern_device(self):
+        self.assert_pcs_success(
+            [
+                "stonith",
+                "level",
+                self.command,
+                "3",
+                r"regexp%rh7-\d",
+                "F2",
+                "F1",
+            ],
+            self.deprecation_warning,
+        )
+        self.assert_pcs_success(
+            "stonith level config".split(),
+            "\n".join(self.config_lines[:7] + self.config_lines[8:]) + "\n",
+        )
+
+    def _test_remove_level_attrib_device(self):
+        self.assert_pcs_success(
+            [
+                "stonith",
+                "level",
+                self.command,
+                "6",
+                "attrib%fencewith=levels2",
+                "F3",
+                "F1",
+            ],
+            self.deprecation_warning,
+        )
+        self.assert_pcs_success(
+            "stonith level config".split(),
+            "\n".join(self.config_lines[:11]) + "\n",
+        )
+
+
+class LevelDeleteDeprecatedSyntax(
+    LevelDeleteRemoveDeprecatedSyntax, metaclass=ParametrizedTestMetaClass
+):
+    command = "delete"
+
+
+class LevelRemoveDeprecatedSyntax(
+    LevelDeleteRemoveDeprecatedSyntax, metaclass=ParametrizedTestMetaClass
+):
+    command = "remove"
+
+
 class LevelDeleteRemove(LevelTestsBase):
     command = None
 
@@ -1491,11 +1793,19 @@ class LevelDeleteRemove(LevelTestsBase):
 
     def _test_nonexisting_level_node_device(self):
         self.assert_pcs_fail(
-            ["stonith", "level", self.command, "1", "rh7-1", "F3"],
+            [
+                "stonith",
+                "level",
+                self.command,
+                "1",
+                "target",
+                "rh7-1",
+                "stonith",
+                "F3",
+            ],
             outdent(
                 """\
                 Error: Fencing level for 'rh7-1' at level '1' with device(s) 'F3' does not exist
-                Error: Fencing level at level '1' with device(s) 'F3', 'rh7-1' does not exist
                 """
             )
             + ERRORS_HAVE_OCURRED,
@@ -1504,7 +1814,16 @@ class LevelDeleteRemove(LevelTestsBase):
 
     def _test_nonexisting_level_pattern_device(self):
         self.assert_pcs_fail(
-            ["stonith", "level", self.command, "1", r"regexp%rh7-\d", "F3"],
+            [
+                "stonith",
+                "level",
+                self.command,
+                "1",
+                "target",
+                r"regexp%rh7-\d",
+                "stonith",
+                "F3",
+            ],
             (
                 "Error: Fencing level for 'rh7-\\d' at level '1' with "
                 "device(s) 'F3' does not exist\n" + ERRORS_HAVE_OCURRED
@@ -1513,7 +1832,17 @@ class LevelDeleteRemove(LevelTestsBase):
         self.assert_pcs_success("stonith level config".split(), self.config)
 
         self.assert_pcs_fail(
-            ["stonith", "level", self.command, "3", r"regexp%rh7-\d", "F1,F2"],
+            [
+                "stonith",
+                "level",
+                self.command,
+                "3",
+                "target",
+                r"regexp%rh7-\d",
+                "stonith",
+                "F1",
+                "F2",
+            ],
             (
                 "Error: Fencing level for 'rh7-\\d' at level '3' with "
                 "device(s) 'F1', 'F2' does not exist\n" + ERRORS_HAVE_OCURRED
@@ -1545,7 +1874,7 @@ class LevelDeleteRemove(LevelTestsBase):
 
     def _test_remove_level_node(self):
         self.assert_pcs_success(
-            ["stonith", "level", self.command, "1", "rh7-2"]
+            ["stonith", "level", self.command, "1", "target", "rh7-2"]
         )
         self.assert_pcs_success(
             "stonith level config".split(),
@@ -1554,17 +1883,23 @@ class LevelDeleteRemove(LevelTestsBase):
 
     def _test_remove_level_pattern(self):
         self.assert_pcs_success(
-            ["stonith", "level", self.command, "3", r"regexp%rh7-\d"]
+            ["stonith", "level", self.command, "3", "target", r"regexp%rh7-\d"]
         )
         self.assert_pcs_success(
             "stonith level config".split(),
             "\n".join(self.config_lines[:7] + self.config_lines[8:]) + "\n",
         )
 
-    @skip_unless_fencing_level_attribute_supported
     def _test_remove_level_attrib(self):
         self.assert_pcs_success(
-            ["stonith", "level", self.command, "6", "attrib%fencewith=levels2"]
+            [
+                "stonith",
+                "level",
+                self.command,
+                "6",
+                "target",
+                "attrib%fencewith=levels2",
+            ]
         )
         self.assert_pcs_success(
             "stonith level config".split(),
@@ -1572,7 +1907,9 @@ class LevelDeleteRemove(LevelTestsBase):
         )
 
     def _test_remove_level_device(self):
-        self.assert_pcs_success(["stonith", "level", self.command, "1", "F2"])
+        self.assert_pcs_success(
+            ["stonith", "level", self.command, "1", "stonith", "F2"]
+        )
         self.assert_pcs_success(
             "stonith level config".split(),
             "\n".join(self.config_lines[:4] + self.config_lines[5:]) + "\n",
@@ -1580,25 +1917,50 @@ class LevelDeleteRemove(LevelTestsBase):
 
     def _test_remove_level_devices(self):
         self.assert_pcs_success(
-            ["stonith", "level", self.command, "3", "F2", "F1"]
+            ["stonith", "level", self.command, "3", "stonith", "F2", "F1"]
         )
         self.assert_pcs_success(
             "stonith level config".split(),
             "\n".join(self.config_lines[:7] + self.config_lines[8:]) + "\n",
         )
 
-    def _test_remove_level_devices_old_syntax(self):
-        self.assert_pcs_success(
-            ["stonith", "level", self.command, "3", "F2,F1"]
-        )
-        self.assert_pcs_success(
-            "stonith level config".split(),
-            "\n".join(self.config_lines[:7] + self.config_lines[8:]) + "\n",
+    def _test_comma_separated_devices_not_supported(self):
+        self.assert_pcs_fail(
+            ["stonith", "level", self.command, "3", "stonith", "F2,F1"],
+            "Error: invalid stonith id 'F2,F1', ',' is not a valid character "
+            "for a stonith id\n" + ERRORS_HAVE_OCURRED,
         )
 
     def _test_remove_level_node_device(self):
         self.assert_pcs_success(
-            ["stonith", "level", self.command, "1", "rh7-2", "F2"]
+            [
+                "stonith",
+                "level",
+                self.command,
+                "1",
+                "target",
+                "rh7-2",
+                "stonith",
+                "F2",
+            ]
+        )
+        self.assert_pcs_success(
+            "stonith level config".split(),
+            "\n".join(self.config_lines[:4] + self.config_lines[5:]) + "\n",
+        )
+
+    def _test_remove_level_device_node(self):
+        self.assert_pcs_success(
+            [
+                "stonith",
+                "level",
+                self.command,
+                "1",
+                "stonith",
+                "F2",
+                "target",
+                "rh7-2",
+            ]
         )
         self.assert_pcs_success(
             "stonith level config".split(),
@@ -1612,7 +1974,9 @@ class LevelDeleteRemove(LevelTestsBase):
                 "level",
                 self.command,
                 "3",
+                "target",
                 r"regexp%rh7-\d",
+                "stonith",
                 "F2",
                 "F1",
             ]
@@ -1622,7 +1986,6 @@ class LevelDeleteRemove(LevelTestsBase):
             "\n".join(self.config_lines[:7] + self.config_lines[8:]) + "\n",
         )
 
-    @skip_unless_fencing_level_attribute_supported
     def _test_remove_level_attrib_device(self):
         self.assert_pcs_success(
             [
@@ -1630,7 +1993,9 @@ class LevelDeleteRemove(LevelTestsBase):
                 "level",
                 self.command,
                 "6",
+                "target",
                 "attrib%fencewith=levels2",
+                "stonith",
                 "F3",
                 "F1",
             ]
@@ -1640,18 +2005,35 @@ class LevelDeleteRemove(LevelTestsBase):
             "\n".join(self.config_lines[:11]) + "\n",
         )
 
+    def _test_missing_stonith_keyword(self):
+        self.assert_pcs_fail(
+            ["stonith", "level", self.command, "1", "target", "rh7-2", "F2"],
+            "Error: At most one target can be specified\n",
+        )
+
+    def _test_missing_target_stonith_values(self):
+        self.assert_pcs_fail(
+            ["stonith", "level", self.command, "1", "target"],
+            "Error: Missing value after 'target'\n",
+        )
+        self.assert_pcs_fail(
+            ["stonith", "level", self.command, "1", "stonith"],
+            "Error: Missing value after 'stonith'\n",
+        )
+        self.assert_pcs_fail(
+            ["stonith", "level", self.command, "1", "target", "stonith"],
+            "Error: Missing value after 'target' and 'stonith'\n",
+        )
+
 
-@skip_unless_fencing_level_supported
 class LevelDelete(LevelDeleteRemove, metaclass=ParametrizedTestMetaClass):
     command = "delete"
 
 
-@skip_unless_fencing_level_supported
 class LevelRemove(LevelDeleteRemove, metaclass=ParametrizedTestMetaClass):
     command = "remove"
 
 
-@skip_unless_fencing_level_supported
 class LevelVerify(LevelTestsBase):
     def test_success(self):
         self.fixture_full_configuration()
