@@ -30,8 +30,16 @@ def xml_format(xml_string):
 
 def get_assert_pcs_effect_mixin(get_cib_part):
     class AssertPcsEffectMixin(AssertPcsMixin):
-        def assert_resources_xml_in_cib(self, expected_xml_resources):
-            xml = get_cib_part(self.temp_cib)
+        def assert_resources_xml_in_cib(
+            self,
+            expected_xml_resources,
+            get_cib_part_func=None,
+        ):
+            self.temp_cib.seek(0)
+            if get_cib_part_func is not None:
+                xml = get_cib_part_func(self.temp_cib)
+            else:
+                xml = get_cib_part(self.temp_cib)
             try:
                 assert_xml_equal(expected_xml_resources, xml.decode())
             except AssertionError as e:
@@ -39,7 +47,7 @@ def get_assert_pcs_effect_mixin(get_cib_part):
                     "{0}\n\nCopy format ;)\n{1}".format(
                         e.args[0], xml_format(xml.decode())
                     )
-                )
+                ) from e
 
         def assert_effect_single(
             self,
@@ -64,7 +72,7 @@ def get_assert_pcs_effect_mixin(get_cib_part):
         ):
             alternative_list = (
                 alternative_cmds
-                if isinstance(alternative_cmds, list)
+                if isinstance(alternative_cmds[0], list)
                 else [alternative_cmds]
             )
             self.temp_cib.seek(0)
