@@ -53,7 +53,10 @@ def log_response(response, indent=0):
         label_data.append(("respose_code", response.response_code))
     else:
         label_data.extend(
-            [("errno", response.errno), ("error_msg", response.error_msg),]
+            [
+                ("errno", response.errno),
+                ("error_msg", response.error_msg),
+            ]
         )
 
     label_data.append(("data", parse_qs(response.request.data)))
@@ -119,6 +122,7 @@ def _communication_to_response(
     was_connected,
     errno,
     error_msg,
+    raw_data,
 ):
     return Response(
         MockCurlSimple(
@@ -134,7 +138,7 @@ def _communication_to_response(
                 #    by pcsd, we will do so by setting an appropriate response.
                 #    The actual token value doesn't matter.
                 RequestTarget(label, dest_list=dest_list, token=None),
-                RequestData(action, param_list),
+                RequestData(action, param_list, raw_data),
             ),
         ),
         was_connected=was_connected,
@@ -153,6 +157,7 @@ def create_communication(
     was_connected=True,
     errno=0,
     error_msg=None,
+    raw_data=None,
 ):
     """
     list of dict communication_list -- each dict describes one request-response
@@ -168,6 +173,7 @@ def create_communication(
             bool was_connected -- see Response
             int errno -- see Response
             string error_msg -- see Response
+            string raw_data -- see data attrib in RequestData
         if some key is not present, it is put here from common values - rest
         args of this fuction(except name, communication_list,
         error_msg_template)
@@ -179,6 +185,7 @@ def create_communication(
     bool was_connected -- see Response
     int errno -- see Response
     string error_msg -- see Response
+    string raw_data -- see data attrib in RequestData
     """
     # We don't care about tokens, see _communication_to_response.
     common = dict(
@@ -190,6 +197,7 @@ def create_communication(
         was_connected=was_connected,
         errno=errno,
         error_msg=error_msg,
+        raw_data=raw_data,
     )
 
     response_list = []
@@ -342,7 +350,8 @@ class NodeCommunicator:
 
     def add_requests(self, request_list):
         _, add_request_call = self.__call_queue.take(
-            CALL_TYPE_HTTP_ADD_REQUESTS, request_list,
+            CALL_TYPE_HTTP_ADD_REQUESTS,
+            request_list,
         )
 
         expected_request_list = add_request_call.request_list
